@@ -9,7 +9,6 @@
 #include "frontend/CompilationStencil.h"  // ScopeContext
 #include "frontend/Parser.h"              // ParserBase
 #include "js/friend/ErrorMessages.h"      // JSMSG_*
-#include "vm/WellKnownAtom.h"             // js_*_str
 
 using mozilla::Maybe;
 using mozilla::Nothing;
@@ -34,6 +33,12 @@ const char* DeclarationKindString(DeclarationKind kind) {
       return "let";
     case DeclarationKind::Const:
       return "const";
+#ifdef ENABLE_EXPLICIT_RESOURCE_MANAGEMENT
+    case DeclarationKind::Using:
+      return "using";
+    case DeclarationKind::AwaitUsing:
+      return "await using";
+#endif
     case DeclarationKind::Class:
       return "class";
     case DeclarationKind::Import:
@@ -179,6 +184,50 @@ void UsedNameTracker::rewind(RewindToken token) {
   }
 }
 
+#if defined(DEBUG) || defined(JS_JITSPEW)
+void UsedNameTracker::dump(ParserAtomsTable& table) {
+  js::Fprinter out(stderr);
+
+  out.printf("Used names:\n");
+
+  for (UsedNameMap::Range r = map_.all(); !r.empty(); r.popFront()) {
+    const auto& item = r.front();
+
+    const auto& name = item.key();
+    const auto& nameInfo = item.value();
+
+    out.put("  ");
+    table.dumpCharsNoQuote(out, name);
+    out.put("\n");
+
+    if (nameInfo.visibility_ == NameVisibility::Private) {
+      out.put("    visibility: private\n");
+    }
+
+    if (nameInfo.firstUsePos_) {
+      const auto& pos = *nameInfo.firstUsePos_;
+      out.printf("    first use pos: %u\n", pos.begin);
+    }
+
+    out.printf("    %zu user(s)", nameInfo.uses_.length());
+    bool first = true;
+    for (const auto& use : nameInfo.uses_) {
+      if (first) {
+        first = false;
+        out.put(" (");
+      } else {
+        out.put(", ");
+      }
+      out.printf("%u/%u", use.scriptId, use.scopeId);
+    }
+    if (!first) {
+      out.put(")");
+    }
+    out.put("\n");
+  }
+}
+#endif
+
 void ParseContext::Scope::dump(ParseContext* pc, ParserBase* parser) {
   fprintf(stdout, "ParseScope %p", this);
 
@@ -335,7 +384,7 @@ ParseContext::ParseContext(FrontendContext* fc, ParseContext*& parent,
 
 bool ParseContext::init() {
   if (scriptId_ == UINT32_MAX) {
-    errorReporter_.errorNoOffset(JSMSG_NEED_DIET, js_script_str);
+    errorReporter_.errorNoOffset(JSMSG_NEED_DIET, "script");
     return false;
   }
 
@@ -550,15 +599,30 @@ bool ParseContext::hasUsedName(const UsedNameTracker& usedNames,
   return false;
 }
 
+bool ParseContext::hasClosedOverName(const UsedNameTracker& usedNames,
+                                     TaggedParserAtomIndex name) {
+  if (auto p = usedNames.lookup(name)) {
+    return p->value().isClosedOver(scriptId());
+  }
+  return false;
+}
+
 bool ParseContext::hasUsedFunctionSpecialName(const UsedNameTracker& usedNames,
                                               TaggedParserAtomIndex name) {
   MOZ_ASSERT(name == TaggedParserAtomIndex::WellKnown::arguments() ||
-             name == TaggedParserAtomIndex::WellKnown::dotThis() ||
-             name == TaggedParserAtomIndex::WellKnown::dotNewTarget());
+             name == TaggedParserAtomIndex::WellKnown::dot_this_() ||
+             name == TaggedParserAtomIndex::WellKnown::dot_newTarget_());
   return hasUsedName(usedNames, name) ||
          functionBox()->bindingsAccessedDynamically();
 }
 
+bool ParseContext::hasClosedOverFunctionSpecialName(
+    const UsedNameTracker& usedNames, TaggedParserAtomIndex name) {
+  MOZ_ASSERT(name == TaggedParserAtomIndex::WellKnown::arguments());
+  return hasClosedOverName(usedNames, name) ||
+         functionBox()->bindingsAccessedDynamically();
+}
+
 bool ParseContext::declareFunctionThis(const UsedNameTracker& usedNames,
                                        bool canSkipLazyClosedOverBindings) {
   // The asm.js validator does all its own symbol-table management so, as an
@@ -571,7 +635,7 @@ bool ParseContext::declareFunctionThis(const UsedNameTracker& usedNames,
   // '.this' to be bound. Class field initializers implicitly read `.this`.
   // Therefore we unconditionally declare `.this` in all class constructors.
   FunctionBox* funbox = functionBox();
-  auto dotThis = TaggedParserAtomIndex::WellKnown::dotThis();
+  auto dotThis = TaggedParserAtomIndex::WellKnown::dot_this_();
 
   bool declareThis;
   if (canSkipLazyClosedOverBindings) {
@@ -601,17 +665,41 @@ bool ParseContext::declareFunctionArgumentsObject(
   ParseContext::Scope& funScope = functionScope();
   ParseContext::Scope& _varScope = varScope();
 
-  bool usesArguments = false;
   bool hasExtraBodyVarScope = &funScope != &_varScope;
 
   // Time to implement the odd semantics of 'arguments'.
   auto argumentsName = TaggedParserAtomIndex::WellKnown::arguments();
 
-  bool tryDeclareArguments;
+  bool tryDeclareArguments = false;
+  bool needsArgsObject = false;
+
+  // When delazifying simply defer to the function box.
   if (canSkipLazyClosedOverBindings) {
     tryDeclareArguments = funbox->shouldDeclareArguments();
+    needsArgsObject = funbox->needsArgsObj();
   } else {
-    tryDeclareArguments = hasUsedFunctionSpecialName(usedNames, argumentsName);
+    // We cannot compute these values when delazifying, hence why we need to
+    // rely on the function box flags instead.
+    bool bindingClosedOver =
+        hasClosedOverFunctionSpecialName(usedNames, argumentsName);
+    bool bindingUsedOnlyHere =
+        hasUsedFunctionSpecialName(usedNames, argumentsName) &&
+        !bindingClosedOver;
+
+    // Declare arguments if there's a closed-over consumer of the binding, or if
+    // there is a non-length use and we will reference the binding during
+    // bytecode emission.
+    tryDeclareArguments =
+        !funbox->isEligibleForArgumentsLength() || bindingClosedOver;
+    // If we have a use and the binding isn't closed over, then we will do
+    // bytecode emission with the arguments intrinsic.
+    if (bindingUsedOnlyHere && funbox->isEligibleForArgumentsLength()) {
+      // If we're using the intrinsic we should not be declaring the binding.
+      MOZ_ASSERT(!tryDeclareArguments);
+      funbox->setUsesArgumentsIntrinsics();
+    } else if (tryDeclareArguments) {
+      needsArgsObject = true;
+    }
   }
 
   // ES 9.2.12 steps 19 and 20 say formal parameters, lexical bindings,
@@ -627,9 +715,19 @@ bool ParseContext::declareFunctionArgumentsObject(
   DeclaredNamePtr p = _varScope.lookupDeclaredName(argumentsName);
   if (p && p->value()->kind() == DeclarationKind::Var) {
     if (hasExtraBodyVarScope) {
+      // While there is a binding in the var scope, we should declare
+      // the binding in the function scope.
       tryDeclareArguments = true;
     } else {
-      usesArguments = true;
+      // A binding in the function scope (since varScope and functionScope are
+      // the same) exists, so arguments is used.
+      if (needsArgsObject) {
+        funbox->setNeedsArgsObj();
+      }
+
+      // There is no point in continuing on below: We know we already have
+      // a declaration of arguments in the function scope.
+      return true;
     }
   }
 
@@ -642,17 +740,11 @@ bool ParseContext::declareFunctionArgumentsObject(
         return false;
       }
       funbox->setShouldDeclareArguments();
-      usesArguments = true;
-    } else if (hasExtraBodyVarScope) {
-      // Formal parameters shadow the arguments object.
-      return true;
+      if (needsArgsObject) {
+        funbox->setNeedsArgsObj();
+      }
     }
   }
-
-  if (usesArguments) {
-    funbox->setNeedsArgsObj();
-  }
-
   return true;
 }
 
@@ -665,7 +757,7 @@ bool ParseContext::declareNewTarget(const UsedNameTracker& usedNames,
   }
 
   FunctionBox* funbox = functionBox();
-  auto dotNewTarget = TaggedParserAtomIndex::WellKnown::dotNewTarget();
+  auto dotNewTarget = TaggedParserAtomIndex::WellKnown::dot_newTarget_();
 
   bool declareNewTarget;
   if (canSkipLazyClosedOverBindings) {
@@ -692,7 +784,7 @@ bool ParseContext::declareDotGeneratorName() {
   // The special '.generator' binding must be on the function scope, and must
   // be marked closed-over, as generators expect to find it on the CallObject.
   ParseContext::Scope& funScope = functionScope();
-  auto dotGenerator = TaggedParserAtomIndex::WellKnown::dotGenerator();
+  auto dotGenerator = TaggedParserAtomIndex::WellKnown::dot_generator_();
   AddDeclaredNamePtr p = funScope.lookupDeclaredNameForAdd(dotGenerator);
   if (!p) {
     if (!funScope.addDeclaredName(this, p, dotGenerator, DeclarationKind::Var,
@@ -711,7 +803,7 @@ bool ParseContext::declareTopLevelDotGeneratorName() {
       sc()->isModuleContext(),
       "Tried to declare top level dot generator in a non-module context.");
   ParseContext::Scope& modScope = varScope();
-  auto dotGenerator = TaggedParserAtomIndex::WellKnown::dotGenerator();
+  auto dotGenerator = TaggedParserAtomIndex::WellKnown::dot_generator_();
   AddDeclaredNamePtr p = modScope.lookupDeclaredNameForAdd(dotGenerator);
   return p ||
          modScope.addDeclaredName(this, p, dotGenerator, DeclarationKind::Var,
