@@ -169,6 +169,7 @@ static void MakeGray(const JS::ArrayBufferOrView& view) {
 //  - WeakHeapPtr
 BEGIN_TEST(testGCHeapPostBarriers) {
   AutoLeaveZeal nozeal(cx);
+  AutoGCParameter disableSemispace(cx, JSGC_SEMISPACE_NURSERY_ENABLED, 0);
 
   /* Sanity check - objects start in the nursery and then become tenured. */
   JS_GC(cx);
@@ -501,7 +502,7 @@ bool CallDuringIncrementalGC(uint32_t mode, F&& f) {
 
   const int64_t BudgetMS = 10000;  // 10S should be long enough for anyone.
 
-  JS_SetGCZeal(cx, mode, 0);
+  JS::SetGCZeal(cx, mode, 0);
   JS::PrepareZoneForGC(cx, js::GetContextZone(cx));
   js::SliceBudget budget{TimeBudget(BudgetMS)};
   JS::StartIncrementalGC(cx, JS::GCOptions(), JS::GCReason::DEBUG_GC, budget);
