@@ -14,6 +14,7 @@
 #include "js/CompilationAndEvaluation.h"  // JS::Evaluate
 #include "js/GlobalObject.h"              // JS_NewGlobalObject
 #include "js/Initialization.h"
+#include "js/Prefs.h"
 #include "js/PropertyAndElement.h"  // JS_DefineFunction
 #include "js/RootingAPI.h"
 #include "js/SourceText.h"  // JS::Source{Ownership,Text}
@@ -117,9 +118,7 @@ JSObject* JSAPIRuntimeTest::createGlobal(JSPrincipals* principals) {
   /* Create the global object. */
   JS::RootedObject newGlobal(cx);
   JS::RealmOptions options;
-  options.creationOptions()
-      .setWeakRefsEnabled(JS::WeakRefSpecifier::EnabledWithCleanupSome)
-      .setSharedMemoryAndAtomicsEnabled(true);
+  options.creationOptions().setSharedMemoryAndAtomicsEnabled(true);
   newGlobal = JS_NewGlobalObject(cx, getGlobalClass(), principals,
                                  JS::FireOnNewGlobalHook, options);
   if (!newGlobal) {
@@ -231,6 +230,13 @@ int main(int argc, char* argv[]) {
     return 0;
   }
 
+  // Override prefs for jsapi-tests.
+  JS::Prefs::setAtStartup_weakrefs(true);
+  JS::Prefs::setAtStartup_experimental_weakrefs_expose_cleanupSome(true);
+#ifdef NIGHTLY_BUILD
+  JS::Prefs::setAtStartup_experimental_symbols_as_weakmap_keys(true);
+#endif
+
   if (!options.frontendOnly) {
     if (!JS_Init()) {
       printf("TEST-UNEXPECTED-FAIL | jsapi-tests | JS_Init() failed.\n");
