@@ -3,13 +3,12 @@
 
 /*---
 esid: sec-array.prototype.every
-es5id: 15.4.4.16-4-6
-description: Array.prototype.every throws TypeError if callbackfn is string
+description: Array.prototype.every applied to undefined throws a TypeError
 ---*/
 
-var arr = new Array(10);
+
 assert.throws(TypeError, function() {
-  arr.every("abc");
+  Array.prototype.every.call(undefined); // TypeError is thrown if value is undefined
 });
 
 reportCompare(0, 0);
