@@ -4,15 +4,16 @@
 /*---
 esid: sec-array.prototype.filter
 description: >
-    Array.prototype.filter - value of 'length' is a number (value is
-    positive)
+    Array.prototype.filter applied to Array-like object, 'length' is
+    own data property
 ---*/
 
 function callbackfn(val, idx, obj) {
-  return true;
+  return obj.length === 2;
 }
 
 var obj = {
+  0: 12,
   1: 11,
   2: 9,
   length: 2
@@ -20,7 +21,6 @@ var obj = {
 
 var newArr = Array.prototype.filter.call(obj, callbackfn);
 
-assert.sameValue(newArr.length, 1, 'newArr.length');
-assert.sameValue(newArr[0], 11, 'newArr[0]');
+assert.sameValue(newArr.length, 2, 'newArr.length');
 
 reportCompare(0, 0);
