@@ -11,9 +11,6 @@ description: Checking by using eval, argument at apply function is void 0
 
 eval(" Function(\"this.feat=1\").apply(void 0) ");
 
-//CHECK#1
-if (this["feat"] !== 1) {
-  $ERROR('#1: If thisArg is null or undefined, the called function is passed the global object as the this value');
-}
+assert.sameValue(this["feat"], 1, 'The value of this["feat"] is expected to be 1');
 
 reportCompare(0, 0);
