@@ -37,25 +37,23 @@ try {
 
   throw new Test262Error("Expected an exception.");
 } catch (e) {
-  verifyEqualTo(obj, "0", 1001);
-
-  verifyNotWritable(obj, "0");
-
-  verifyNotEnumerable(obj, "0");
-
-  verifyNotConfigurable(obj, "0");
-  verifyEqualTo(obj, "1", 1003);
-
-  verifyNotWritable(obj, "1");
-
-  verifyNotEnumerable(obj, "1");
-
-  verifyConfigurable(obj, "1");
-
   if (!(e instanceof TypeError)) {
     throw new Test262Error("Expected TypeError, got " + e);
   }
-
 }
 
+verifyProperty(obj, "0", {
+  value: 1001,
+  writable: false,
+  enumerable: false,
+  configurable: false,
+});
+
+verifyProperty(obj, "1", {
+  value: 1003,
+  writable: false,
+  enumerable: false,
+  configurable: true,
+});
+
 reportCompare(0, 0);
