@@ -29,8 +29,9 @@ assert.throws(TypeError, function() {
 });
 verifyEqualTo(arrObj, "1", getFunc());
 
-verifyNotEnumerable(arrObj, "1");
-
-verifyConfigurable(arrObj, "1");
+verifyProperty(arrObj, "1", {
+  enumerable: false,
+  configurable: true,
+});
 
 reportCompare(0, 0);
