@@ -2,12 +2,14 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.2-2-12
+es5id: 15.2.3.2-2-21
 description: >
     Object.getPrototypeOf returns the [[Prototype]] of its parameter
-    (EvalError)
+    (Array object)
 ---*/
 
-assert.sameValue(Object.getPrototypeOf(EvalError), Error, 'Object.getPrototypeOf(EvalError)');
+var arr = [1, 2, 3];
+
+assert.sameValue(Object.getPrototypeOf(arr), Array.prototype, 'Object.getPrototypeOf(arr)');
 
 reportCompare(0, 0);
