@@ -25,7 +25,7 @@ assert.sameValue(isConstructor(Object.keys), false, 'isConstructor(Object.keys)
 
 assert.throws(TypeError, () => {
   new Object.keys({});
-}, '`new Object.keys({})` throws TypeError');
+});
 
 
 reportCompare(0, 0);
