@@ -29,7 +29,7 @@ assert.sameValue(
 
 assert.throws(TypeError, () => {
   new Object.prototype.propertyIsEnumerable('');
-}, '`new Object.prototype.propertyIsEnumerable(\'\')` throws TypeError');
+});
 
 
 reportCompare(0, 0);
