@@ -3,20 +3,17 @@
 
 /*---
 info: |
-    The form (?! Disjunction ) specifies a zero-width negative lookahead.
-    In order for it to succeed, the pattern inside Disjunction must fail to match at the current position.
-    The current position is not advanced before matching the sequel
-es5id: 15.10.2.8_A2_T2
-description: >
-    Execute /Java(?!Script)([A-Z]\w*)/.exec("using of JavaBeans
-    technology") and check results
+    i) The production QuantifierPrefix :: { DecimalDigits } evaluates...
+    ii) The production QuantifierPrefix :: ? evaluates by returning the two results 0 and 1
+es5id: 15.10.2.7_A2_T2
+description: Execute /\w{3}\d?/.exec("CELL\uFFDDbox127") and check results
 ---*/
 
-var __executed = /Java(?!Script)([A-Z]\w*)/.exec("using of JavaBeans technology");
+var __executed = /\w{3}\d?/.exec("CELL\uFFDDbox127");
 
-var __expected = ["JavaBeans", "Beans"];
-__expected.index = 9;
-__expected.input = "using of JavaBeans technology";
+var __expected = ["CEL"];
+__expected.index = 0;
+__expected.input = "CELL\uFFDDbox127";
 
 assert.sameValue(
   __executed.length,
