@@ -3,18 +3,20 @@
 
 /*---
 info: |
-    The production CharacterClass :: [ [lookahead \notin {^}] ClassRanges ]
-    evaluates by evaluating ClassRanges to obtain a CharSet and returning
-    that CharSet and the boolean false
-es5id: 15.10.2.13_A1_T4
-description: Execute /q[ax-zb](?=\s+)/.exec("tqaqy ") and check results
+    The form (?= Disjunction ) specifies a zero-width positive lookahead.
+    In order for it to succeed, the pattern inside Disjunction must match at the current position, but the current position is not advanced before matching the sequel.
+    If Disjunction can match at the current position in several ways, only the first one is tried
+es5id: 15.10.2.8_A1_T4
+description: >
+    Execute /[Jj]ava([Ss]cript)?(?=\:)/.exec("taste of java: the
+    cookbook ") and check results
 ---*/
 
-var __executed = /q[ax-zb](?=\s+)/.exec("tqaqy ");
+var __executed = /[Jj]ava([Ss]cript)?(?=\:)/.exec("taste of java: the cookbook ");
 
-var __expected = ["qy"];
-__expected.index = 3;
-__expected.input = "tqaqy ";
+var __expected = ["java", undefined];
+__expected.index = 9;
+__expected.input = "taste of java: the cookbook ";
 
 assert.sameValue(
   __executed.length,
