@@ -1,4 +1,4 @@
-// |reftest| skip -- Temporal is not supported
+// |reftest| skip-if(!this.hasOwnProperty('Temporal')) -- Temporal is not enabled unconditionally
 // Copyright (C) 2022 Igalia, S.L. All rights reserved.
 // This code is governed by the BSD license found in the LICENSE file.
 
@@ -12,20 +12,12 @@ const instance = new Temporal.Calendar("iso8601");
 
 const calendar = "2016-12-31T23:59:60";
 
-let arg = { year: 1976, monthCode: "M11", day: 18, calendar };
-const result1 = instance.month(arg);
+const arg = { year: 1976, monthCode: "M11", day: 18, calendar };
+const result = instance.month(arg);
 assert.sameValue(
-  result1,
+  result,
   11,
   "leap second is a valid ISO string for calendar"
 );
 
-arg = { year: 1976, monthCode: "M11", day: 18, calendar: { calendar } };
-const result2 = instance.month(arg);
-assert.sameValue(
-  result2,
-  11,
-  "leap second is a valid ISO string for calendar (nested property)"
-);
-
 reportCompare(0, 0);
