@@ -1,4 +1,4 @@
-// |reftest| skip -- Temporal is not supported
+// |reftest| skip-if(!this.hasOwnProperty('Temporal')) -- Temporal is not enabled unconditionally
 // Copyright (C) 2022 Igalia, S.L. All rights reserved.
 // This code is governed by the BSD license found in the LICENSE file.
 
@@ -39,7 +39,7 @@ const options = TemporalHelpers.propertyBagObserver(actual, {
 
 const result = instance.yearMonthFromFields(fields, options);
 TemporalHelpers.assertPlainYearMonth(result, 1, 1, "M01", "yearMonth result");
-assert.sameValue(result.calendar, instance, "calendar result");
+assert.sameValue(result.getISOFields().calendar, "iso8601", "calendar slot should store a string");
 assert.compareArray(actual, expected, "order of operations");
 
 reportCompare(0, 0);
