@@ -1,4 +1,4 @@
-// |reftest| skip -- Temporal is not supported
+// |reftest| skip-if(!this.hasOwnProperty('Temporal')) -- Temporal is not enabled unconditionally
 // Copyright (C) 2022 Igalia, S.L. All rights reserved.
 // This code is governed by the BSD license found in the LICENSE file.
 
@@ -17,7 +17,6 @@ const tests = [
   ["2000-05-02T15:23[!u-ca=iso8601]", "with ! and no time zone"],
   ["2000-05-02T15:23[UTC][!u-ca=iso8601]", "with ! and time zone"],
   ["2000-05-02T15:23[u-ca=iso8601][u-ca=discord]", "second annotation ignored"],
-  ["2000-05-02T15:23[u-ca=iso8601][!u-ca=discord]", "second annotation ignored even with !"],
 ];
 
 const instance = new Temporal.PlainDate(2000, 5, 2);
