@@ -1,4 +1,4 @@
-// |reftest| skip -- Temporal is not supported
+// |reftest| skip-if(!this.hasOwnProperty('Temporal')) -- Temporal is not enabled unconditionally
 // Copyright (C) 2022 Igalia, S.L. All rights reserved.
 // This code is governed by the BSD license found in the LICENSE file.
 
@@ -33,7 +33,10 @@ const tests = [
 ];
 for (const [test, description = typeof test] of tests) {
   const plainDate = new Temporal.PlainDate(2000, 5, 2, new CustomCalendar(test));
-  assert.throws(TypeError, () => plainDate.until("2022-06-20"), `Expected error with ${description}`);
+  assert.throws(
+    TypeError, () => plainDate.until("2022-06-20", { largestUnit: "years" }),
+    `Expected error with ${description}`
+  );
 }
 
 reportCompare(0, 0);
