@@ -1,4 +1,4 @@
-// |reftest| skip -- Temporal is not supported
+// |reftest| skip-if(!this.hasOwnProperty('Temporal')) -- Temporal is not enabled unconditionally
 // Copyright (C) 2022 Igalia, S.L. All rights reserved.
 // This code is governed by the BSD license found in the LICENSE file.
 
@@ -15,7 +15,6 @@ const tests = [
   ["1976-11-18T15:23[!u-ca=iso8601]", "with ! and no time zone"],
   ["1976-11-18T15:23[UTC][!u-ca=iso8601]", "with ! and time zone"],
   ["1976-11-18T15:23[u-ca=iso8601][u-ca=discord]", "second annotation ignored"],
-  ["1976-11-18T15:23[u-ca=iso8601][!u-ca=discord]", "second annotation ignored even with !"],
 ];
 
 const instance = new Temporal.TimeZone("UTC");
