@@ -11,13 +11,11 @@ info: |
 includes: [propertyHelper.js]
 ---*/
 
-assert.sameValue(
-  WeakMap.prototype.set.length, 2,
-  'The value of `WeakMap.prototype.set.length` is `2`'
-);
-
-verifyNotEnumerable(WeakMap.prototype.set, 'length');
-verifyNotWritable(WeakMap.prototype.set, 'length');
-verifyConfigurable(WeakMap.prototype.set, 'length');
+verifyProperty(WeakMap.prototype.set, "length", {
+  value: 2,
+  writable: false,
+  enumerable: false,
+  configurable: true
+});
 
 reportCompare(0, 0);
