@@ -29,7 +29,7 @@ assert.sameValue(
 
 assert.throws(TypeError, () => {
   let ws = new WeakSet(); new ws.add({});
-}, '`let ws = new WeakSet(); new ws.add({})` throws TypeError');
+});
 
 
 reportCompare(0, 0);
