@@ -2,7 +2,7 @@
 // This code is governed by the license found in the LICENSE file.
 
 /*---
-es5id: 8.0_L15
+esid: intl-object
 description: >
     Tests that Intl meets the requirements for built-in objects
     defined by the introduction of chapter 17 of the ECMAScript
@@ -10,10 +10,6 @@ description: >
 author: Norbert Lindenberg
 ---*/
 
-assert.sameValue(Object.prototype.toString.call(Intl), "[object Object]",
-                 "The [[Class]] internal property of a built-in non-function object must be " +
-                 "\"Object\".");
-
 assert(Object.isExtensible(Intl), "Built-in objects must be extensible.");
 
 assert.sameValue(Object.getPrototypeOf(Intl), Object.prototype,
