@@ -2,15 +2,15 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 10.1.1-1-s
+es5id: 10.1.1-4-s
 description: >
-    Strict Mode - Use Strict Directive Prologue is 'use  strict';
-    which contains two space between 'use' and 'strict'
+    Strict Mode - Use Strict Directive Prologue is ''use strict ';'
+    which the last character is space
 flags: [noStrict]
 ---*/
 
 function testcase() {
-        "use  strict";
+        "use strict ";
         var public = 1;
 
         assert.sameValue(public, 1);
