@@ -7,7 +7,7 @@ description: >
     The left-hand side expression is evaluated before the right-hand side.
     Left-hand side expression is MemberExpression: base[prop]. Evaluating
     ToPropertyKey(prop) throws an error.
-    Check operator is "x >>= y".
+    Check operator is "x >>>= y".
 ---*/
 
 function DummyError() { }
@@ -23,7 +23,7 @@ assert.throws(DummyError, function() {
     throw new Test262Error("right-hand side expression evaluated");
   };
 
-  base[prop] >>= expr();
+  base[prop] >>>= expr();
 });
 
 reportCompare(0, 0);
