@@ -6,14 +6,17 @@ info: |
     This test is actually testing the [[Delete]] internal method (8.12.8). Since the
     language provides no way to directly exercise [[Delete]], the tests are placed here.
 esid: sec-delete-operator-runtime-semantics-evaluation
-description: delete operator inside 'eval'
+description: >
+    delete operator returns true on deleting arguments
+    properties(arguments.callee)
 flags: [noStrict]
 ---*/
 
-var x = 1;
-var d = eval('delete x');
+(function() {
+  var d = delete arguments.callee;
 
-assert.sameValue(d, false, 'd');
-assert.sameValue(x, 1, 'x');
+  assert.sameValue(d, true, 'd');
+  assert.sameValue(arguments.callee, undefined, 'arguments.callee');
+})();
 
 reportCompare(0, 0);
