@@ -3,17 +3,15 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 10.4.3-1-9gs
+es5id: 10.4.3-1-15gs
 description: >
-    Strict - checking 'this' from a global scope (FunctionExpression
-    defined within strict mode)
+    Strict - checking 'this' from a global scope (New'ed Function
+    constructor defined within strict mode)
 flags: [onlyStrict]
 ---*/
 
-var f = function () {
-    return typeof this;
-}
-if (f() !== "undefined") {
+var f = new Function("return typeof this;");
+if (f() === "undefined") {
     throw "'this' had incorrect value!";
 }
 
