@@ -18,17 +18,17 @@ info: |
     SourceCharacter but not LineTerminator
 
 description: >
-  A regular expression may not contain a <PS> as a SourceCharacter, evaluated
-
+  The first character of a regular expression may not be a <LS>, (\u2028), evaluated
 ---*/
 
+//CHECK#1
 try {
-   eval("/s\u2029/").source;
-   $ERROR('#1.1: RegularExpressionChar :: Paragraph separator is incorrect. Actual: ' + (eval("/s\u2029/").source));
+   eval("/\u2029/").source;
+   throw new Test262Error('#1.1: RegularExpressionFirstChar :: Paragraph separator is incorrect. Actual: ' + (eval("/\u2029/").source));
 }
 catch (e) {
   if ((e instanceof SyntaxError) !== true) {
-     $ERROR('#1.2: RegularExpressionChar :: Paragraph separator is incorrect. Actual: ' + (e));
+     throw new Test262Error('#1.2: RegularExpressionFirstChar :: Paragraph separator is incorrect. Actual: ' + (e));
   }
 }
 
