@@ -28,7 +28,7 @@ SDL2_VERSION="SDL2-2.24.0"
 # NOTE: remember to also update LIB_URL below when changing version
 BOOST_VERSION="boost_1_81_0"
 # NOTE: remember to also update LIB_URL below when changing version
-WXWIDGETS_VERSION="wxWidgets-3.1.4"
+WXWIDGETS_VERSION="wxWidgets-3.2.8"
 # libpng was included as part of X11 but that's removed from Mountain Lion
 # (also the Snow Leopard version was ancient 1.2)
 PNG_VERSION="libpng-1.6.44"
@@ -48,7 +48,8 @@ ENET_VERSION="enet-1.3.18"
 MINIUPNPC_VERSION="miniupnpc-2.2.8"
 SODIUM_VERSION="libsodium-1.0.20"
 FMT_VERSION="7.1.3"
-MOLTENVK_VERSION="1.2.2"
+MOLTENVK_VERSION="1.3.0"
+OPENAL_SOFT_VERSION="1.24.2"
 # --------------------------------------------------------------
 # Bundled with the game:
 # * SpiderMonkey
@@ -57,12 +58,11 @@ MOLTENVK_VERSION="1.2.2"
 # --------------------------------------------------------------
 # --------------------------------------------------------------
 # Provided by OS X:
-# * OpenAL
 # * OpenGL
 # --------------------------------------------------------------
 
 export CC="${CC:="clang"}" CXX="${CXX:="clang++"}"
-export MIN_OSX_VERSION="${MIN_OSX_VERSION:="10.12"}"
+export MIN_OSX_VERSION="${MIN_OSX_VERSION:="10.15"}"
 export ARCH="${ARCH:=""}"
 
 # The various libs offer inconsistent configure options, some allow
@@ -183,6 +183,7 @@ if [ $force_rebuild = "true" ]; then
 	rm -rf "$PC_PATH"
 fi
 mkdir -p "$PC_PATH"
+export PKG_CONFIG_PATH="${PKG_CONFIG_PATH}:${PC_PATH}"
 
 echo "Building third-party dependencies..."
 # --------------------------------------------------------------
@@ -476,7 +477,7 @@ echo "Building wxWidgets..."
 	LIB_VERSION="${WXWIDGETS_VERSION}"
 	LIB_ARCHIVE="$LIB_VERSION.tar.bz2"
 	LIB_DIRECTORY="$LIB_VERSION"
-	LIB_URL="http://github.com/wxWidgets/wxWidgets/releases/download/v3.1.4/"
+	LIB_URL="http://github.com/wxWidgets/wxWidgets/releases/download/v3.2.8/"
 
 	mkdir -p wxwidgets
 	cd wxwidgets
@@ -497,6 +498,7 @@ echo "Building wxWidgets..."
 			CONF_OPTS="
 				--prefix=$INSTALL_DIR
 				--disable-shared
+				--disable-sys-libs
 				--enable-unicode
 				--with-cocoa
 				--with-opengl
@@ -509,7 +511,6 @@ echo "Building wxWidgets..."
 				--without-x
 				--disable-stc
 				--disable-webview
-				--disable-webkit
 				--disable-webviewwebkit
 				--disable-webviewie
 				--without-libjpeg"
@@ -645,6 +646,7 @@ OGG_DIR="$(pwd)/libogg"
 			-S $LIB_DIRECTORY \
 			-G "Unix Makefiles" \
 			-DCMAKE_INSTALL_PREFIX="$OGG_DIR" \
+			-DCMAKE_POLICY_VERSION_MINIMUM=3.5 \
 			-DBUILD_SHARED_LIBS=OFF \
 			-DINSTALL_DOCS=OFF \
 			-DCMAKE_C_FLAGS="$CFLAGS" \
@@ -685,6 +687,7 @@ echo "Building libvorbis..."
 			-G "Unix Makefiles" \
 			-DCMAKE_INSTALL_PREFIX="$INSTALL_DIR" \
 			-DCMAKE_PREFIX_PATH="$OGG_DIR" \
+			-DCMAKE_POLICY_VERSION_MINIMUM=3.5 \
 			-DBUILD_SHARED_LIBS=OFF \
 			-DINSTALL_DOCS=OFF \
 			-DCMAKE_C_FLAGS="$CFLAGS" \
@@ -1102,6 +1105,44 @@ echo "Building libsodium..."
 	fi
 ) || die "Failed to build libsodium"
 
+echo "Building OpenAL Soft"
+(
+	LIB_DIRECTORY="openal-soft-$OPENAL_SOFT_VERSION"
+	LIB_ARCHIVE="$OPENAL_SOFT_VERSION.tar.gz"
+	LIB_URL="https://github.com/kcat/openal-soft/archive/refs/tags/"
+
+	mkdir -p openal-soft
+	cd openal-soft
+
+	if [ $force_rebuild = "true" ] || [ ! -e .already-built ] || [ "$(cat .already-built)" != "$OPENAL_SOFT_VERSION" ]; then
+		INSTALL_DIR="$(pwd)"
+
+		rm -f .already-built
+		download_lib $LIB_URL $LIB_ARCHIVE || die
+
+		rm -rf $LIB_DIRECTORY include lib share libopenal-soft
+		tar -xf $LIB_ARCHIVE || die
+
+		# shellcheck disable=SC2086
+		cmake -B libopenal-soft \
+			-S $LIB_DIRECTORY \
+			-DCMAKE_C_FLAGS="$CFLAGS" \
+			-DLIBTYPE=STATIC \
+			-DALSOFT_EXAMPLES=OFF \
+			-DALSOFT_UTILS=OFF \
+			-DALSOFT_TESTS=OFF \
+			-G "Unix Makefiles" \
+			-DCMAKE_INSTALL_PREFIX="$INSTALL_DIR" \
+			$CMAKE_FLAGS || die
+		cmake --build libopenal-soft "${JOBS}" --target install || die
+
+		cp -f lib/pkgconfig/* "$PC_PATH"
+		echo "$OPENAL_SOFT_VERSION" >.already-built
+	else
+		already_built
+	fi
+) || die "Failed to build OpenAL Soft"
+
 # --------------------------------------------------------------
 echo "Building fmt..."
 
@@ -1146,8 +1187,8 @@ echo "Building Molten VK..."
 
 (
 	LIB_DIRECTORY="MoltenVK-$MOLTENVK_VERSION"
-	LIB_ARCHIVE="MoltenVK-$MOLTENVK_VERSION.tar.gz"
-	LIB_URL="https://releases.wildfiregames.com/libs/"
+	LIB_ARCHIVE="v$MOLTENVK_VERSION.tar.gz"
+	LIB_URL="https://github.com/KhronosGroup/MoltenVK/archive/refs/tags/"
 
 	mkdir -p "molten-vk"
 	cd "molten-vk"
@@ -1161,10 +1202,25 @@ echo "Building Molten VK..."
 		rm -rf "$LIB_DIRECTORY"
 		tar -xf $LIB_ARCHIVE || die
 
-		# The CI cannot build MoltenVK so we provide prebuild binaries instead.
-		# Use mv instead of copy to preserve binary signature integrity. See:
-		# https://developer.apple.com/forums/thread/130313?answerId=410541022#410541022
-		mv $LIB_DIRECTORY/dylib/libMoltenVK.dylib $INSTALL_DIR || die
+		(
+			cd "$LIB_DIRECTORY"
+			# dont use --parallel-build, it breaks the build since it calls kill.
+			MACOSX_DEPLOYMENT_TARGET="$MIN_OSX_VERSION" CFLAGS="$CFLAGS" LDFLAGS="$LDFLAGS" ./fetchDependencies --macos || die
+
+			xcodebuild \
+				-quiet \
+				-project MoltenVKPackaging.xcodeproj \
+				-scheme "MoltenVK Package (macOS only)" \
+				-destination "generic/platform=macOS" \
+				MACOSX_DEPLOYMENT_TARGET="$MIN_OSX_VERSION" \
+				CFLAGS="$CFLAGS" \
+				CXXFLAGS="$CXXFLAGS" \
+				LDFLAGS="$LDFLAGS" \
+				ARCHS="arm64 x86_64" || die
+		) || die
+
+		# We don't use the provided install command, because we haven't got enough permissions to use it.
+		mv $LIB_DIRECTORY/Package/Latest/MoltenVK/dylib/macOS/libMoltenVK.dylib $INSTALL_DIR || die
 
 		echo "$MOLTENVK_VERSION" >.already-built
 	else
