@@ -6,13 +6,27 @@ set -e
 cd "$(dirname "$0")"
 
 PV=28209
-LIB_VERSION=${PV}+wfg1
+LIB_VERSION=${PV}+wfg4
 
 fetch()
 {
+	tar_version=$(tar --version | head --lines 1)
+	case "${tar_version}" in
+		*"GNU tar"*)
+			tar_extra_opts="--owner root --group root"
+			;;
+		*"libarchive"*)
+			tar_extra_opts="--uname root --gname root"
+			;;
+		*)
+			echo "unknown tar implementation ${tar_version}"
+			;;
+	esac
+
 	rm -Rf nvtt-${PV}
 	svn export https://svn.wildfiregames.com/public/source-libs/trunk/nvtt@${PV} nvtt-${PV}
-	"${TAR}" cJf nvtt-${PV}.tar.xz nvtt-${PV}
+	# shellcheck disable=SC2086
+	"${TAR}" -c ${tar_extra_opts} -Jf nvtt-${PV}.tar.xz nvtt-${PV}
 	rm -R nvtt-${PV}
 }
 
@@ -50,6 +64,9 @@ rm -Rf nvtt-${PV}
 patch -d nvtt-${PV} -p1 <patches/0001-Don-t-overspecify-flags.patch
 patch -d nvtt-${PV} -p1 <patches/0002-Bump-cmake-min-version-to-3.10.patch
 patch -d nvtt-${PV} -p1 <patches/0003-Use-execute_process-insted-of-exec_program.patch
+patch -d nvtt-${PV} -p1 <patches/0004-Properly-detect-ppc64le-systems.patch
+patch -d nvtt-${PV} -p1 <patches/0005-Fix-compiler-flags-on-ppc64le-systems.patch
+patch -d nvtt-${PV} -p1 <patches/0006-Fix-altivec-include-on-ppc64le-systems.patch
 
 # build
 (
