@@ -6,10 +6,25 @@ set -e
 cd "$(dirname "$0")"
 
 # This should match the version in config/milestone.txt
-FOLDER="mozjs-115.16.1"
+PV=128.13.0
+FOLDER="mozjs-${PV}"
 # If same-version changes are needed, increment this.
-LIB_VERSION="115.16.1+a27.1"
-LIB_NAME="mozjs115"
+LIB_VERSION="${PV}+wfg4"
+LIB_NAME="mozjs128"
+
+build_archive()
+{
+	if [ ! -e "firefox-${PV}esr.source.tar.xz" ]; then
+		curl -fLo "firefox-${PV}esr.source.tar.xz" \
+			"https://archive.mozilla.org/pub/firefox/releases/${PV}esr/source/firefox-${PV}esr.source.tar.xz"
+	fi
+
+	rm -Rf firefox-${PV}
+	rm -Rf mozjs-${PV}.tar.xz
+	${TAR} -xJf firefox-${PV}esr.source.tar.xz
+
+	DIST="$(realpath .)" STAGING="$(realpath .)/firefox-${PV}/mozjs-src-pkg" firefox-${PV}/js/src/make-source-package.py build
+}
 
 fetch()
 {
@@ -17,9 +32,12 @@ fetch()
 		"https://releases.wildfiregames.com/libs/${FOLDER}.tar.xz"
 }
 
-echo "Building SpiderMonkey..."
 while [ "$#" -gt 0 ]; do
 	case "$1" in
+		--build-archive)
+			build_archive
+			exit
+			;;
 		--fetch-only)
 			fetch
 			exit
@@ -33,6 +51,8 @@ while [ "$#" -gt 0 ]; do
 	shift
 done
 
+echo "Building SpiderMonkey..."
+
 if [ -e .already-built ] && [ "$(cat .already-built || true)" = "${LIB_VERSION}" ]; then
 	echo "Skipping - already built (use --force-rebuild to override)"
 	exit
@@ -44,25 +64,23 @@ OS="${OS:=$(uname -s)}"
 # This tarball is built from https://ftp.mozilla.org/pub/firefox/releases/115.16.1esr/source/
 # by running js/src/make-source-package.py
 if [ ! -e "${FOLDER}.tar.xz" ]; then
-	fetch
+	fetch || build_archive
 fi
 
 # unpack
 rm -Rf "${FOLDER}"
-"${TAR}" xfJ "${FOLDER}.tar.xz"
+"${TAR}" xfJ "${FOLDER}.tar.xz" \
+	--exclude=js/src/tests/non262 \
+	--exclude=js/src/tests/test262 \
+	--exclude=js/src/jit-test \
+	--exclude=python/mozperftest \
+	--exclude=testing/web-platform \
+	--exclude=third_party/rust/mp4parse/link-u-avif-sample-images
 
 # patch
 (
 	cd "${FOLDER}"
 
-	# Fix build on recent macOS versions.
-	# https://bugzilla.mozilla.org/show_bug.cgi?id=1844694
-	# The --enable-bootstrap fix mentioned on the ticket does not fix the issue. Instead,
-	# use Homebrew's workaround.
-	if [ "${OS}" = "Darwin" ]; then
-		sed -i '' 's/\["-Wl,--version"]/["-Wl,-ld_classic,--version"]/g' build/moz.configure/toolchain.configure
-	fi
-
 	# shellcheck disable=SC1091
 	. ../patches/patch.sh
 )
@@ -83,11 +101,16 @@ rm -Rf "${FOLDER}"
 	export MOZBUILD_STATE_PATH="${MOZBUILD_STATE_PATH:=$(pwd)/mozbuild-state}"
 
 	if [ -n "$PROFILE" ]; then
-		CONF_OPTS="$CONF_OPTS --enable-profiling
-		                      --enable-perf
-		                      --enable-instruments
-		                      --enable-jitspew
-		                      --with-jitreport-granularity=3"
+		CONF_OPTS="$CONF_OPTS
+			--enable-profiling
+			--enable-perf
+			--enable-jitspew
+			--with-jitreport-granularity=3"
+
+		if [ "${OS}" = "Darwin" ]; then
+			CONF_OPTS="$CONF_OPTS
+				--enable-instruments"
+		fi
 	fi
 
 	if [ "${OS}" = "Windows_NT" ]; then
@@ -103,8 +126,7 @@ rm -Rf "${FOLDER}"
 		fi
 		CONF_OPTS="${CONF_OPTS} --target=$ARCH-apple-darwin"
 
-		# Link to custom-built zlib
-		export PKG_CONFIG_PATH="=${ZLIB_DIR}:${PKG_CONFIG_PATH}"
+		# This needs PKG_CONFIG_PATH to be exported in build-macos-libs.sh
 		CONF_OPTS="${CONF_OPTS} --with-system-zlib"
 		# Specify target versions and SDK
 		if [ "${MIN_OSX_VERSION}" ] && [ "${MIN_OSX_VERSION-_}" ]; then
@@ -130,20 +152,22 @@ rm -Rf "${FOLDER}"
 	# Build
 	# Debug (broken on FreeBSD)
 	if [ "${OS}" != "FreeBSD" ]; then
+		# shellcheck disable=SC2086
 		MOZCONFIG="$(pwd)/../mozconfig" \
 		MOZCONFIG_OPTIONS="${CONF_OPTS} \
 			--enable-debug \
 			--disable-optimize \
 			--enable-gczeal" \
 		BUILD_DIR="build-debug" \
-			./mach build "${JOBS}"
+			./mach build ${JOBS}
 	fi
 	# Release
+	# shellcheck disable=SC2086
 	MOZCONFIG="$(pwd)/../mozconfig" \
 	MOZCONFIG_OPTIONS="${CONF_OPTS} \
 		--enable-optimize" \
 	BUILD_DIR="build-release" \
-		./mach build "${JOBS}"
+		./mach build ${JOBS}
 )
 
 # install
@@ -178,12 +202,6 @@ if [ "${OS}" = "Windows_NT" ]; then
 		cd "${FOLDER}"/build-release/dist/include
 		rm -f mozzconf.h zconf.h zlib.h
 	)
-
-	# SpiderMonkey can be linked/included in projects built with MSVC, however, since clang is now the only
-	# supported compiler on Windows, the codebase has accumulated some divergences with MSVC.
-	# Upstream tries on a best-effort basis to keep the SM headers MSVC-compatible.
-	patch -d "${FOLDER}"/build-debug/dist/include -p1 <patches/FixHeadersForMSVC.diff
-	patch -d "${FOLDER}"/build-release/dist/include -p1 <patches/FixHeadersForMSVC.diff
 fi
 
 # js-config.h is different for debug and release builds, so we need different include directories for both
@@ -200,7 +218,7 @@ DEB="debug"
 REL="release"
 
 # Fetch the jsrust static library. Path is grepped from the build file as it varies by rust toolset.
-rust_path=$(grep jsrust <"${FOLDER}/build-release/js/src/build/backend.mk" | cut -d = -f 2 | cut -c2-)
+rust_path="${FOLDER}/build-release/$(grep jsrust "${FOLDER}/build-release/js/src/build/backend.mk" | cut -d / -f 2-)"
 cp -L "${rust_path}" "lib/${LIB_PREFIX}${LIB_NAME}-rust${STATIC_LIB_SUFFIX}"
 
 if [ "${OS}" = "Darwin" ]; then
@@ -209,21 +227,21 @@ if [ "${OS}" = "Darwin" ]; then
 	cp -L "${FOLDER}/build-${REL}/js/src/build/${LIB_PREFIX}js_static${LIB_SUFFIX}" "lib/${LIB_PREFIX}${LIB_NAME}-${REL}${LIB_SUFFIX}"
 elif [ "${OS}" = "Windows_NT" ]; then
 	# Windows needs DLLs to binaries/, static stubs to lib/ and debug symbols
-	cp -L "${FOLDER}/build-${DEB}/js/src/build/${LIB_PREFIX}${LIB_NAME}-${DEB}${LIB_SUFFIX}" "bin/${LIB_PREFIX}${LIB_NAME}-${DEB}${LIB_SUFFIX}"
-	cp -L "${FOLDER}/build-${REL}/js/src/build/${LIB_PREFIX}${LIB_NAME}-${REL}${LIB_SUFFIX}" "bin/${LIB_PREFIX}${LIB_NAME}-${REL}${LIB_SUFFIX}"
+	cp -L "${FOLDER}/build-${DEB}/dist/bin/${LIB_PREFIX}${LIB_NAME}-${DEB}${LIB_SUFFIX}" "bin/${LIB_PREFIX}${LIB_NAME}-${DEB}${LIB_SUFFIX}"
+	cp -L "${FOLDER}/build-${REL}/dist/bin/${LIB_PREFIX}${LIB_NAME}-${REL}${LIB_SUFFIX}" "bin/${LIB_PREFIX}${LIB_NAME}-${REL}${LIB_SUFFIX}"
 	cp -L "${FOLDER}/build-${DEB}/js/src/build/${LIB_PREFIX}${LIB_NAME}-${DEB}${STATIC_LIB_SUFFIX}" "lib/${LIB_PREFIX}${LIB_NAME}-${DEB}${STATIC_LIB_SUFFIX}"
 	cp -L "${FOLDER}/build-${REL}/js/src/build/${LIB_PREFIX}${LIB_NAME}-${REL}${STATIC_LIB_SUFFIX}" "lib/${LIB_PREFIX}${LIB_NAME}-${REL}${STATIC_LIB_SUFFIX}"
 	# Copy debug symbols as well.
 	cp -L "${FOLDER}/build-${DEB}/js/src/build/${LIB_PREFIX}${LIB_NAME}-${DEB}.pdb" "bin/${LIB_PREFIX}${LIB_NAME}-${DEB}.pdb"
 	cp -L "${FOLDER}/build-${REL}/js/src/build/${LIB_PREFIX}${LIB_NAME}-${REL}.pdb" "bin/${LIB_PREFIX}${LIB_NAME}-${REL}.pdb"
 	# Copy the debug jsrust library.
-	rust_path=$(grep jsrust <"${FOLDER}/build-debug/js/src/build/backend.mk" | cut -d = -f 2 | cut -c2-)
+	rust_path="${FOLDER}/build-debug/$(grep jsrust "${FOLDER}/build-debug/js/src/build/backend.mk" | cut -d / -f 2-)"
 	cp -L "${rust_path}" "lib/${LIB_PREFIX}${LIB_NAME}-rust-debug${STATIC_LIB_SUFFIX}"
 else
 	# Copy shared libs to lib/, they will also be copied to binaries/system, so the compiler and executable (resp.) can find them.
-	cp -L "${FOLDER}/build-${REL}/js/src/build/${LIB_PREFIX}${LIB_NAME}-${REL}${LIB_SUFFIX}" "lib/${LIB_PREFIX}${LIB_NAME}-${REL}${LIB_SUFFIX}"
+	cp -L "${FOLDER}/build-${REL}/dist/bin/${LIB_PREFIX}${LIB_NAME}-${REL}${LIB_SUFFIX}" "lib/${LIB_PREFIX}${LIB_NAME}-${REL}${LIB_SUFFIX}"
 	if [ "${OS}" != "FreeBSD" ]; then
-		cp -L "${FOLDER}/build-${DEB}/js/src/build/${LIB_PREFIX}${LIB_NAME}-${DEB}${LIB_SUFFIX}" "lib/${LIB_PREFIX}${LIB_NAME}-${DEB}${LIB_SUFFIX}"
+		cp -L "${FOLDER}/build-${DEB}/dist/bin/${LIB_PREFIX}${LIB_NAME}-${DEB}${LIB_SUFFIX}" "lib/${LIB_PREFIX}${LIB_NAME}-${DEB}${LIB_SUFFIX}"
 	fi
 fi
 
