@@ -391,6 +391,15 @@ class Linkable(ContextDerived):
         self.lib_defines = Defines(context, OrderedDict())
         self.sources = defaultdict(list)
 
+    @property
+    def output_path(self):
+        if self.installed:
+            return ObjDirPath(
+                self._context, "!/" + mozpath.join(self.install_target, self.name)
+            )
+        else:
+            return ObjDirPath(self._context, "!" + self.name)
+
     def link_library(self, obj):
         assert isinstance(obj, BaseLibrary)
         if obj.KIND != self.KIND:
@@ -481,15 +490,6 @@ class BaseProgram(Linkable):
         self.program = program
         self.is_unit_test = is_unit_test
 
-    @property
-    def output_path(self):
-        if self.installed:
-            return ObjDirPath(
-                self._context, "!/" + mozpath.join(self.install_target, self.program)
-            )
-        else:
-            return ObjDirPath(self._context, "!" + self.program)
-
     def __repr__(self):
         return "<%s: %s/%s>" % (type(self).__name__, self.relobjdir, self.program)
 
@@ -561,9 +561,9 @@ def cargo_output_directory(context, target_var):
     return mozpath.join(context.config.substs[target_var], rust_build_kind)
 
 
-# Rust programs aren't really Linkable, since Cargo handles all the details
-# of linking things.
-class BaseRustProgram(ContextDerived):
+# We pretend Rust programs are Linkable, despite Cargo handling all the details
+# of linking things. This is used to declare in-tree dependencies.
+class BaseRustProgram(Linkable):
     __slots__ = (
         "name",
         "cargo_file",
@@ -574,7 +574,7 @@ class BaseRustProgram(ContextDerived):
     )
 
     def __init__(self, context, name, cargo_file):
-        ContextDerived.__init__(self, context)
+        Linkable.__init__(self, context)
         self.name = name
         self.cargo_file = cargo_file
         # Skip setting properties below which depend on cargo
@@ -637,6 +637,10 @@ class BaseLibrary(Linkable):
     def name(self):
         return self.lib_name
 
+    @property
+    def import_path(self):
+        return ObjDirPath(self._context, "!" + self.import_name)
+
 
 class Library(BaseLibrary):
     """Context derived container object for a library"""
@@ -692,7 +696,6 @@ class BaseRustLibrary(object):
         "cargo_file",
         "crate_type",
         "dependencies",
-        "deps_path",
         "features",
         "output_category",
         "is_gkrust",
@@ -731,15 +734,21 @@ class BaseRustLibrary(object):
         # build in that case.
         if not context.config.substs.get("COMPILE_ENVIRONMENT"):
             return
-        build_dir = mozpath.join(
-            context.config.topobjdir,
-            cargo_output_directory(context, self.TARGET_SUBST_VAR),
+        self.import_name = self.lib_name
+
+    @property
+    def import_path(self):
+        return ObjDirPath(
+            self._context,
+            "!/"
+            + mozpath.join(
+                cargo_output_directory(self._context, self.TARGET_SUBST_VAR),
+                self.import_name,
+            ),
         )
-        self.import_name = mozpath.join(build_dir, self.lib_name)
-        self.deps_path = mozpath.join(build_dir, "deps")
 
 
-class RustLibrary(StaticLibrary, BaseRustLibrary):
+class RustLibrary(BaseRustLibrary, StaticLibrary):
     """Context derived container object for a rust static library"""
 
     KIND = "target"
@@ -866,13 +875,22 @@ class SharedLibrary(Library):
                     + self.symbols_file
                 )
             elif os_target == "WINNT":
-                if context.config.substs.get("GNU_CC"):
-                    self.symbols_link_arg = self.symbols_file
-                else:
+                if context.config.substs.get("CC_TYPE") == "clang-cl":
                     self.symbols_link_arg = "-DEF:" + self.symbols_file
+                else:
+                    self.symbols_link_arg = self.symbols_file
             elif context.config.substs.get("GCC_USE_GNU_LD"):
                 self.symbols_link_arg = "-Wl,--version-script," + self.symbols_file
 
+    @property
+    def import_path(self):
+        if self.config.substs.get("OS_ARCH") == "WINNT":
+            # We build import libs on windows in a library's objdir
+            # to avoid cluttering up dist/bin.
+            return ObjDirPath(self._context, "!" + self.import_name)
+        assert self.import_name == self.name
+        return self.output_path
+
 
 class HostSharedLibrary(HostMixin, Library):
     """Context derived container object for a host shared library.
@@ -913,7 +931,7 @@ class HostLibrary(HostMixin, BaseLibrary):
     no_expand_lib = False
 
 
-class HostRustLibrary(HostLibrary, BaseRustLibrary):
+class HostRustLibrary(BaseRustLibrary, HostLibrary):
     """Context derived container object for a host rust library"""
 
     KIND = "host"
