@@ -18,12 +18,12 @@ class JSONFormatter(object):
 
 
 all_formatters = {
-    'compact': CompactFormatter,
-    'json': JSONFormatter,
-    'stylish': StylishFormatter,
-    'summary': SummaryFormatter,
-    'treeherder': TreeherderFormatter,
-    'unix': UnixFormatter,
+    "compact": CompactFormatter,
+    "json": JSONFormatter,
+    "stylish": StylishFormatter,
+    "summary": SummaryFormatter,
+    "treeherder": TreeherderFormatter,
+    "unix": UnixFormatter,
 }
 
 
