@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,21 +19,20 @@
 
 #include "CameraController.h"
 
-#include "graphics/HFTracer.h"
+#include "graphics/Camera.h"
 #include "graphics/Terrain.h"
-#include "i18n/L10n.h"
+#include "lib/external_libraries/libsdl.h"
 #include "lib/input.h"
-#include "lib/timer.h"
 #include "maths/MathUtil.h"
 #include "maths/Matrix3D.h"
 #include "maths/Quaternion.h"
+#include "maths/Vector3D.h"
 #include "ps/CLogger.h"
+#include "ps/CStr.h"
 #include "ps/ConfigDB.h"
 #include "ps/Game.h"
 #include "ps/Globals.h"
 #include "ps/Hotkey.h"
-#include "ps/Pyrogenesis.h"
-#include "ps/TouchInput.h"
 #include "ps/World.h"
 #include "renderer/Renderer.h"
 #include "renderer/SceneRenderer.h"
@@ -41,7 +40,12 @@
 #include "simulation2/Simulation2.h"
 #include "simulation2/components/ICmpPosition.h"
 #include "simulation2/components/ICmpRangeManager.h"
-#include "simulation2/helpers/Los.h"
+#include "simulation2/system/Component.h"
+
+#include <algorithm>
+#include <cmath>
+#include <functional>
+#include <string>
 
 extern int g_xres, g_yres;
 
@@ -54,6 +58,7 @@ CCameraController::CCameraController(CCamera& camera)
 	  m_ConstrainCamera(true),
 	  m_FollowEntity(INVALID_ENTITY),
 	  m_FollowFirstPerson(false),
+	  m_BirdsEyeView(false),
 
 	  // Dummy values (these will be filled in by the config file)
 	  m_ViewScrollSpeed(0),
@@ -68,6 +73,7 @@ CCameraController::CCameraController(CCamera& camera)
 	  m_ViewRotateYDefault(0),
 	  m_ViewRotateSpeedModifier(1),
 	  m_ViewDragSpeed(0),
+	  m_ViewDragInverted(false),
 	  m_ViewZoomSpeed(0),
 	  m_ViewZoomSpeedWheel(0),
 	  m_ViewZoomMin(0),
@@ -87,6 +93,15 @@ CCameraController::CCameraController(CCamera& camera)
 	  m_RotateX(0, 0, 0.001f),
 	  m_RotateY(0, 0, 0.001f)
 {
+	m_ViewDragInvertedConfigHook =
+		std::make_unique<CConfigDBHook>(g_ConfigDB.RegisterHookAndCall("view.drag.inverted", [this]() {
+			m_ViewDragInverted = g_ConfigDB.Get("view.drag.inverted", m_ViewDragInverted);
+		}));
+	m_ViewDragSpeedConfigHook =
+		std::make_unique<CConfigDBHook>(g_ConfigDB.RegisterHookAndCall("view.drag.speed", [this]() {
+			m_ViewDragSpeed = g_ConfigDB.Get("view.drag.speed", m_ViewDragSpeed);
+		}));
+
 	SViewPort vp;
 	vp.m_X = 0;
 	vp.m_Y = 0;
@@ -103,34 +118,33 @@ CCameraController::~CCameraController() = default;
 
 void CCameraController::LoadConfig()
 {
-	CFG_GET_VAL("view.scroll.speed", m_ViewScrollSpeed);
-	CFG_GET_VAL("view.scroll.speed.modifier", m_ViewScrollSpeedModifier);
-	CFG_GET_VAL("view.scroll.mouse.detectdistance", m_ViewScrollMouseDetectDistance);
-	CFG_GET_VAL("view.rotate.x.speed", m_ViewRotateXSpeed);
-	CFG_GET_VAL("view.rotate.x.min", m_ViewRotateXMin);
-	CFG_GET_VAL("view.rotate.x.max", m_ViewRotateXMax);
-	CFG_GET_VAL("view.rotate.x.default", m_ViewRotateXDefault);
-	CFG_GET_VAL("view.rotate.y.speed", m_ViewRotateYSpeed);
-	CFG_GET_VAL("view.rotate.y.speed.wheel", m_ViewRotateYSpeedWheel);
-	CFG_GET_VAL("view.rotate.y.default", m_ViewRotateYDefault);
-	CFG_GET_VAL("view.rotate.speed.modifier", m_ViewRotateSpeedModifier);
-	CFG_GET_VAL("view.drag.speed", m_ViewDragSpeed);
-	CFG_GET_VAL("view.zoom.speed", m_ViewZoomSpeed);
-	CFG_GET_VAL("view.zoom.speed.wheel", m_ViewZoomSpeedWheel);
-	CFG_GET_VAL("view.zoom.min", m_ViewZoomMin);
-	CFG_GET_VAL("view.zoom.max", m_ViewZoomMax);
-	CFG_GET_VAL("view.zoom.default", m_ViewZoomDefault);
-	CFG_GET_VAL("view.zoom.speed.modifier", m_ViewZoomSpeedModifier);
+	m_ViewScrollSpeed = g_ConfigDB.Get("view.scroll.speed", m_ViewScrollSpeed);
+	m_ViewScrollSpeedModifier = g_ConfigDB.Get("view.scroll.speed.modifier", m_ViewScrollSpeedModifier);
+	m_ViewScrollMouseDetectDistance = g_ConfigDB.Get("view.scroll.mouse.detectdistance",
+		m_ViewScrollMouseDetectDistance);
+	m_ViewRotateXSpeed = g_ConfigDB.Get("view.rotate.x.speed", m_ViewRotateXSpeed);
+	m_ViewRotateXMin = g_ConfigDB.Get("view.rotate.x.min", m_ViewRotateXMin);
+	m_ViewRotateXMax = g_ConfigDB.Get("view.rotate.x.max", m_ViewRotateXMax);
+	m_ViewRotateXDefault = g_ConfigDB.Get("view.rotate.x.default", m_ViewRotateXDefault);
+	m_ViewRotateYSpeed = g_ConfigDB.Get("view.rotate.y.speed", m_ViewRotateYSpeed);
+	m_ViewRotateYSpeedWheel = g_ConfigDB.Get("view.rotate.y.speed.wheel", m_ViewRotateYSpeedWheel);
+	m_ViewRotateYDefault = g_ConfigDB.Get("view.rotate.y.default", m_ViewRotateYDefault);
+	m_ViewRotateSpeedModifier = g_ConfigDB.Get("view.rotate.speed.modifier", m_ViewRotateSpeedModifier);
+	m_ViewDragSpeed = g_ConfigDB.Get("view.drag.speed", m_ViewDragSpeed);
+	m_ViewDragInverted = g_ConfigDB.Get("view.drag.inverted", m_ViewDragInverted);
+	m_ViewZoomSpeed = g_ConfigDB.Get("view.zoom.speed", m_ViewZoomSpeed);
+	m_ViewZoomSpeedWheel = g_ConfigDB.Get("view.zoom.speed.wheel", m_ViewZoomSpeedWheel);
+	m_ViewZoomMin = g_ConfigDB.Get("view.zoom.min", m_ViewZoomMin);
+	m_ViewZoomMax = g_ConfigDB.Get("view.zoom.max", m_ViewZoomMax);
+	m_ViewZoomDefault = g_ConfigDB.Get("view.zoom.default", m_ViewZoomDefault);
+	m_ViewZoomSpeedModifier = g_ConfigDB.Get("view.zoom.speed.modifier", m_ViewZoomSpeedModifier);
 
-	CFG_GET_VAL("view.height.smoothness", m_HeightSmoothness);
-	CFG_GET_VAL("view.height.min", m_HeightMin);
+	m_HeightSmoothness = g_ConfigDB.Get("view.height.smoothness", m_HeightSmoothness);
+	m_HeightMin = g_ConfigDB.Get("view.height.min", m_HeightMin);
 
 #define SETUP_SMOOTHNESS(CFG_PREFIX, SMOOTHED_VALUE) \
-	{ \
-		float smoothness = SMOOTHED_VALUE.GetSmoothness(); \
-		CFG_GET_VAL(CFG_PREFIX ".smoothness", smoothness); \
-		SMOOTHED_VALUE.SetSmoothness(smoothness); \
-	}
+	SMOOTHED_VALUE.SetSmoothness( \
+		g_ConfigDB.Get(CFG_PREFIX ".smoothness", SMOOTHED_VALUE.GetSmoothness()));
 
 	SETUP_SMOOTHNESS("view.pos", m_PosX);
 	SETUP_SMOOTHNESS("view.pos", m_PosY);
@@ -140,9 +154,9 @@ void CCameraController::LoadConfig()
 	SETUP_SMOOTHNESS("view.rotate.y", m_RotateY);
 #undef SETUP_SMOOTHNESS
 
-	CFG_GET_VAL("view.near", m_ViewNear);
-	CFG_GET_VAL("view.far", m_ViewFar);
-	CFG_GET_VAL("view.fov", m_ViewFOV);
+	m_ViewNear = g_ConfigDB.Get("view.near", m_ViewNear);
+	m_ViewFar = g_ConfigDB.Get("view.far", m_ViewFar);
+	m_ViewFOV = g_ConfigDB.Get("view.fov", m_ViewFOV);
 
 	// Convert to radians
 	m_RotateX.SetValue(DEGTORAD(m_ViewRotateXDefault));
@@ -170,9 +184,9 @@ void CCameraController::Update(const float deltaRealTime)
 		m_RotateY.AddSmoothly(m_ViewRotateYSpeed * deltaRealTime);
 	if (HotkeyIsPressed("camera.rotate.ccw"))
 		m_RotateY.AddSmoothly(-m_ViewRotateYSpeed * deltaRealTime);
-	if (HotkeyIsPressed("camera.rotate.up"))
+	if (HotkeyIsPressed("camera.rotate.up") && !m_BirdsEyeView)
 		m_RotateX.AddSmoothly(-m_ViewRotateXSpeed * deltaRealTime);
-	if (HotkeyIsPressed("camera.rotate.down"))
+	if (HotkeyIsPressed("camera.rotate.down") && !m_BirdsEyeView)
 		m_RotateX.AddSmoothly(m_ViewRotateXSpeed * deltaRealTime);
 
 	float moveRightward = 0.f;
@@ -180,8 +194,14 @@ void CCameraController::Update(const float deltaRealTime)
 
 	if (HotkeyIsPressed("camera.pan"))
 	{
-		moveRightward += m_ViewDragSpeed * mouse_dx;
-		moveForward += m_ViewDragSpeed * -mouse_dy;
+		if (m_ViewDragInverted) {
+			moveRightward += m_ViewDragSpeed * -mouse_dx;
+			moveForward += m_ViewDragSpeed * mouse_dy;
+		}
+		else {
+			moveRightward += m_ViewDragSpeed * mouse_dx;
+			moveForward += m_ViewDragSpeed * -mouse_dy;
+		}
 	}
 
 	if (g_mouse_active && m_ViewScrollMouseDetectDistance > 0)
@@ -282,7 +302,12 @@ void CCameraController::Update(const float deltaRealTime)
 	}
 
 	if (m_ConstrainCamera)
-		m_RotateX.ClampSmoothly(DEGTORAD(m_ViewRotateXMin), DEGTORAD(m_ViewRotateXMax));
+	{
+		if (m_BirdsEyeView)
+			m_RotateX.ClampSmoothly(static_cast<float>(M_PI_2), static_cast<float>(M_PI_2));
+		else
+			m_RotateX.ClampSmoothly(DEGTORAD(m_ViewRotateXMin), DEGTORAD(m_ViewRotateXMax));
+	}
 
 	FocusHeight(true);
 
@@ -447,6 +472,9 @@ void CCameraController::SetCamera(const CVector3D& pos, float rotX, float rotY,
 
 	// Break out of following mode so the camera really moves to the target
 	m_FollowEntity = INVALID_ENTITY;
+
+	// Leave bird's eye view
+	m_BirdsEyeView = false;
 }
 
 void CCameraController::MoveCameraTarget(const CVector3D& target)
@@ -493,6 +521,9 @@ void CCameraController::ResetCameraTarget(const CVector3D& target)
 
 	// Break out of following mode so the camera really moves to the target
 	m_FollowEntity = INVALID_ENTITY;
+
+	// Leave bird's eye view
+	m_BirdsEyeView = false;
 }
 
 void CCameraController::FollowEntity(entity_id_t entity, bool firstPerson)
@@ -527,6 +558,16 @@ void CCameraController::ResetCameraAngleZoom()
 	// Reset orientations to default
 	m_RotateX.SetValueSmoothly(DEGTORAD(m_ViewRotateXDefault));
 	m_RotateY.SetValueSmoothly(DEGTORAD(m_ViewRotateYDefault));
+
+	// Leave bird's eye view
+	m_BirdsEyeView = false;
+}
+
+void CCameraController::ToggleBirdsEyeView()
+{
+	m_BirdsEyeView = !m_BirdsEyeView;
+	float angle = m_BirdsEyeView ? M_PI / 2 : DEGTORAD(m_ViewRotateXDefault);
+	m_RotateX.SetValueSmoothly(angle);
 }
 
 void CCameraController::SetupCameraMatrixSmooth(CMatrix3D* orientation)
@@ -625,6 +666,11 @@ InReaction CCameraController::HandleEvent(const SDL_Event_* ev)
 			ResetCameraAngleZoom();
 			return IN_HANDLED;
 		}
+		else if (hotkey == "camera.togglebirdseyeview")
+		{
+			ToggleBirdsEyeView();
+			return IN_HANDLED;
+		}
 		return IN_PASS;
 	}
 
