@@ -1,4 +1,4 @@
-/* Copyright (C) 2023 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -20,6 +20,10 @@
 
 #include "graphics/Material.h"
 #include "graphics/ModelAbstract.h"
+#include "lib/debug.h"
+#include "lib/posix/posix_types.h"
+
+#include <cstddef>
 
 class CTerrain;
 
@@ -71,7 +75,7 @@ public:
 	void SetTransform(const CMatrix3D& transform) override;
 
 	// remove shadow receiving
-	void RemoveShadows();
+	void RemoveShadowsReceive();
 
 	/**
 	 * Compute the terrain vertex indexes that bound the decal's
