@@ -1,4 +1,4 @@
-/* Copyright (C) 2021 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -30,14 +30,15 @@ class CFontMetrics
 {
 public:
 	CFontMetrics(CStrIntern font);
+	CFontMetrics(CStrIntern font, CStrIntern locale);
 
-	int GetLineSpacing() const;
-	int GetHeight() const;
-	int GetCharacterWidth(wchar_t c) const;
-	void CalculateStringSize(const wchar_t* string, int& w, int& h) const;
+	float GetHeight() const;
+	float GetCapHeight() const;
+	float GetCharacterWidth(wchar_t c) const;
+	void CalculateStringSize(const wchar_t* string, float& w, float& h) const;
 
 private:
-	std::shared_ptr<CFont> m_Font;
+	CFont* m_Font;
 };
 
 #endif // INCLUDED_FONTMETRICS
