@@ -1,4 +1,4 @@
-/* Copyright (C) 2020 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -24,6 +24,10 @@
 #ifndef INCLUDED_HEIGHTMIPMAP
 #define INCLUDED_HEIGHTMIPMAP
 
+#include "lib/code_annotation.h"
+#include "lib/types.h"
+
+#include <cstddef>
 #include <vector>
 
 class Path;
