@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,15 +19,28 @@
 
 #include "ParticleEmitter.h"
 
-#include "graphics/LightEnv.h"
 #include "graphics/LOSTexture.h"
+#include "graphics/LightEnv.h"
 #include "graphics/ParticleEmitterType.h"
 #include "graphics/ParticleManager.h"
-#include "graphics/ShaderProgram.h"
+#include "graphics/RenderableObject.h"
 #include "graphics/TextureManager.h"
+#include "lib/debug.h"
+#include "lib/types.h"
+#include "maths/Matrix3D.h"
+#include "ps/CStrIntern.h"
 #include "ps/CStrInternStatic.h"
 #include "renderer/Renderer.h"
+#include "renderer/Scene.h"
 #include "renderer/SceneRenderer.h"
+#include "renderer/backend/Format.h"
+#include "renderer/backend/IBuffer.h"
+#include "renderer/backend/IDeviceCommandContext.h"
+#include "renderer/backend/IShaderProgram.h"
+
+#include <array>
+#include <cmath>
+#include <cstdint>
 
 CParticleEmitter::CParticleEmitter(const CParticleEmitterTypePtr& type) :
 	m_Type(type), m_Active(true), m_NextParticleIdx(0), m_EmissionRoundingError(0.f),
@@ -211,14 +224,7 @@ void CParticleEmitter::Bind(
 		shader->GetBindingSlot(str_losTransform),
 		los.GetTextureMatrix()[0], los.GetTextureMatrix()[12]);
 
-	const CLightEnv& lightEnv = g_Renderer.GetSceneRenderer().GetLightEnv();
-
-	deviceCommandContext->SetUniform(
-		shader->GetBindingSlot(str_sunColor), lightEnv.m_SunColor.AsFloatArray());
-	deviceCommandContext->SetUniform(
-		shader->GetBindingSlot(str_fogColor), lightEnv.m_FogColor.AsFloatArray());
-	deviceCommandContext->SetUniform(
-		shader->GetBindingSlot(str_fogParams), lightEnv.m_FogFactor, lightEnv.m_FogMax);
+	g_Renderer.GetSceneRenderer().GetLightEnv().Bind(deviceCommandContext, shader);
 
 	deviceCommandContext->SetTexture(
 		shader->GetBindingSlot(str_baseTex), m_Type->m_Texture->GetBackendTexture());
