@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,8 +19,7 @@
 #define INCLUDED_SHADERTECHNIQUE
 
 #include "graphics/ShaderDefines.h"
-#include "graphics/ShaderProgram.h"
-#include "graphics/ShaderTechniquePtr.h"
+#include "graphics/ShaderProgramPtr.h"
 #include "lib/code_annotation.h"
 #include "lib/file/vfs/vfs_path.h"
 #include "renderer/backend/PipelineState.h"
@@ -29,6 +28,8 @@
 #include <memory>
 #include <vector>
 
+namespace Renderer::Backend { class IShaderProgram; }
+
 /**
  * Implements a render pass consisting of a pipeline state and a shader,
  * used by CShaderTechnique.
