@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,11 +18,19 @@
 #include "lib/self_test.h"
 
 #include "graphics/LOSTexture.h"
+
+#include "lib/posix/posix_types.h"
 #include "lib/timer.h"
+#include "lib/types.h"
 #include "scriptinterface/ScriptInterface.h"
 #include "simulation2/Simulation2.h"
+#include "simulation2/helpers/Grid.h"
 #include "simulation2/helpers/Los.h"
 
+#include <cstdio>
+#include <memory>
+#include <vector>
+
 class TestLOSTexture : public CxxTest::TestSuite
 {
 public:
