@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,18 +18,31 @@
 #ifndef INCLUDED_GUIMANAGER
 #define INCLUDED_GUIMANAGER
 
-#include "lib/file/vfs/vfs_path.h"
+#include "lib/code_annotation.h"
 #include "lib/input.h"
+#include "lib/path.h"
+#include "lib/status.h"
 #include "ps/CStr.h"
 #include "ps/TemplateLoader.h"
+#include "scriptinterface/ScriptInterface.h"
 #include "scriptinterface/StructuredClone.h"
 
+#include <cstddef>
 #include <deque>
+#include <js/TypeDecls.h>
+#include <memory>
+#include <optional>
 #include <string>
 #include <unordered_set>
 
 class CCanvas2D;
 class CGUI;
+class CParamNode;
+class ScriptContext;
+namespace JS { class HandleValueArray; }
+namespace JS { class Value; }
+namespace PS { template <typename T, size_t N> class StaticVector; }
+struct SDL_Event_;
 
 /**
  * External interface to the GUI system.
@@ -70,13 +83,7 @@ public:
 	 * user inputs.
 	 * The returned promise will be fulfilled once the pushed page is closed.
 	 */
-	JS::Value PushPage(const CStrW& pageName, Script::StructuredClone initData);
-
-	/**
-	 * Unload the currently active GUI page, and make the previous page active.
-	 * (There must be at least two pages when you call this.)
-	 */
-	void PopPage(Script::StructuredClone args);
+	JS::Value OpenChildPage(const CStrW& pageName, Script::StructuredClone initData);
 
 	/**
 	 * Called when a file has been modified, to hotload changes.
@@ -101,8 +108,10 @@ public:
 
 	/**
 	 * See CGUI::TickObjects; applies to @em all loaded pages.
+	 * When the root page is closed it's returned wheter Atlas should be
+	 * started.
 	 */
-	void TickObjects();
+	std::optional<bool> TickObjects();
 
 	/**
 	 * See CGUI::Draw; applies to @em all loaded pages.
@@ -143,7 +152,7 @@ private:
 		/**
 		 * Create the CGUI with it's own ScriptInterface. Deletes the previous CGUI if it existed.
 		 */
-		void LoadPage(ScriptContext& scriptContext);
+		void LoadPage(ScriptContext& context);
 
 		/**
 		 * A new promise gets set. A reference to that promise is returned. The promise will settle when
@@ -151,10 +160,24 @@ private:
 		 */
 		JS::Value ReplacePromise(ScriptInterface& scriptInterface);
 
+		struct CloseResult
+		{
+			Script::StructuredClone arg;
+			bool rejected;
+		};
 		/**
-		 * Execute the stored callback function with the given arguments.
+		 * If the page should be closed this function closes the page and
+		 * returns the result of the @c init function.
+		 * If this page wasn't closed an empty optional is returned.
 		 */
-		void ResolvePromise(Script::StructuredClone args);
+		std::optional<CloseResult> MaybeClose(const bool topmostPage);
+
+		/**
+		 * This function should be called when a child page got closed. The
+		 * result of the closed page should be the argument of this
+		 * function. This function resolves the @c receivingPromise.
+		 */
+		void Refocus(const CloseResult& result);
 
 		std::wstring m_Name;
 		std::unordered_set<VfsPath> inputs; // for hotloading
@@ -162,10 +185,16 @@ private:
 		std::shared_ptr<CGUI> gui; // the actual GUI page
 
 		/**
-		 * Function executed by this parent GUI page when the child GUI page it pushed is popped.
-		 * Notice that storing it in the SGUIPage instead of CGUI means that it will survive the hotloading CGUI reset.
+		 * When this promise is settled this page wants to be closed. It
+		 * settles with the page completion value.
 		 */
-		std::shared_ptr<JS::PersistentRootedObject> callbackFunction;
+		std::shared_ptr<JS::PersistentRootedObject> sendingPromise;
+
+		/**
+		 * The parent page waits on this promise. It also gets the
+		 * completion value through this promise.
+		 */
+		std::shared_ptr<JS::PersistentRootedObject> receivingPromise;
 	};
 
 	std::shared_ptr<CGUI> top() const;
@@ -195,6 +224,11 @@ private:
 	};
 	PageStackType m_PageStack;
 
+	/**
+	 * Returns an immutable copy so iterators aren't invalidated by handlers.
+	 */
+	PS::StaticVector<SGUIPage, 16> GetCopyOfFrozenStack() const;
+
 	CTemplateLoader m_TemplateLoader;
 };
 
