@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,18 +19,17 @@
 #define INCLUDED_GUIRENDERER
 
 #include "graphics/Color.h"
-#include "graphics/ShaderTechniquePtr.h"
 #include "graphics/Texture.h"
 #include "maths/Rect.h"
-#include "ps/CStrForward.h"
-#include "ps/CStrIntern.h"
 
 #include <map>
+#include <memory>
 #include <vector>
 
 class CCanvas2D;
 class CGUI;
 class CGUISprite;
+class CStr8;
 struct CGUIColor;
 struct SGUIImage;
 
@@ -64,7 +63,7 @@ namespace GUIRenderer
 		DrawCalls& operator=(const DrawCalls&);
 	};
 
-	void UpdateDrawCallCache(const CGUI& pGUI, DrawCalls& Calls, const CStr8& SpriteName, const CRect& Size, std::map<CStr8, std::unique_ptr<const CGUISprite>>& Sprites);
+	void UpdateDrawCallCache(const CGUI& pGUI, DrawCalls& Calls, const CStr8& SpriteName, const CRect& Size, const bool RoundCoordinates, std::map<CStr8, std::unique_ptr<const CGUISprite>>& Sprites);
 
 	void Draw(DrawCalls& Calls, CCanvas2D& canvas);
 }
