@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -20,6 +20,7 @@
 #include "CImage.h"
 
 #include "gui/CGUI.h"
+#include "ps/CStr.h"
 
 CImage::CImage(CGUI& pGUI)
 	: IGUIObject(pGUI),
@@ -27,10 +28,6 @@ CImage::CImage(CGUI& pGUI)
 {
 }
 
-CImage::~CImage()
-{
-}
-
 void CImage::Draw(CCanvas2D& canvas)
 {
 	m_pGUI.DrawSprite(m_Sprite, canvas, m_CachedActualSize, m_VisibleArea);
