@@ -1,4 +1,4 @@
-/* Copyright (C) 2021 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,9 +18,12 @@
 #ifndef INCLUDED_CIMAGE
 #define INCLUDED_CIMAGE
 
+#include "gui/CGUISetting.h"
 #include "gui/CGUISprite.h"
 #include "gui/ObjectBases/IGUIObject.h"
 
+class CGUI;
+
 /**
  * Object just for drawing a sprite. Like CText, without the
  * possibility to draw text.
@@ -37,7 +40,6 @@ class CImage : public IGUIObject
 
 public:
 	CImage(CGUI& pGUI);
-	virtual ~CImage();
 
 protected:
 	/**
