@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -24,15 +24,34 @@
 #include "graphics/TextRenderer.h"
 #include "gui/CGUI.h"
 #include "gui/CGUIScrollBarVertical.h"
+#include "gui/IGUIScrollBar.h"
+#include "gui/SGUIMessage.h"
+#include "gui/SettingTypes/EAlign.h"
+#include "lib/debug.h"
+#include "lib/external_libraries/libsdl.h"
 #include "lib/timer.h"
 #include "lib/utf8.h"
+#include "maths/Size2D.h"
+#include "maths/Vector2D.h"
+#include "ps/CStrIntern.h"
 #include "ps/ConfigDB.h"
-#include "ps/CStrInternStatic.h"
-#include "ps/GameSetup/Config.h"
 #include "ps/Globals.h"
 #include "ps/Hotkey.h"
 
-#include <sstream>
+#include <SDL_clipboard.h>
+#include <SDL_events.h>
+#include <SDL_keyboard.h>
+#include <SDL_mouse.h>
+#include <SDL_rect.h>
+#include <SDL_scancode.h>
+#include <SDL_stdinc.h>
+#include <algorithm>
+#include <cstring>
+#include <cwchar>
+#include <memory>
+#include <string>
+#include <unordered_map>
+#include <utility>
 
 extern int g_yres;
 
@@ -50,7 +69,7 @@ CInput::CInput(CGUI& pGUI)
 	m_HorizontalScroll(),
 	m_PrevTime(),
 	m_CursorVisState(true),
-	m_CursorBlinkRate(0.5),
+	m_CursorBlinkRate{g_ConfigDB.Get("gui.cursorblinkrate", 0.5)},
 	m_ComposingText(),
 	m_GeneratedPlaceholderTextValid(false),
 	m_iComposedLength(),
@@ -75,17 +94,11 @@ CInput::CInput(CGUI& pGUI)
 	m_PlaceholderText(this, "placeholder_text"),
 	m_PlaceholderColor(this, "placeholder_color")
 {
-	CFG_GET_VAL("gui.cursorblinkrate", m_CursorBlinkRate);
-
 	auto bar = std::make_unique<CGUIScrollBarVertical>(pGUI);
 	bar->SetRightAligned(true);
 	AddScrollBar(std::move(bar));
 }
 
-CInput::~CInput()
-{
-}
-
 void CInput::UpdateBufferPositionSetting()
 {
 	m_BufferPosition.Set(m_iBufferPos, false);
@@ -328,7 +341,7 @@ void CInput::ManuallyMutableHandleKeyDownEvent(const SDL_Keycode keyCode)
 		}
 
 		cooked = '\n'; // Change to '\n' and do default:
-		FALLTHROUGH;
+		[[fallthrough]];
 	}
 	default: // Insert a character
 	{
@@ -1232,11 +1245,11 @@ void CInput::DrawContent(CCanvas2D& canvas)
 	}
 
 	// Get the height of this font.
-	float h = (float)font.GetHeight();
-	float ls = (float)font.GetLineSpacing();
+	const float h{font.GetCapHeight()};
+	const float ls{font.GetHeight()};
 
 	CTextRenderer textRenderer;
-	textRenderer.SetCurrentFont(font_name);
+	textRenderer.SetCurrentFont(font_name, CStrIntern{});
 
 	textRenderer.Translate(
 		(float)(int)(m_CachedActualSize.left) + m_BufferZone,
@@ -1880,7 +1893,7 @@ void CInput::UpdateText(int from, int to_before, int to_after)
 
 	if (m_ScrollBar)
 	{
-		GetScrollBar(0).SetScrollRange(m_CharacterPositions.size() * font.GetLineSpacing() + m_BufferZone * 2.f);
+		GetScrollBar(0).SetScrollRange(m_CharacterPositions.size() * font.GetHeight() + m_BufferZone * 2.f);
 		GetScrollBar(0).SetScrollSpace(m_CachedActualSize.GetHeight());
 	}
 }
@@ -1903,10 +1916,8 @@ int CInput::GetMouseHoveringTextPosition() const
 		if (m_ScrollBar)
 			scroll = GetScrollBarPos(0);
 
-		// Now get the height of the font.
-						// TODO: Get the real font
-		CFontMetrics font(CStrIntern(m_Font->ToUTF8()));
-		float spacing = (float)font.GetLineSpacing();
+		const CFontMetrics font{CStrIntern{m_Font->ToUTF8()}};
+		const float spacing{font.GetHeight()};
 
 		// Change mouse position relative to text.
 		mouse -= m_CachedActualSize.TopLeft();
@@ -2032,11 +2043,8 @@ void CInput::UpdateAutoScroll()
 
 		const float scroll = GetScrollBar(0).GetPos();
 
-		// Now get the height of the font.
-						// TODO: Get the real font
-		CFontMetrics font(CStrIntern(m_Font->ToUTF8()));
-		float spacing = (float)font.GetLineSpacing();
-		//float height = font.GetHeight();
+		const CFontMetrics font{CStrIntern{m_Font->ToUTF8()}};
+		const float spacing{font.GetHeight()};
 
 		// TODO Gee (2004-11-21): Okay, I need a 'std::list' for some reasons, but I would really like to
 		//  be able to get the specific element here. This is hopefully a temporary hack.
