@@ -18,8 +18,11 @@
 #ifndef INCLUDED_CRADIOBUTTON
 #define INCLUDED_CRADIOBUTTON
 
+#include "gui/ObjectBases/IGUIObject.h"
 #include "gui/ObjectTypes/CCheckBox.h"
 
+class CGUI;
+
 /**
  * Just like a check box, but it'll nullify its siblings,
  * and it won't switch itself.
