@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -23,13 +23,15 @@
 #ifndef INCLUDED_L10N
 #define INCLUDED_L10N
 
-#include "lib/code_annotation.h"
-#include "lib/external_libraries/icu.h"
 #include "lib/file/vfs/vfs_path.h"
+#include "lib/status.h"
 #include "ps/Singleton.h"
 
 #include <memory>
 #include <string>
+#include <unicode/datefmt.h>
+#include <unicode/locid.h>
+#include <unicode/utypes.h>
 #include <vector>
 
 namespace tinygettext
@@ -210,15 +212,6 @@ public:
 	 */
 	std::string GetLocaleScript(const std::string& locale) const;
 
-	/**
-	 * Returns @c true if the current locale is the special "Long Strings"
-	 * locale. It returns @c false otherwise.
-	 *
-	 * @return Whether the current locale is the special "Long Strings"
-	 *         (@c true) or not (@c false).
-	 */
-	bool UseLongStrings() const;
-
 	/**
 	 * Returns an array of paths to files in the virtual filesystem that provide
 	 * translations for the specified locale code.
@@ -523,14 +516,6 @@ private:
 	 */
 	bool m_CurrentLocaleIsOriginalGameLocale{false};
 
-	/**
-	 * Whether the game is using the special game locale with the longest
-	 * strings of each translation (@c true) or not (@c false).
-	 *
-	 * @sa https://gitea.wildfiregames.com/0ad/0ad/wiki/Implementation_of_Internationalization_and_Localization#LongStringsLocale
-	 */
-	bool m_UseLongStrings{false};
-
 	/**
 	 * Loads the translation files for the
 	 * @link L10n::GetCurrentLocale() current locale@endlink.
