@@ -1,4 +1,4 @@
-/* Copyright (C) 2014 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -32,13 +32,4 @@
 
 #include <png.h>
 
-// automatically link against the required library
-#if MSC_VERSION
-# ifdef NDEBUG
-#  pragma comment(lib, "libpng16.lib")
-# else
-#  pragma comment(lib, "libpng16d.lib")
-# endif	// NDEBUG
-#endif	// MSC_VERSION
-
 #endif	//	#ifndef INCLUDED_PNG
