@@ -1,4 +1,4 @@
-/* Copyright (c) 2010 Wildfire Games
+/* Copyright (C) 2025 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -7,10 +7,10 @@
  * distribute, sublicense, and/or sell copies of the Software, and to
  * permit persons to whom the Software is furnished to do so, subject to
  * the following conditions:
- * 
+ *
  * The above copyright notice and this permission notice shall be included
  * in all copies or substantial portions of the Software.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -25,21 +25,38 @@
  */
 
 #include "precompiled.h"
-#include "lib/file/archive/archive_zip.h"
 
-#include <time.h>
-#include <limits>
+#include "archive_zip.h"
 
-#include "lib/utf8.h"
+#include "lib/alignment.h"
+#include "lib/allocators/dynarray.h"
+#include "lib/allocators/pool.h"
 #include "lib/bits.h"
 #include "lib/byte_order.h"
-#include "lib/allocators/pool.h"
-#include "lib/sysdep/filesystem.h"
+#include "lib/code_annotation.h"
+#include "lib/debug.h"
 #include "lib/file/archive/archive.h"
+#include "lib/file/archive/codec.h"
 #include "lib/file/archive/codec_zlib.h"
 #include "lib/file/archive/stream.h"
 #include "lib/file/file.h"
+#include "lib/file/file_system.h"
 #include "lib/file/io/io.h"
+#include "lib/lib.h"
+#include "lib/path.h"
+#include "lib/posix/posix_types.h"
+#include "lib/status.h"
+#include "lib/types.h"
+#include "lib/utf8.h"
+
+#include <algorithm>
+#include <cstdint>
+#include <cstring>
+#include <ctime>
+#include <exception>
+#include <fcntl.h>
+#include <memory>
+#include <string>
 
 //-----------------------------------------------------------------------------
 // timestamp conversion: DOS FAT <-> Unix time_t
@@ -269,6 +286,11 @@ public:
 		cd_size      = (size_t)read_le32(&m_cd_size);
 	}
 
+	off_t GetCommentLength() const
+	{
+		return static_cast<off_t>(read_le16(&m_comment_len));
+	}
+
 private:
 	u32 m_magic;
 	u16 m_diskNum;
@@ -289,7 +311,7 @@ cassert(sizeof(ECDR) == 22);
 // ArchiveFile_Zip
 //-----------------------------------------------------------------------------
 
-class ArchiveFile_Zip : public IArchiveFile
+class ArchiveFile_Zip final : public IArchiveFile
 {
 public:
 	ArchiveFile_Zip(const PFile& file, off_t ofs, off_t csize, u32 checksum, ZipMethod method)
@@ -299,22 +321,22 @@ public:
 	{
 	}
 
-	virtual size_t Precedence() const
+	size_t Precedence() const override
 	{
 		return 2u;
 	}
 
-	virtual wchar_t LocationCode() const
+	wchar_t LocationCode() const override
 	{
 		return 'A';
 	}
 
-	virtual OsPath Path() const
+	const OsPath& Path() const override
 	{
 		return m_file->Pathname();
 	}
 
-	virtual Status Load(const OsPath& UNUSED(name), const shared_ptr<u8>& buf, size_t size) const
+	Status Load(const OsPath& /*name*/, const std::shared_ptr<u8>& buf, size_t size) const override
 	{
 		AdjustOffset();
 
@@ -448,17 +470,17 @@ public:
 		size_t cd_numEntries = 0;
 		size_t cd_size = 0;
 		RETURN_STATUS_IF_ERR(LocateCentralDirectory(m_file, m_fileSize, cd_ofs, cd_numEntries, cd_size));
-		UniqueRange buf(RVALUE(io::Allocate(cd_size)));
+		io::BufferPtr buf(io::Allocate(cd_size));
 
 		io::Operation op(*m_file.get(), buf.get(), cd_size, cd_ofs);
 		RETURN_STATUS_IF_ERR(io::Run(op));
 
 		// iterate over Central Directory
-		const u8* pos = (const u8*)buf.get();
+		const u8* pos = buf.get();
 		for(size_t i = 0; i < cd_numEntries; i++)
 		{
 			// scan for next CDFH
-			CDFH* cdfh = (CDFH*)FindRecord((const u8*)buf.get(), cd_size, pos, cdfh_magic, sizeof(CDFH));
+			CDFH* cdfh = (CDFH*)FindRecord(buf.get(), cd_size, pos, cdfh_magic, sizeof(CDFH));
 			if(!cdfh)
 				WARN_RETURN(ERR::CORRUPTED);
 
@@ -467,7 +489,7 @@ public:
 			{
 				const OsPath name = relativePathname.Filename();
 				CFileInfo fileInfo(name, cdfh->USize(), cdfh->MTime());
-				shared_ptr<ArchiveFile_Zip> archiveFile(new ArchiveFile_Zip(m_file, cdfh->HeaderOffset(), cdfh->CSize(), cdfh->Checksum(), cdfh->Method()));
+				std::shared_ptr<ArchiveFile_Zip> archiveFile = std::make_shared<ArchiveFile_Zip>(m_file, cdfh->HeaderOffset(), cdfh->CSize(), cdfh->Checksum(), cdfh->Method());
 				cb(relativePathname, fileInfo, archiveFile, cbData);
 			}
 
@@ -521,8 +543,40 @@ private:
 		io::Operation op(*file.get(), buf, scanSize, ofs);
 		RETURN_STATUS_IF_ERR(io::Run(op));
 
-		// look for ECDR in buffer
-		const ECDR* ecdr = (const ECDR*)FindRecord(buf, scanSize, buf, ecdr_magic, sizeof(ECDR));
+		// Scanning for ECDR first assumes no comment exists
+		// (standard case), so ECDR structure exists right at
+		// end of file
+		off_t offsetInBlock = scanSize - sizeof(ECDR);
+		const ECDR* ecdr = nullptr;
+
+		for (off_t commentSize = 0; commentSize <= offsetInBlock && !ecdr; ++commentSize)
+		{
+			const u8 *pECDRTest = buf + offsetInBlock - commentSize;
+			if (*reinterpret_cast<const u32*>(pECDRTest) == ecdr_magic)
+			{
+				// Signature matches, test whether comment
+				// fills up the whole space following the
+				// ECDR
+				ecdr = reinterpret_cast<const ECDR*>(pECDRTest);
+				if (commentSize != ecdr->GetCommentLength())
+				{
+					// Signature matches but there is some other data between
+					// header, comment and EOF. There are three possibilities
+					// for this:
+					// 1) Header file format and size differ from what we expect
+					// 2) File has been truncated
+					// 3) The magic id occurs inside a zip comment
+					ecdr = nullptr;
+				}
+				else
+				{
+					// Seems like a valid archive header before an archive-level
+					// comment
+					break;
+				}
+			}
+		}
+
 		if(!ecdr)
 			return INFO::CANNOT_HANDLE;
 
@@ -533,18 +587,11 @@ private:
 	static Status LocateCentralDirectory(const PFile& file, off_t fileSize, off_t& cd_ofs, size_t& cd_numEntries, size_t& cd_size)
 	{
 		const size_t maxScanSize = 66000u;	// see below
-		UniqueRange buf(RVALUE(io::Allocate(maxScanSize)));
-
-		// expected case: ECDR at EOF; no file comment
-		Status ret = ScanForEcdr(file, fileSize, (u8*)buf.get(), sizeof(ECDR), cd_numEntries, cd_ofs, cd_size);
-		if(ret == INFO::OK)
-			return INFO::OK;
-		// worst case: ECDR precedes 64 KiB of file comment
-		ret = ScanForEcdr(file, fileSize, (u8*)buf.get(), maxScanSize, cd_numEntries, cd_ofs, cd_size);
+		io::BufferPtr buf(io::Allocate(maxScanSize));
+		Status ret = ScanForEcdr(file, fileSize, static_cast<u8*>(buf.get()), maxScanSize, cd_numEntries, cd_ofs, cd_size);
 		if(ret == INFO::OK)
 			return INFO::OK;
 
-		// both ECDR scans failed - this is not a valid Zip file.
 		io::Operation op(*file.get(), buf.get(), sizeof(LFH));
 		RETURN_STATUS_IF_ERR(io::Run(op));
 		// the Zip file has an LFH but lacks an ECDR. this can happen if
@@ -555,7 +602,7 @@ private:
 		//   because it'd be slow.
 		// - do not warn - the corrupt archive will be deleted on next
 		//   successful archive builder run anyway.
-		if(FindRecord((const u8*)buf.get(), sizeof(LFH), (const u8*)buf.get(), lfh_magic, sizeof(LFH)))
+		if(FindRecord(buf.get(), sizeof(LFH), buf.get(), lfh_magic, sizeof(LFH)))
 			return ERR::CORRUPTED;	// NOWARN
 		// totally bogus
 		else
@@ -600,7 +647,7 @@ public:
 		const size_t cd_size = m_cdfhPool.da.pos;
 		ECDR* ecdr = (ECDR*)pool_alloc(&m_cdfhPool, sizeof(ECDR));
 		if(!ecdr)
-			throw std::bad_alloc();
+			std::terminate();
 		const off_t cd_ofs = m_fileSize;
 		ecdr->Init(m_numEntries, cd_ofs, cd_size);
 
@@ -662,12 +709,12 @@ public:
 
 		// allocate memory
 		const size_t csizeMax = codec->MaxOutputSize(size_t(usize));
-		UniqueRange buf(RVALUE(io::Allocate(sizeof(LFH) + pathnameLength + csizeMax)));
+		io::BufferPtr buf(io::Allocate(sizeof(LFH) + pathnameLength + csizeMax));
 
 		// read and compress file contents
 		size_t csize; u32 checksum;
 		{
-			u8* cdata = (u8*)buf.get() + sizeof(LFH) + pathnameLength;
+			u8* cdata = buf.get() + sizeof(LFH) + pathnameLength;
 			Stream stream(codec);
 			stream.SetOutputBuffer(cdata, csizeMax);
 			StreamFeeder streamFeeder(stream);
@@ -687,7 +734,7 @@ public:
 
 		// build LFH
 		{
-			LFH* lfh = (LFH*)buf.get();
+			LFH* lfh = reinterpret_cast<LFH*>(buf.get());
 			lfh->Init(fileInfo, (off_t)csize, method, checksum, pathnameInArchive);
 		}
 
@@ -720,7 +767,7 @@ private:
 		static const wchar_t* incompressibleExtensions[] =
 		{
 			L".zip", L".rar",
-			L".jpg", L".jpeg", L".png", 
+			L".jpg", L".jpeg", L".png",
 			L".ogg", L".mp3"
 		};
 
