@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -27,9 +27,10 @@
 #ifndef INCLUDED_CPU
 #define INCLUDED_CPU
 
+#include "lib/status.h"
+#include "lib/sysdep/arch.h"
 #include "lib/sysdep/compiler.h"
 
-
 namespace ERR
 {
 	const Status CPU_FEATURE_MISSING     = -130000;
