@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -32,9 +32,10 @@
 
 #include "lib/posix/posix_filesystem.h"	// O_CREAT
 #include "lib/sysdep/os/win/wposix/wposix_internal.h"
-#include "lib/sysdep/os/win/wposix/wtime.h"			// timespec
 #include "lib/sysdep/os/win/wseh.h"		// wseh_ExceptionFilter
 
+#include <ctime>
+
 namespace
 {
 
@@ -272,23 +273,23 @@ again:
 // memory manager used a pthread_mutex.
 
 
-int pthread_mutexattr_init(pthread_mutexattr_t* UNUSED(attr))
+int pthread_mutexattr_init(pthread_mutexattr_t*)
 {
 	return 0;
 }
 
-int pthread_mutexattr_destroy(pthread_mutexattr_t* UNUSED(attr))
+int pthread_mutexattr_destroy(pthread_mutexattr_t*)
 {
 	return 0;
 }
 
-int pthread_mutexattr_gettype(const pthread_mutexattr_t* UNUSED(attr), int* type)
+int pthread_mutexattr_gettype(const pthread_mutexattr_t*, int* type)
 {
 	*type = PTHREAD_MUTEX_RECURSIVE;
 	return 0;
 }
 
-int pthread_mutexattr_settype(pthread_mutexattr_t* UNUSED(attr), int type)
+int pthread_mutexattr_settype(pthread_mutexattr_t*, int type)
 {
 	return (type == PTHREAD_MUTEX_RECURSIVE)? 0 : -ENOSYS;
 }
@@ -357,7 +358,7 @@ int pthread_mutex_unlock(pthread_mutex_t* m)
 
 // not implemented - pthread_mutex is based on CRITICAL_SECTION,
 // which doesn't support timeouts. use sem_timedwait instead.
-int pthread_mutex_timedlock(pthread_mutex_t* UNUSED(m), const struct timespec* UNUSED(abs_timeout))
+int pthread_mutex_timedlock(pthread_mutex_t*, const struct timespec* /*abs_timeout*/)
 {
 	return -ENOSYS;
 }
@@ -437,7 +438,7 @@ int sem_close(sem_t* sem)
 	return 0;	// success
 }
 
-int sem_unlink(const char* UNUSED(name))
+int sem_unlink(const char* /*name*/)
 {
 	// see sem_close
 	return 0;	// success
@@ -567,7 +568,7 @@ static unsigned __stdcall thread_start(void* param)
 }
 
 
-int pthread_create(pthread_t* thread_id, const void* UNUSED(attr), void* (*func)(void*), void* arg)
+int pthread_create(pthread_t* thread_id, const void* /*attr*/, void* (*func)(void*), void* arg)
 {
 	// notes:
 	// - use wutil_Allocate instead of the normal heap because we /might/
