@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -22,10 +22,22 @@
 
 #include "lib/self_test.h"
 
-#include "lib/lib.h"
+#include "lib/code_annotation.h"
+#include "lib/os_path.h"
+#include "lib/posix/posix_dlfcn.h"
+#include "lib/posix/posix_filesystem.h"
+#include "lib/posix/posix_types.h"
 #include "lib/secure_crt.h"
 #include "lib/sysdep/filesystem.h"
+#include "lib/sysdep/os.h"
 #include "lib/sysdep/sysdep.h"
+#include "lib/types.h"
+
+#include <climits>
+#include <cstdio>
+#include <cstdlib>
+#include <cwchar>
+#include <string>
 
 #if OS_BSD || OS_LINUX
 # include "lib/sysdep/os/unix/unix_executable_pathname.h"
@@ -157,7 +169,7 @@ public:
 	{
 	public:
 		Mock_dladdr(const std::string& fname) : fname_(fname) { }
-		int dladdr(void *UNUSED(addr), Dl_info *info) {
+		int dladdr(void* /*addr*/, Dl_info *info) {
 			info->dli_fname = fname_.c_str();
 			return 1;
 		}
