@@ -1,4 +1,4 @@
-/* Copyright (C) 2021 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -24,6 +24,9 @@
 
 #include "lib/adts/ring_buf.h"
 
+#include <algorithm>
+#include <cstddef>
+#include <deque>
 #include <random>
 
 class TestRingbuf : public CxxTest::TestSuite
