@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of this software and associated documentation files (the
@@ -24,15 +24,18 @@
 
 #include "tex.h"
 
+#include "lib/alignment.h"
+#include "lib/allocators/dynarray.h"
 #include "lib/allocators/shared_ptr.h"
 #include "lib/bits.h"
-#include "lib/sysdep/cpu.h"
+#include "lib/debug.h"
+#include "lib/posix/posix_types.h"
 #include "lib/tex/tex_codec.h"
 #include "lib/timer.h"
 
 #include <algorithm>
-#include <cmath>
-#include <cstdlib>
+#include <cstdint>
+#include <cstring>
 
 static const StatusDefinition texStatusDefinitions[] =
 {
@@ -669,7 +672,8 @@ u32 Tex::get_average_color() const
 }
 
 
-static void add_level_size(size_t UNUSED(level), size_t UNUSED(level_w), size_t UNUSED(level_h), const u8* RESTRICT UNUSED(level_data), size_t level_dataSize, void* RESTRICT cbData)
+static void add_level_size(size_t /*level*/, size_t /*level_w*/, size_t /*level_h*/,
+	const u8* RESTRICT /*level_data*/, size_t level_dataSize, void* RESTRICT cbData)
 {
 	size_t* ptotal_size = (size_t*)cbData;
 	*ptotal_size += level_dataSize;
