@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -31,20 +31,40 @@ that of Atlas depending on commandline parameters.
 #define MINIMAL_PCH 2
 #include "lib/precompiled.h"
 
+#include "dapinterface/DapInterface.h"
+#include "graphics/GameView.h"
+#include "graphics/TextureManager.h"
+#include "gui/GUIManager.h"
+#include "lib/code_annotation.h"
+#include "lib/config2.h"
 #include "lib/debug.h"
-#include "lib/status.h"
-#include "lib/secure_crt.h"
+#include "lib/external_libraries/libsdl.h"
+#include "lib/file/file_system.h"
+#include "lib/file/vfs/vfs.h"
 #include "lib/frequency_filter.h"
 #include "lib/input.h"
+#include "lib/path.h"
+#include "lib/posix/posix_types.h"
+#include "lib/secure_crt.h"
+#include "lib/status.h"
+#include "lib/sysdep/compiler.h"
+#include "lib/sysdep/os.h"
 #include "lib/timer.h"
-#include "lib/external_libraries/libsdl.h"
-
+#include "lib/types.h"
+#include "lobby/IXmppClient.h"
+#include "network/NetClient.h"
 #include "ps/ArchiveBuilder.h"
 #include "ps/CConsole.h"
 #include "ps/CLogger.h"
+#include "ps/CStr.h"
 #include "ps/ConfigDB.h"
 #include "ps/Filesystem.h"
 #include "ps/Game.h"
+#include "ps/GameSetup/Atlas.h"
+#include "ps/GameSetup/CmdLineArgs.h"
+#include "ps/GameSetup/Config.h"
+#include "ps/GameSetup/GameSetup.h"
+#include "ps/GameSetup/Paths.h"
 #include "ps/Globals.h"
 #include "ps/Hotkey.h"
 #include "ps/Loader.h"
@@ -54,37 +74,40 @@ that of Atlas depending on commandline parameters.
 #include "ps/Profiler2.h"
 #include "ps/Pyrogenesis.h"
 #include "ps/Replay.h"
+#include "ps/TaskManager.h"
 #include "ps/TouchInput.h"
 #include "ps/UserReport.h"
-#include "ps/Util.h"
 #include "ps/VideoMode.h"
-#include "ps/TaskManager.h"
-#include "ps/World.h"
-#include "ps/GameSetup/GameSetup.h"
-#include "ps/GameSetup/Atlas.h"
-#include "ps/GameSetup/Config.h"
-#include "ps/GameSetup/CmdLineArgs.h"
-#include "ps/GameSetup/Paths.h"
 #include "ps/XML/Xeromyces.h"
-#include "network/NetClient.h"
-#include "network/NetServer.h"
-#include "network/NetSession.h"
-#include "lobby/IXmppClient.h"
-#include "graphics/Camera.h"
-#include "graphics/GameView.h"
-#include "graphics/TextureManager.h"
-#include "gui/GUIManager.h"
-#include "renderer/backend/IDevice.h"
 #include "renderer/Renderer.h"
 #include "rlinterface/RLInterface.h"
+#include "scriptinterface/JSON.h"
 #include "scriptinterface/ScriptContext.h"
+#include "scriptinterface/ScriptConversions.h"
 #include "scriptinterface/ScriptEngine.h"
 #include "scriptinterface/ScriptInterface.h"
-#include "scriptinterface/JSON.h"
-#include "simulation2/Simulation2.h"
+#include "scriptinterface/ScriptRequest.h"
 #include "simulation2/system/TurnManager.h"
 #include "soundmanager/ISoundManager.h"
 
+#include <SDL_events.h>
+#include <SDL_stdinc.h>
+#include <SDL_timer.h>
+#include <SDL_video.h>
+#include <chrono>
+#include <cstdlib>
+#include <ctime>
+#include <exception>
+#include <js/RootingAPI.h>
+#include <js/TypeDecls.h>
+#include <js/Value.h>
+#include <memory>
+#include <optional>
+#include <span>
+#include <string>
+#include <utility>
+#include <vector>
+
 #if OS_UNIX
 #include <iostream>
 #include <unistd.h> // geteuid
@@ -124,9 +147,6 @@ extern "C"
 }
 #endif
 
-#include <chrono>
-#include <utility>
-
 extern CStrW g_UniqueLogPostfix;
 
 // Determines the lifetime of the mainloop
@@ -146,6 +166,7 @@ enum ShutdownType
 };
 
 static ShutdownType g_Shutdown = ShutdownType::None;
+static int g_ExitStatus{EXIT_SUCCESS};
 
 // to avoid redundant and/or recursive resizing, we save the new
 // size after VIDEORESIZE messages and only update the video mode
@@ -162,9 +183,10 @@ bool IsQuitRequested()
 	return g_Shutdown == ShutdownType::Quit;
 }
 
-void QuitEngine()
+void QuitEngine(int exitStatus)
 {
 	g_Shutdown = ShutdownType::Quit;
+	g_ExitStatus = exitStatus;
 }
 
 void RestartEngine()
@@ -172,11 +194,6 @@ void RestartEngine()
 	g_Shutdown = ShutdownType::Restart;
 }
 
-void StartAtlas()
-{
-	g_Shutdown = ShutdownType::RestartAsAtlas;
-}
-
 // main app message handler
 static InReaction MainInputHandler(const SDL_Event_* ev)
 {
@@ -195,7 +212,7 @@ static InReaction MainInputHandler(const SDL_Event_* ev)
 		break;
 
 	case SDL_QUIT:
-		QuitEngine();
+		QuitEngine(EXIT_SUCCESS);
 		break;
 
 	case SDL_DROPFILE:
@@ -221,7 +238,7 @@ static InReaction MainInputHandler(const SDL_Event_* ev)
 		std::string hotkey = static_cast<const char*>(ev->ev.user.data1);
 		if (hotkey == "exit")
 		{
-			QuitEngine();
+			QuitEngine(EXIT_SUCCESS);
 			return IN_HANDLED;
 		}
 		else if (hotkey == "screenshot")
@@ -244,6 +261,12 @@ static InReaction MainInputHandler(const SDL_Event_* ev)
 			g_Profiler2.Toggle();
 			return IN_HANDLED;
 		}
+		else if (hotkey == "mousegrabtoggle")
+		{
+			SDL_Window* const window{g_VideoMode.GetWindow()};
+			const SDL_bool willGrabMouse{SDL_GetWindowGrab(window) ? SDL_FALSE : SDL_TRUE};
+			SDL_SetWindowGrab(window, willGrabMouse);
+		}
 		break;
 	}
 
@@ -284,8 +307,8 @@ inline static void LimitFPS()
 	if (g_VideoMode.IsVSyncEnabled())
 		return;
 
-	double fpsLimit = 0.0;
-	CFG_GET_VAL(g_Game && g_Game->IsGameStarted() ? "adaptivefps.session" : "adaptivefps.menu", fpsLimit);
+	const double fpsLimit{
+		g_ConfigDB.Get(g_Game && g_Game->IsGameStarted() ? "adaptivefps.session" : "adaptivefps.menu", 0.0)};
 
 	// Keep in sync with options.json
 	if (fpsLimit < 20.0 || fpsLimit >= 360.0)
@@ -361,7 +384,11 @@ static void RendererIncrementalLoad()
 	while (more && timer_Time() - startTime < maxTime);
 }
 
-static void Frame(RL::Interface* rlInterface)
+#if CONFIG2_DAP_INTERFACE
+static void Frame(RL::Interface* rlInterface, const int fixedFrameFrequency, DAP::Interface* dapInterface)
+#else
+static void Frame(RL::Interface* rlInterface, const int fixedFrameFrequency)
+#endif // CONFIG2_DAP_INTERFACE
 {
 	g_Profiler2.RecordFrameStart();
 	PROFILE2("frame");
@@ -381,7 +408,8 @@ static void Frame(RL::Interface* rlInterface)
 
 	// .. new method - filtered and more smooth, but errors may accumulate
 #else
-	const float realTimeSinceLastFrame = 1.0 / g_frequencyFilter->SmoothedFrequency();
+	const float realTimeSinceLastFrame{static_cast<float>(
+		1.0 / (fixedFrameFrequency > 0 ? fixedFrameFrequency : g_frequencyFilter->SmoothedFrequency()))};
 #endif
 	ENSURE(realTimeSinceLastFrame > 0.0f);
 
@@ -424,7 +452,14 @@ static void Frame(RL::Interface* rlInterface)
 	if (g_NetClient)
 		g_NetClient->Poll();
 
-	g_GUI->TickObjects();
+#if CONFIG2_DAP_INTERFACE
+	if (dapInterface)
+		dapInterface->TryHandleMessage();
+#endif // CONFIG2_DAP_INTERFACE
+
+	std::optional<bool> completionCommand{g_GUI->TickObjects()};
+	if (completionCommand.has_value())
+		g_Shutdown = completionCommand.value() ? ShutdownType::RestartAsAtlas : ShutdownType::Quit;
 
 	if (rlInterface)
 		rlInterface->TryApplyMessage();
@@ -473,7 +508,7 @@ static void NonVisualFrame()
 	g_Profiler.Frame();
 
 	if (g_Game->IsGameFinished())
-		QuitEngine();
+		QuitEngine(EXIT_SUCCESS);
 }
 
 static void MainControllerInit()
@@ -494,19 +529,33 @@ static std::optional<RL::Interface> CreateRLInterface(const CmdLineArgs& args)
 	if (!args.Has("rl-interface"))
 		return std::nullopt;
 
-	std::string server_address;
-	CFG_GET_VAL("rlinterface.address", server_address);
-
-	if (!args.Get("rl-interface").empty())
-		server_address = args.Get("rl-interface");
+	const std::string server_address{args.Get("rl-interface").empty() ?
+		g_ConfigDB.Get("rlinterface.address", std::string{}) : args.Get("rl-interface")};
 
 	debug_printf("RL interface listening on %s\n", server_address.c_str());
 	return std::make_optional<RL::Interface>(server_address.c_str());
 }
 
+#if CONFIG2_DAP_INTERFACE
+static std::optional<DAP::Interface> CreateDAPInterface(const CmdLineArgs& args)
+{
+	if (!args.Has("dap-interface"))
+		return std::nullopt;
+
+	const std::string server_address{args.Get("dapinterface.address").empty() ?
+		g_ConfigDB.Get("dapinterface.address", std::string{}) : args.Get("dapinterface.address")};
+
+	const int port{args.Get("dapinterface.port").empty() ?
+		g_ConfigDB.Get("dapinterface.port", int{}) : args.Get("dapinterface.port").ToInt()};
+
+	debug_printf("DAP interface listening on %s:%d\n", server_address.c_str(), port);
+	return std::make_optional<DAP::Interface>(server_address, port, *g_ScriptContext);
+}
+#endif // CONFIG2_DAP_INTERFACE
+
 // moved into a helper function to ensure args is destroyed before
 // exit(), which may result in a memory leak.
-static void RunGameOrAtlas(const PS::span<const char* const> argv)
+static void RunGameOrAtlas(const std::span<const char* const> argv)
 {
 	const CmdLineArgs args(argv);
 
@@ -514,13 +563,15 @@ static void RunGameOrAtlas(const PS::span<const char* const> argv)
 
 	if (args.Has("version"))
 	{
-		debug_printf("Pyrogenesis %s\n", engine_version);
+		debug_printf("Pyrogenesis %s\n", PS_VERSION);
+		if (std::strcmp(PS_VERSION, PS_SERIALIZATION_VERSION) != 0)
+			debug_printf("Compatible down to patch %s\n", PS_SERIALIZATION_VERSION);
 		return;
 	}
 
 	if (args.Has("autostart-nonvisual") && args.Get("autostart").empty() && !args.Has("rl-interface") && !args.Has("autostart-client"))
 	{
-		LOGERROR("-autostart-nonvisual cant be used alone. A map with -autostart=\"TYPEDIR/MAPNAME\" is needed.");
+		LOGERROR("-autostart-nonvisual can't be used alone. A map with -autostart=\"TYPEDIR/MAPNAME\" is needed.");
 		return;
 	}
 
@@ -531,6 +582,9 @@ static void RunGameOrAtlas(const PS::span<const char* const> argv)
 	const bool isNonVisualReplay = args.Has("replay");
 	const bool isVisual = !args.Has("autostart-nonvisual");
 
+	const int fixedFrameFrequency{args.Has("fixed-frame-frequency")
+		? args.Get("fixed-frame-frequency").ToInt() : 0};
+
 	const OsPath replayFile(
 		isVisualReplay ? args.Get("replay-visual") :
 		isNonVisualReplay ? args.Get("replay") : "");
@@ -632,6 +686,7 @@ static void RunGameOrAtlas(const PS::span<const char* const> argv)
 	g_frequencyFilter = CreateFrequencyFilter(res, 30.0);
 
 	// run the game
+	bool rlInterfaceError{false};
 	bool firstIteration{true};
 	do
 	{
@@ -672,6 +727,10 @@ static void RunGameOrAtlas(const PS::span<const char* const> argv)
 			g_Mods.UpdateAvailableMods(modInterface);
 		}
 
+#if CONFIG2_DAP_INTERFACE
+		std::optional<DAP::Interface> dapInterface{CreateDAPInterface(args)};
+#endif // CONFIG2_DAP_INTERFACE
+
 		std::optional<ScriptInterface> guiScriptInterface;
 
 		if (isVisual)
@@ -683,32 +742,52 @@ static void RunGameOrAtlas(const PS::span<const char* const> argv)
 		else if (!InitNonVisual(args))
 			g_Shutdown = ShutdownType::Quit;
 
-		// MSVC doesn't support copy elision in ternary expressions. So we use a lambda instead.
-		std::optional<RL::Interface> rlInterface{[&]() -> std::optional<RL::Interface>
-			{
-				if (g_Shutdown == ShutdownType::None)
-					return CreateRLInterface(args);
-				else
-					return std::nullopt;
-			}()};
-
-		while (g_Shutdown == ShutdownType::None)
+		try
 		{
-			if (isVisual)
-				Frame(rlInterface ? &*rlInterface : nullptr);
-			else if(rlInterface)
-				rlInterface->TryApplyMessage();
-			else
-				NonVisualFrame();
+			// MSVC doesn't support copy elision in ternary expressions. So we use a lambda instead.
+			std::optional<RL::Interface> rlInterface{[&]() -> std::optional<RL::Interface>
+				{
+					if (g_Shutdown == ShutdownType::None)
+						return CreateRLInterface(args);
+					else
+						return std::nullopt;
+				}()};
+
+			while (g_Shutdown == ShutdownType::None)
+			{
+				if (isVisual)
+#if CONFIG2_DAP_INTERFACE
+				Frame(rlInterface ? &*rlInterface : nullptr, fixedFrameFrequency, dapInterface ? &*dapInterface : nullptr);
+#else
+					Frame(rlInterface ? &*rlInterface : nullptr, fixedFrameFrequency);
+#endif
+				else if(rlInterface)
+					rlInterface->TryApplyMessage();
+				else
+					NonVisualFrame();
+			}
+
+		}
+		catch (const RL::SetupError&)
+		{
+		      rlInterfaceError = true;
 		}
 
 		ShutdownNetworkAndUI();
 		guiScriptInterface.reset();
+
+#if CONFIG2_DAP_INTERFACE
+		dapInterface.reset();
+#endif // CONFIG2_DAP_INTERFACE
+
 		ShutdownConfigAndSubsequent();
 		MainControllerShutdown();
 
 	} while (g_Shutdown == ShutdownType::Restart);
 
+	if (rlInterfaceError)
+	      throw RL::SetupError{};
+
 #if OS_MACOSX
 	if (g_Shutdown == ShutdownType::RestartAsAtlas)
 		startNewAtlasProcess(g_Mods.GetEnabledMods());
@@ -721,12 +800,10 @@ static void RunGameOrAtlas(const PS::span<const char* const> argv)
 #if OS_ANDROID
 // In Android we compile the engine as a shared library, not an executable,
 // so rename main() to a different symbol that the wrapper library can load
-#undef main
-#define main pyrogenesis_main
-extern "C" __attribute__((visibility ("default"))) int main(int argc, char* argv[]);
+extern "C" __attribute__((visibility ("default"))) int pyrogenesis_main(int argc, char* argv[])
+#else
+int main(int argc, char* argv[])
 #endif
-
-extern "C" int main(int argc, char* argv[])
 {
 #if OS_UNIX
 	// Don't allow people to run the game with root permissions,
@@ -751,8 +828,15 @@ extern "C" int main(int argc, char* argv[])
 
 	EarlyInit();	// must come at beginning of main
 
-	// static_cast is ok, argc is never negative.
-	RunGameOrAtlas({argv, static_cast<std::size_t>(argc)});
+	try
+	{
+		// static_cast is ok, argc is never negative.
+		RunGameOrAtlas({argv, static_cast<std::size_t>(argc)});
+	}
+	catch (const RL::SetupError&)
+	{
+		g_ExitStatus = EXIT_FAILURE;
+	}
 
 	// Shut down profiler initialised by EarlyInit
 	g_Profiler2.Shutdown();
@@ -765,5 +849,5 @@ extern "C" int main(int argc, char* argv[])
 	wutil_Shutdown();
 #endif
 
-	return EXIT_SUCCESS;
+	return g_ExitStatus;
 }
