@@ -1,4 +1,4 @@
-/* Copyright (C) 2011 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,8 +18,11 @@
 #ifndef INCLUDED_NETWORK_STRINGCONVERTERS
 #define INCLUDED_NETWORK_STRINGCONVERTERS
 
+#include "lib/types.h"
 #include "ps/CStr.h"
 
+#include <string>
+
 static inline CStr NetMessageStringConvert(u32 arg)
 {
 	return CStr::FromUInt(arg);
