@@ -1,4 +1,4 @@
-/* Copyright (C) 2023 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,15 +19,21 @@
 
 #include "ArchiveBuilder.h"
 
-#include "graphics/TextureManager.h"
 #include "graphics/ColladaManager.h"
-#include "lib/tex/tex_codec.h"
+#include "graphics/TextureManager.h"
+#include "lib/debug.h"
+#include "lib/file/archive/archive.h"
 #include "lib/file/archive/archive_zip.h"
+#include "lib/file/file_system.h"
 #include "lib/file/vfs/vfs_util.h"
+#include "lib/path.h"
+#include "lib/tex/tex.h"
+#include "ps/XMB/XMBStorage.h"
 #include "ps/XML/Xeromyces.h"
 #include "renderer/backend/dummy/Device.h"
 
 #include <boost/algorithm/string/predicate.hpp>
+#include <string>
 
 CArchiveBuilder::CArchiveBuilder(const OsPath& mod, const OsPath& tempdir) :
 	m_TempDir(tempdir), m_NumBaseMods(0)
@@ -176,7 +182,7 @@ void CArchiveBuilder::Build(const OsPath& archive, bool compress)
 	debug_printf("Finished packaging \"%s\".", archive.string8().c_str());
 }
 
-Status CArchiveBuilder::CollectFileCB(const VfsPath& pathname, const CFileInfo& UNUSED(fileInfo), const uintptr_t cbData)
+Status CArchiveBuilder::CollectFileCB(const VfsPath& pathname, const CFileInfo&, const uintptr_t cbData)
 {
 	CArchiveBuilder* self = static_cast<CArchiveBuilder*>((void*)cbData);
 	self->m_Files.push_back(pathname);
