@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -20,30 +20,55 @@
 #include "CConsole.h"
 
 #include "graphics/Canvas2D.h"
+#include "graphics/Color.h"
 #include "graphics/FontMetrics.h"
 #include "graphics/TextRenderer.h"
 #include "gui/CGUI.h"
 #include "gui/GUIManager.h"
 #include "lib/code_generation.h"
+#include "lib/debug.h"
+#include "lib/external_libraries/libsdl.h"
+#include "lib/file/io/write_buffer.h"
+#include "lib/file/vfs/vfs.h"
+#include "lib/status.h"
 #include "lib/timer.h"
+#include "lib/types.h"
 #include "lib/utf8.h"
 #include "maths/MathUtil.h"
-#include "ps/CLogger.h"
+#include "maths/Rect.h"
+#include "maths/Vector2D.h"
+#include "ps/CStr.h"
+#include "ps/CStrIntern.h"
 #include "ps/ConfigDB.h"
-#include "ps/CStrInternStatic.h"
 #include "ps/Filesystem.h"
 #include "ps/GameSetup/Config.h"
 #include "ps/Globals.h"
 #include "ps/Hotkey.h"
+#include "ps/KeyName.h"
 #include "ps/Profile.h"
-#include "ps/Pyrogenesis.h"
+#include "ps/Profiler2.h"
 #include "ps/VideoMode.h"
-#include "scriptinterface/ScriptInterface.h"
 #include "scriptinterface/JSON.h"
+#include "scriptinterface/ScriptInterface.h"
+#include "scriptinterface/ScriptRequest.h"
 
-#include <string_view>
+#include <SDL_clipboard.h>
+#include <SDL_events.h>
+#include <SDL_keyboard.h>
+#include <SDL_keycode.h>
+#include <SDL_scancode.h>
+#include <SDL_stdinc.h>
+#include <algorithm>
+#include <cmath>
+#include <cstring>
+#include <cwchar>
+#include <iterator>
+#include <js/RootingAPI.h>
+#include <js/TypeDecls.h>
+#include <js/Value.h>
+#include <unordered_map>
+#include <utility>
 #include <vector>
-#include <wctype.h>
 
 namespace
 {
@@ -51,8 +76,6 @@ namespace
 // For text being typed into the console.
 constexpr int CONSOLE_BUFFER_SIZE = 1024;
 
-const char* CONSOLE_FONT = "mono-10";
-
 } // anonymous namespace
 
 CConsole* g_Console = 0;
@@ -84,31 +107,33 @@ CConsole::~CConsole() = default;
 
 void CConsole::Init()
 {
+	PROFILE2("CConsole::Init");
 	// Initialise console history file
-	m_MaxHistoryLines = 200;
-	CFG_GET_VAL("console.history.size", m_MaxHistoryLines);
+	m_MaxHistoryLines = g_ConfigDB.Get("console.history.size", 200);
+	m_HistoryIgnoreDuplicates = g_ConfigDB.Get("console.history.ignore_duplicates", true);
+	m_consoleFont = g_ConfigDB.Get("console.font", std::string{"mono-10"});
 
 	m_HistoryFile = L"config/console.txt";
 	LoadHistory();
 
 	UpdateScreenSize(g_xres, g_yres);
 
-	// Calculate and store the line spacing
-	const CFontMetrics font{CStrIntern(CONSOLE_FONT)};
-	m_FontHeight = font.GetLineSpacing();
+	// Calculate and store the line spacing.
+	const CFontMetrics font{CStrIntern(m_consoleFont)};
+	m_FontHeight = font.GetHeight();
 	m_FontWidth = font.GetCharacterWidth(L'C');
 	m_CharsPerPage = static_cast<size_t>(g_xres / m_FontWidth);
-	// Offset by an arbitrary amount, to make it fit more nicely
-	m_FontOffset = 7;
+	// Fonts constains two dimensions: the full height, and the cap height.
+	// We are adding some offset to move the text up a bit, so it looks better in the console.
+	m_FontOffset = font.GetCapHeight() / 2.f;
 
-	m_CursorBlinkRate = 0.5;
-	CFG_GET_VAL("gui.cursorblinkrate", m_CursorBlinkRate);
+	m_CursorBlinkRate = g_ConfigDB.Get("gui.cursorblinkrate", 0.5);
 }
 
 void CConsole::UpdateScreenSize(int w, int h)
 {
-	m_X = 0;
-	m_Y = 0;
+	m_X = 0.0f;
+	m_Y = 0.0f;
 	float height = h * 0.6f;
 	m_Width = w / g_VideoMode.GetScale();
 	m_Height = height / g_VideoMode.GetScale();
@@ -196,12 +221,12 @@ void CConsole::Render(CCanvas2D& canvas)
 	if (!(m_Visible || m_Toggle))
 		return;
 
-	PROFILE3_GPU("console");
+	PROFILE3("console");
 
 	DrawWindow(canvas);
 
 	CTextRenderer textRenderer;
-	textRenderer.SetCurrentFont(CStrIntern(CONSOLE_FONT));
+	textRenderer.SetCurrentFont(CStrIntern{m_consoleFont}, CStrIntern{});
 	// Animation: slide in from top of screen.
 	const float deltaY = (1.0f - m_VisibleFrac) * m_Height;
 	textRenderer.Translate(m_X, m_Y - deltaY);
@@ -225,18 +250,18 @@ void CConsole::DrawWindow(CCanvas2D& canvas)
 	for (CVector2D& point : points)
 		point += CVector2D{m_X, m_Y - (1.0f - m_VisibleFrac) * m_Height};
 
-	canvas.DrawRect(CRect(points[1], points[3]), CColor(0.0f, 0.0f, 0.5f, 0.6f));
-	canvas.DrawLine(points, 1.0f, CColor(0.5f, 0.5f, 0.0f, 0.6f));
+	canvas.DrawRect(CRect(points[1], points[3]), CColor(0.05f, 0.05f, 0.2f, 0.85f));
+	canvas.DrawLine(points, 1.0f, CColor(0.5f, 0.5f, 0.0f, 0.85f));
 
-	if (m_Height > m_FontHeight + 4)
+	if (m_Height > m_FontHeight + 2.0f * m_FontOffset)
 	{
 		points = {
-			CVector2D{0.0f, m_Height - static_cast<float>(m_FontHeight) - 4.0f},
-			CVector2D{m_Width, m_Height - static_cast<float>(m_FontHeight) - 4.0f}
+			CVector2D{0.0f, m_Height - m_FontHeight - 2.0f * m_FontOffset},
+			CVector2D{m_Width, m_Height - m_FontHeight - 2.0f * m_FontOffset}
 		};
 		for (CVector2D& point : points)
 			point += CVector2D{m_X, m_Y - (1.0f - m_VisibleFrac) * m_Height};
-		canvas.DrawLine(points, 1.0f, CColor(0.5f, 0.5f, 0.0f, 0.6f));
+		canvas.DrawLine(points, 1.0f, CColor(0.5f, 0.5f, 0.0f, 0.85f));
 	}
 }
 
@@ -259,7 +284,7 @@ void CConsole::DrawHistory(CTextRenderer& textRenderer)
 		{
 			textRenderer.Put(
 				9.0f,
-				m_Height - static_cast<float>(m_FontOffset) - static_cast<float>(m_FontHeight) * (i - m_MsgHistPos + 1),
+				m_Height - 3.0f * m_FontOffset - m_FontHeight * (i - m_MsgHistPos + 1),
 				it->c_str());
 		}
 
@@ -275,7 +300,7 @@ void CConsole::DrawBuffer(CTextRenderer& textRenderer)
 
 	const CVector2D savedTranslate = textRenderer.GetTranslate();
 
-	textRenderer.Translate(2.0f, m_Height - static_cast<float>(m_FontOffset) + 1.0f);
+	textRenderer.Translate(2.0f, m_Height - m_FontOffset);
 
 	textRenderer.SetCurrentColor(CColor(1.0f, 1.0f, 0.0f, 1.0f));
 	textRenderer.PutAdvance(L"]");
@@ -416,7 +441,7 @@ void CConsole::InsertChar(const int szChar, const wchar_t cooked)
 		{
 			std::lock_guard<std::mutex> lock(m_Mutex); // needed for safe access to m_deqMsgHistory
 
-			const int linesShown = static_cast<int>(m_Height / m_FontHeight) - 4;
+			const int linesShown = static_cast<int>(std::ceil(m_Height / m_FontHeight)) - 4;
 			m_MsgHistPos = Clamp(static_cast<int>(m_MsgHistory.size()) - linesShown, 1, static_cast<int>(m_MsgHistory.size()));
 		}
 		else
@@ -579,9 +604,12 @@ void CConsole::ProcessBuffer(const wchar_t* szLine)
 
 	ENSURE(wcslen(szLine) < CONSOLE_BUFFER_SIZE);
 
-	m_BufHistory.push_front(szLine);
-	SaveHistory(); // Do this each line for the moment; if a script causes
-	               // a crash it's a useful record.
+	if (!m_HistoryIgnoreDuplicates || m_BufHistory.empty() || m_BufHistory.front() != szLine)
+	{
+		m_BufHistory.push_front(szLine);
+		SaveHistory(); // Do this each line for the moment; if a script causes
+		               // a crash it's a useful record.
+	}
 
 	// Process it as JavaScript
 	std::shared_ptr<ScriptInterface> pScriptInterface = g_GUI->GetActiveGUI()->GetScriptInterface();
