@@ -31,12 +31,16 @@
  * triggered. All with the hotkey name stored in ev.user.data1 as a const char*.
  */
 
-#include "CStr.h"
 #include "lib/input.h"
+#include "lib/types.h"
+#include "ps/CStr.h"
+#include "ps/containers/StaticVector.h"
 
 #include <unordered_map>
 #include <vector>
 
+struct SDL_Event_;
+
 // SDL_Scancode is an enum, we'll use an explicit int to avoid including SDL in this header.
 using SDL_Scancode_ = int;
 
@@ -64,7 +68,7 @@ struct SHotkeyMapping
 {
 	CStr name; // name of the hotkey
 	SKey primary; // the primary key
-	std::vector<SKey> required; // list of non-primary keys that must also be active
+	PS::StaticVector<SKey, 8> required; // list of non-primary keys that must also be active
 };
 
 typedef std::vector<SHotkeyMapping> KeyMapping;
