@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -26,9 +26,11 @@
 #include "ps/CStr.h"
 #include "ps/Singleton.h"
 
+#include <cstddef>
 #include <vector>
 
 class CCanvas2D;
+struct SDL_Event_;
 
 /**
  * Struct ProfileColumn: Describes one column of an AbstractProfileTable.
@@ -119,7 +121,7 @@ public:
 	 *
 	 * @return true if the row should be highlighted in a special color.
 	 */
-	virtual bool IsHighlightRow(size_t row) { UNUSED2(row); return false; }
+	virtual bool IsHighlightRow(size_t /*row*/) { return false; }
 };
 
 
