@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,13 +18,16 @@
 #ifndef INCLUDED_SAVEDGAME
 #define INCLUDED_SAVEDGAME
 
-#include "ps/CStr.h"
-#include "scriptinterface/ScriptTypes.h"
+#include "lib/status.h"
 #include "scriptinterface/StructuredClone.h"
 
+#include <js/Value.h>
 #include <optional>
+#include <string>
 
 class CSimulation2;
+class CStrW;
+class ScriptInterface;
 
 /**
  * @file
