@@ -1,4 +1,4 @@
-/* Copyright (C) 2023 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -21,8 +21,12 @@
 #include "lib/file/vfs/vfs_path.h"
 #include "lib/os_path.h"
 #include "lib/status.h"
+#include "lib/types.h"
 #include "ps/CStr.h"
 
+#include <cstddef>
+#include <string>
+
 class Tex;
 
 const wchar_t* ErrorString(int err);
