@@ -19,7 +19,13 @@
 
 #include "JSInterface_Game.h"
 
+#include "graphics/HeightMipmap.h"
 #include "graphics/Terrain.h"
+#include "lib/config2.h"
+#include "lib/debug.h"
+#include "lib/file/vfs/vfs.h"
+#include "lib/os_path.h"
+#include "lib/path.h"
 #include "network/NetClient.h"
 #include "network/NetServer.h"
 #include "ps/CLogger.h"
@@ -29,10 +35,19 @@
 #include "ps/Replay.h"
 #include "ps/World.h"
 #include "scriptinterface/FunctionWrapper.h"
+#include "scriptinterface/ScriptRequest.h"
 #include "scriptinterface/StructuredClone.h"
-#include "simulation2/system/TurnManager.h"
 #include "simulation2/Simulation2.h"
-#include "soundmanager/SoundManager.h"
+#include "simulation2/system/TurnManager.h"
+#include "soundmanager/ISoundManager.h"
+
+#include <js/RootingAPI.h>
+#include <js/TypeDecls.h>
+#include <js/Value.h>
+#include <stdexcept>
+#include <string>
+
+class ScriptInterface;
 
 namespace JSI_Game
 {
@@ -67,7 +82,7 @@ int GetPlayerID()
 	return g_Game->GetPlayerID();
 }
 
-void SetPlayerID(const ScriptRequest& rq, int id)
+void SetPlayerID(int id)
 {
 	if (!g_Game)
 		return;
@@ -79,10 +94,10 @@ void SetPlayerID(const ScriptRequest& rq, int id)
 	if (g_Game->CheatsEnabled() || g_Game->IsVisualReplay())
 		g_Game->SetPlayerID(id);
 	else
-		ScriptException::Raise(rq, "Changing player ID with cheats disabled is prohibited");
+		throw std::logic_error{"Changing player ID with cheats disabled is prohibited"};
 }
 
-void SetViewedPlayer(const ScriptRequest& rq, int id)
+void SetViewedPlayer(int id)
 {
 	if (!g_Game || g_Game->GetViewedPlayerID() == id)
 		return;
@@ -92,7 +107,7 @@ void SetViewedPlayer(const ScriptRequest& rq, int id)
 	if (playerID == -1 || g_Game->CheatsEnabled() || g_Game->PlayerFinished(playerID) || g_Game->IsVisualReplay())
 		g_Game->SetViewedPlayerID(id);
 	else
-		ScriptException::Raise(rq, "Changing the perspective with cheats disabled is prohibited");
+		throw std::logic_error{"Changing the perspective with cheats disabled is prohibited"};
 }
 
 float GetSimRate()
@@ -113,24 +128,18 @@ int GetPendingTurns()
 	return g_Game->GetTurnManager()->GetPendingTurns();
 }
 
-bool IsPaused(const ScriptRequest& rq)
+bool IsPaused()
 {
 	if (!g_Game)
-	{
-		ScriptException::Raise(rq, "Game is not started");
-		return false;
-	}
+		throw std::logic_error{"Game is not started"};
 
 	return g_Game->m_Paused;
 }
 
-void SetPaused(const ScriptRequest& rq, bool pause, bool sendMessage)
+void SetPaused(bool pause, bool sendMessage)
 {
 	if (!g_Game)
-	{
-		ScriptException::Raise(rq, "Game is not started");
-		return;
-	}
+		throw std::logic_error{"Game is not started"};
 
 	g_Game->m_Paused = pause;
 
