@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -17,8 +17,14 @@
 
 #include "lib/self_test.h"
 
+#include "lib/utf8.h"
 #include "ps/CLogger.h"
 
+#include <cstddef>
+#include <sstream>
+#include <string>
+#include <vector>
+
 class TestCLogger : public CxxTest::TestSuite
 {
 public:
