@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -24,13 +24,14 @@
 #define INCLUDED_MODELVERTEXRENDERER
 
 #include "graphics/MeshManager.h"
-#include "graphics/ShaderProgramPtr.h"
-#include "ps/containers/Span.h"
-#include "renderer/backend/IDeviceCommandContext.h"
-#include "renderer/backend/IShaderProgram.h"
+
+#include <span>
 
 class CModel;
+class CModelDef;
 class CModelRData;
+namespace Renderer::Backend { class IDeviceCommandContext; }
+namespace Renderer::Backend { class IShaderProgram; }
 
 /**
  * Class ModelVertexRenderer: Normal ModelRenderer implementations delegate
@@ -84,7 +85,7 @@ public:
 	 */
 	virtual void UpdateModelsData(
 		Renderer::Backend::IDeviceCommandContext* deviceCommandContext,
-		PS::span<CModel*> models) = 0;
+		std::span<CModel*> models) = 0;
 
 	/**
 	 * Upload per-model data to backend.
@@ -100,7 +101,7 @@ public:
 	 */
 	virtual void UploadModelsData(
 		Renderer::Backend::IDeviceCommandContext* deviceCommandContext,
-		PS::span<CModel*> models) = 0;
+		std::span<CModel*> models) = 0;
 
 	/**
 	 * PrepareModelDef: Setup backend state for rendering of models that
