@@ -1,4 +1,4 @@
-/* Copyright (C) 2023 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -20,20 +20,24 @@
 
 #include "graphics/Patch.h"
 #include "graphics/RenderableObject.h"
+#include "lib/code_annotation.h"
+#include "lib/posix/posix_types.h"
+#include "lib/types.h"
+#include "maths/BoundingBoxAligned.h"
 #include "maths/Vector2D.h"
 #include "maths/Vector3D.h"
-#include "renderer/backend/IDeviceCommandContext.h"
-#include "renderer/backend/IShaderProgram.h"
 #include "renderer/VertexBufferManager.h"
 
+#include <cstddef>
 #include <vector>
 
-class CPatch;
 class CShaderDefines;
 class CSimulation2;
 class CTerrainTextureEntry;
 class CTextRenderer;
 class ShadowMap;
+namespace Renderer::Backend { class IDeviceCommandContext; }
+namespace Renderer::Backend { class IVertexInputLayout; }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////
 // CPatchRData: class encapsulating logic for rendering terrain patches; holds per
