@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -22,37 +22,48 @@
 #include "graphics/Camera.h"
 #include "graphics/Canvas2D.h"
 #include "graphics/Decal.h"
-#include "graphics/GameView.h"
-#include "graphics/LightEnv.h"
 #include "graphics/LOSTexture.h"
+#include "graphics/LightEnv.h"
 #include "graphics/Patch.h"
-#include "graphics/Model.h"
+#include "graphics/ShaderDefines.h"
 #include "graphics/ShaderManager.h"
-#include "graphics/TerritoryTexture.h"
+#include "graphics/ShaderTechnique.h"
+#include "graphics/ShaderTechniquePtr.h"
 #include "graphics/TextRenderer.h"
+#include "graphics/Texture.h"
 #include "graphics/TextureManager.h"
+#include "lib/debug.h"
+#include "maths/BoundingBoxAligned.h"
 #include "maths/MathUtil.h"
+#include "maths/Matrix3D.h"
 #include "maths/Vector2D.h"
+#include "maths/Vector3D.h"
 #include "ps/CLogger.h"
+#include "ps/CStrIntern.h"
 #include "ps/CStrInternStatic.h"
-#include "ps/Filesystem.h"
-#include "ps/Game.h"
 #include "ps/Profile.h"
-#include "ps/World.h"
-#include "renderer/backend/IDevice.h"
-#include "renderer/backend/PipelineState.h"
 #include "renderer/DecalRData.h"
 #include "renderer/PatchRData.h"
 #include "renderer/PostprocManager.h"
 #include "renderer/Renderer.h"
-#include "renderer/RenderingOptions.h"
+#include "renderer/Scene.h"
 #include "renderer/SceneRenderer.h"
 #include "renderer/ShadowMap.h"
 #include "renderer/SkyManager.h"
-#include "renderer/VertexArray.h"
 #include "renderer/WaterManager.h"
+#include "renderer/backend/Format.h"
+#include "renderer/backend/IDeviceCommandContext.h"
+#include "renderer/backend/IFramebuffer.h"
+#include "renderer/backend/IShaderProgram.h"
+#include "renderer/backend/PipelineState.h"
 
+#include <array>
+#include <cmath>
+#include <cstddef>
+#include <iterator>
 #include <memory>
+#include <string>
+#include <vector>
 
 /**
  * TerrainRenderer keeps track of which phase it is in, to detect
@@ -294,22 +305,7 @@ void TerrainRenderer::PrepareShader(
 		shader->GetBindingSlot(str_losTransform),
 		los.GetTextureMatrix()[0], los.GetTextureMatrix()[12]);
 
-	deviceCommandContext->SetUniform(
-		shader->GetBindingSlot(str_ambient),
-		lightEnv.m_AmbientColor.AsFloatArray());
-	deviceCommandContext->SetUniform(
-		shader->GetBindingSlot(str_sunColor),
-		lightEnv.m_SunColor.AsFloatArray());
-	deviceCommandContext->SetUniform(
-		shader->GetBindingSlot(str_sunDir),
-		lightEnv.GetSunDir().AsFloatArray());
-
-	deviceCommandContext->SetUniform(
-		shader->GetBindingSlot(str_fogColor),
-		lightEnv.m_FogColor.AsFloatArray());
-	deviceCommandContext->SetUniform(
-		shader->GetBindingSlot(str_fogParams),
-		lightEnv.m_FogFactor, lightEnv.m_FogMax);
+	lightEnv.Bind(deviceCommandContext, shader);
 }
 
 void TerrainRenderer::RenderTerrainShader(
@@ -443,7 +439,7 @@ bool TerrainRenderer::RenderFancyWater(
 	Renderer::Backend::IDeviceCommandContext* deviceCommandContext,
 	const CShaderDefines& context, int cullGroup, ShadowMap* shadow)
 {
-	PROFILE3_GPU("fancy water");
+	PROFILE3("fancy water");
 	GPU_SCOPED_LABEL(deviceCommandContext, "Render fancy water");
 
 	CSceneRenderer& sceneRenderer = g_Renderer.GetSceneRenderer();
@@ -573,12 +569,6 @@ bool TerrainRenderer::RenderFancyWater(
 			waterManager.m_ReflectionMatrix.AsFloatArray());
 	}
 
-	deviceCommandContext->SetUniform(
-		fancyWaterShader->GetBindingSlot(str_ambient), lightEnv.m_AmbientColor.AsFloatArray());
-	deviceCommandContext->SetUniform(
-		fancyWaterShader->GetBindingSlot(str_sunDir), lightEnv.GetSunDir().AsFloatArray());
-	deviceCommandContext->SetUniform(
-		fancyWaterShader->GetBindingSlot(str_sunColor), lightEnv.m_SunColor.AsFloatArray());
 	deviceCommandContext->SetUniform(
 		fancyWaterShader->GetBindingSlot(str_color), waterManager.m_WaterColor.AsFloatArray());
 	deviceCommandContext->SetUniform(
@@ -599,12 +589,8 @@ bool TerrainRenderer::RenderFancyWater(
 		fancyWaterShader->GetBindingSlot(str_cameraPos),
 		camera.GetOrientation().GetTranslation().AsFloatArray());
 
-	deviceCommandContext->SetUniform(
-		fancyWaterShader->GetBindingSlot(str_fogColor),
-		lightEnv.m_FogColor.AsFloatArray());
-	deviceCommandContext->SetUniform(
-		fancyWaterShader->GetBindingSlot(str_fogParams),
-		lightEnv.m_FogFactor, lightEnv.m_FogMax);
+	lightEnv.Bind(deviceCommandContext, fancyWaterShader);
+
 	deviceCommandContext->SetUniform(
 		fancyWaterShader->GetBindingSlot(str_time), static_cast<float>(time));
 	const float scale{g_Renderer.GetPostprocManager().IsEnabled()
@@ -660,7 +646,7 @@ void TerrainRenderer::RenderSimpleWater(
 	Renderer::Backend::IDeviceCommandContext* deviceCommandContext,
 	int cullGroup)
 {
-	PROFILE3_GPU("simple water");
+	PROFILE3("simple water");
 	GPU_SCOPED_LABEL(deviceCommandContext, "Render Simple Water");
 
 	const WaterManager& waterManager = g_Renderer.GetSceneRenderer().GetWaterManager();
@@ -781,7 +767,7 @@ void TerrainRenderer::RenderPriorities(CCanvas2D& canvas, int cullGroup)
 	ENSURE(m->phase == Phase_Render);
 
 	CTextRenderer textRenderer;
-	textRenderer.SetCurrentFont(CStrIntern("mono-stroke-10"));
+	textRenderer.SetCurrentFont(CStrIntern{"mono-stroke-10"}, CStrIntern{});
 	textRenderer.SetCurrentColor(CColor(1.0f, 1.0f, 0.0f, 1.0f));
 
 	std::vector<CPatchRData*>& visiblePatches = m->visiblePatches[cullGroup];
