@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,17 +19,30 @@
 
 #include "TexturedLineRData.h"
 
-#include "graphics/ShaderProgram.h"
+#include "graphics/Color.h"
 #include "graphics/Terrain.h"
+#include "graphics/TextureManager.h"
+#include "lib/debug.h"
 #include "maths/Frustum.h"
 #include "maths/MathUtil.h"
 #include "maths/Quaternion.h"
+#include "ps/CStrIntern.h"
 #include "ps/CStrInternStatic.h"
 #include "renderer/OverlayRenderer.h"
 #include "renderer/Renderer.h"
-#include "simulation2/Simulation2.h"
-#include "simulation2/system/SimContext.h"
+#include "renderer/VertexBuffer.h"
+#include "renderer/backend/Format.h"
+#include "renderer/backend/IBuffer.h"
+#include "renderer/backend/IDeviceCommandContext.h"
+#include "renderer/backend/IShaderProgram.h"
 #include "simulation2/components/ICmpWaterManager.h"
+#include "simulation2/system/Component.h"
+#include "simulation2/system/Entity.h"
+
+#include <array>
+#include <cmath>
+#include <cstddef>
+#include <cstdint>
 
 /* Note: this implementation uses CVertexBufferManager directly rather than access it through the nicer VertexArray interface,
  * because it allows you to work with variable amounts of vertices and indices more easily. New code should prefer
@@ -385,7 +398,7 @@ void CTexturedLineRData::CreateLineCap(const SOverlayTexturedLine& line, const C
 			radius *= 1.5f; // make it a bit sharper (note that we don't use the radius for the butt-end corner points so it should be ok)
 			centerVertex.m_UV.X = 0.480f; // slight visual correction to make the texture match up better at the corner points
 		}
-		FALLTHROUGH;
+		[[fallthrough]];
 	case SOverlayTexturedLine::LINECAP_ROUND:
 		{
 			// Draw a rounded line cap in the 3D plane of the line specified by the two corner points and the normal vector of the
