@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,13 +19,15 @@
 
 #include "Device.h"
 
-#include "lib/external_libraries/libsdl.h"
-#include "lib/hash.h"
+#include "lib/alignment.h"
+#include "lib/build_version.h"
+#include "lib/debug.h"
 #include "lib/sysdep/os.h"
-#include "maths/MathUtil.h"
 #include "ps/CLogger.h"
 #include "ps/ConfigDB.h"
 #include "ps/Profile.h"
+#include "ps/containers/StaticVector.h"
+#include "renderer/backend/Format.h"
 #include "renderer/backend/vulkan/Buffer.h"
 #include "renderer/backend/vulkan/DescriptorManager.h"
 #include "renderer/backend/vulkan/DeviceCommandContext.h"
@@ -41,18 +43,21 @@
 #include "renderer/backend/vulkan/SwapChain.h"
 #include "renderer/backend/vulkan/Texture.h"
 #include "renderer/backend/vulkan/Utilities.h"
-#include "scriptinterface/JSON.h"
 #include "scriptinterface/Object.h"
-#include "scriptinterface/ScriptInterface.h"
 #include "scriptinterface/ScriptRequest.h"
 
+#include <SDL_version.h>
+#include <SDL_video.h>
 #include <algorithm>
+#include <array>
 #include <iterator>
+#include <js/RootingAPI.h>
+#include <js/Value.h>
 #include <limits>
 #include <string>
 #include <string_view>
-#include <type_traits>
 #include <vector>
+#include <vk_platform.h>
 
 // According to https://wiki.libsdl.org/SDL_Vulkan_LoadLibrary the following
 // functionality is supported since SDL 2.0.6.
@@ -72,6 +77,8 @@ namespace Vulkan
 namespace
 {
 
+constexpr size_t QUERY_POOL_SIZE{NUMBER_OF_FRAMES_IN_FLIGHT * 1024};
+
 std::vector<const char*> GetRequiredSDLExtensions(SDL_Window* window)
 {
 	if (!window)
@@ -129,7 +136,7 @@ VKAPI_ATTR VkBool32 VKAPI_CALL DebugCallback(
 	VkDebugUtilsMessageSeverityFlagBitsEXT messageSeverity,
 	VkDebugUtilsMessageTypeFlagsEXT messageType,
 	const VkDebugUtilsMessengerCallbackDataEXT* callbackData,
-	void* UNUSED(userData))
+	void* /*userData*/)
 {
 	if ((messageSeverity & VK_DEBUG_UTILS_MESSAGE_SEVERITY_VERBOSE_BIT_EXT) || (messageSeverity & VK_DEBUG_UTILS_MESSAGE_SEVERITY_INFO_BIT_EXT))
 		LOGMESSAGE("Vulkan: %s", callbackData->pMessage);
@@ -200,12 +207,9 @@ std::unique_ptr<CDevice> CDevice::Create(SDL_Window* window)
 	device->m_Window = window;
 
 #ifdef NDEBUG
-	bool enableDebugMessages = false;
-	CFG_GET_VAL("renderer.backend.debugmessages", enableDebugMessages);
-	bool enableDebugLabels = false;
-	CFG_GET_VAL("renderer.backend.debuglabels", enableDebugLabels);
-	bool enableDebugScopedLabels = false;
-	CFG_GET_VAL("renderer.backend.debugscopedlabels", enableDebugScopedLabels);
+	bool enableDebugMessages{g_ConfigDB.Get("renderer.backend.debugmessages", false)};
+	bool enableDebugLabels{g_ConfigDB.Get("renderer.backend.debuglabels", false)};
+	bool enableDebugScopedLabels{g_ConfigDB.Get("renderer.backend.debugscopedlabels", false)};
 #else
 	bool enableDebugMessages = true;
 	bool enableDebugLabels = true;
@@ -222,7 +226,7 @@ std::unique_ptr<CDevice> CDevice::Create(SDL_Window* window)
 	VkApplicationInfo applicationInfo{};
 	applicationInfo.sType = VK_STRUCTURE_TYPE_APPLICATION_INFO;
 	applicationInfo.pApplicationName = "0 A.D.";
-	applicationInfo.applicationVersion = VK_MAKE_VERSION(0, 0, 27);
+	applicationInfo.applicationVersion = VK_MAKE_VERSION(PS_VERSION_MAJOR, PS_VERSION_MINOR, PS_VERSION_PATCH);
 	applicationInfo.pEngineName = "Pyrogenesis";
 	applicationInfo.engineVersion = applicationInfo.applicationVersion;
 	applicationInfo.apiVersion = VK_API_VERSION_1_1;
@@ -241,8 +245,7 @@ std::unique_ptr<CDevice> CDevice::Create(SDL_Window* window)
 	};
 
 #ifdef NDEBUG
-	bool enableDebugContext = false;
-	CFG_GET_VAL("renderer.backend.debugcontext", enableDebugContext);
+	bool enableDebugContext{g_ConfigDB.Get("renderer.backend.debugcontext", false)};
 #else
 	bool enableDebugContext = true;
 #endif
@@ -389,28 +392,36 @@ std::unique_ptr<CDevice> CDevice::Create(SDL_Window* window)
 		return nullptr;
 	}
 
-	int deviceIndexOverride = -1;
-	CFG_GET_VAL("renderer.backend.vulkan.deviceindexoverride", deviceIndexOverride);
-	auto choosedDeviceIt = device->m_AvailablePhysicalDevices.end();
+	const int deviceIndexOverride{g_ConfigDB.Get("renderer.backend.vulkan.deviceindexoverride", -1)};
+	auto chosenDeviceIt = device->m_AvailablePhysicalDevices.end();
 	if (deviceIndexOverride >= 0)
 	{
-		choosedDeviceIt = std::find_if(
+		chosenDeviceIt = std::find_if(
 			device->m_AvailablePhysicalDevices.begin(), device->m_AvailablePhysicalDevices.end(),
 			[deviceIndexOverride](const SAvailablePhysicalDevice& availableDevice)
 			{
 				return availableDevice.index == static_cast<uint32_t>(deviceIndexOverride);
 			});
-		if (choosedDeviceIt == device->m_AvailablePhysicalDevices.end())
+		if (chosenDeviceIt == device->m_AvailablePhysicalDevices.end())
 			LOGWARNING("Device with override index %d not found.", deviceIndexOverride);
 	}
-	if (choosedDeviceIt == device->m_AvailablePhysicalDevices.end())
+	if (chosenDeviceIt == device->m_AvailablePhysicalDevices.end())
 	{
-		// We need to choose the best available device fits our needs.
-		choosedDeviceIt = min_element(
-			availablePhyscialDevices.begin(), availablePhyscialDevices.end(),
-			ComparePhysicalDevices);
+		const bool chooseBestDevice{g_ConfigDB.Get("renderer.backend.vulkan.choosebestdevice", false)};
+		if (chooseBestDevice)
+		{
+			// We need to choose the best available device fits our needs.
+			chosenDeviceIt = min_element(
+				availablePhyscialDevices.begin(), availablePhyscialDevices.end(),
+				ComparePhysicalDevices);
+		}
+		else
+		{
+			// By default we assume that the Vulkan driver provides a decent default.
+			chosenDeviceIt = availablePhyscialDevices.begin();
+		}
 	}
-	device->m_ChoosenDevice = *choosedDeviceIt;
+	device->m_ChoosenDevice = *chosenDeviceIt;
 	const SAvailablePhysicalDevice& choosenDevice = device->m_ChoosenDevice;
 	device->m_AvailablePhysicalDevices.erase(std::remove_if(
 		device->m_AvailablePhysicalDevices.begin(), device->m_AvailablePhysicalDevices.end(),
@@ -578,7 +589,6 @@ std::unique_ptr<CDevice> CDevice::Create(SDL_Window* window)
 	capabilities.debugScopedLabels = enableDebugScopedLabels;
 	capabilities.S3TC = choosenDevice.features.textureCompressionBC;
 	capabilities.ARBShaders = false;
-	capabilities.ARBShadersShadow = false;
 	capabilities.computeShaders = true;
 	capabilities.storage = choosenDevice.properties.limits.maxStorageBufferRange >= GiB;
 	capabilities.instancing = true;
@@ -603,6 +613,14 @@ std::unique_ptr<CDevice> CDevice::Create(SDL_Window* window)
 	capabilities.maxAnisotropy = choosenDevice.properties.limits.maxSamplerAnisotropy;
 	capabilities.maxTextureSize =
 		choosenDevice.properties.limits.maxImageDimension2D;
+	capabilities.timestamps =
+		choosenDevice.properties.limits.timestampComputeAndGraphics
+		&& choosenDevice.properties.limits.timestampPeriod > 0;
+	if (capabilities.timestamps)
+	{
+		capabilities.timestampMultiplier =
+			device->m_ChoosenDevice.properties.limits.timestampPeriod / 1e9;
+	}
 
 	device->m_RenderPassManager =
 		std::make_unique<CRenderPassManager>(device.get());
@@ -613,9 +631,8 @@ std::unique_ptr<CDevice> CDevice::Create(SDL_Window* window)
 	if (!device->m_SubmitScheduler)
 		return nullptr;
 
-	bool disableDescriptorIndexing = false;
-	CFG_GET_VAL("renderer.backend.vulkan.disabledescriptorindexing", disableDescriptorIndexing);
-	const bool useDescriptorIndexing = hasNeededDescriptorIndexingFeatures && !disableDescriptorIndexing;
+	const bool useDescriptorIndexing{hasNeededDescriptorIndexingFeatures &&
+		!g_ConfigDB.Get("renderer.backend.vulkan.disabledescriptorindexing", false)};
 	device->m_DescriptorManager =
 		std::make_unique<CDescriptorManager>(device.get(), useDescriptorIndexing);
 
@@ -641,6 +658,19 @@ std::unique_ptr<CDevice> CDevice::Create(SDL_Window* window)
 
 	device->m_Extensions = choosenDevice.extensions;
 
+	if (device->m_Capabilities.timestamps)
+	{
+		VkQueryPoolCreateInfo queryPoolInfo{};
+		queryPoolInfo.sType = VK_STRUCTURE_TYPE_QUERY_POOL_CREATE_INFO;
+		queryPoolInfo.queryType = VK_QUERY_TYPE_TIMESTAMP;
+		queryPoolInfo.queryCount = QUERY_POOL_SIZE;
+
+		ENSURE_VK_SUCCESS(vkCreateQueryPool(
+			device->GetVkDevice(), &queryPoolInfo, nullptr, &device->m_QueryPool));
+
+		device->m_Queries.resize(QUERY_POOL_SIZE);
+	}
+
 	return device;
 }
 
@@ -658,6 +688,9 @@ CDevice::~CDevice()
 
 	m_SubmitScheduler.reset();
 
+	if (m_QueryPool)
+		vkDestroyQueryPool(GetVkDevice(), m_QueryPool, nullptr);
+
 	ProcessDeviceObjectToDestroyQueue(true);
 
 	m_RenderPassManager.reset();
@@ -722,7 +755,7 @@ std::unique_ptr<IComputePipelineState> CDevice::CreateComputePipelineState(
 }
 
 std::unique_ptr<IVertexInputLayout> CDevice::CreateVertexInputLayout(
-	const PS::span<const SVertexAttributeFormat> attributes)
+	const std::span<const SVertexAttributeFormat> attributes)
 {
 	return std::make_unique<CVertexInputLayout>(this, attributes);
 }
@@ -782,8 +815,6 @@ bool CDevice::AcquireNextBackbuffer()
 {
 	if (!IsSwapChainValid())
 	{
-		vkDeviceWaitIdle(m_Device);
-
 		RecreateSwapChain();
 		if (!IsSwapChainValid())
 			return false;
@@ -839,9 +870,9 @@ bool CDevice::IsTextureFormatSupported(const Format format) const
 	case Format::R8G8B8_UNORM:
 		return false;
 
-	case Format::BC1_RGB_UNORM: FALLTHROUGH;
-	case Format::BC1_RGBA_UNORM: FALLTHROUGH;
-	case Format::BC2_UNORM: FALLTHROUGH;
+	case Format::BC1_RGB_UNORM:
+	case Format::BC1_RGBA_UNORM:
+	case Format::BC2_UNORM:
 	case Format::BC3_UNORM:
 		if (m_Capabilities.S3TC)
 			return true;
@@ -902,6 +933,52 @@ Format CDevice::GetPreferredDepthStencilFormat(
 	return format;
 }
 
+uint32_t CDevice::AllocateQuery()
+{
+	ENSURE(m_Capabilities.timestamps);
+	auto it = std::find_if(
+		m_Queries.begin(), m_Queries.end(), [](const CDevice::Query& query)
+		{
+			return !query.occupied;
+		});
+	ENSURE(it != m_Queries.end());
+	it->occupied = true;
+	return std::distance(m_Queries.begin(), it);
+}
+
+void CDevice::FreeQuery(const uint32_t handle)
+{
+	ENSURE(handle < m_Queries.size());
+	ENSURE(m_Queries[handle].occupied);
+	m_Queries[handle].occupied = false;
+}
+
+bool CDevice::IsQueryResultAvailable(const uint32_t handle) const
+{
+	ENSURE(handle < m_Queries.size());
+	const Query& query{m_Queries[handle]};
+	ENSURE(query.occupied);
+	ENSURE(query.submitted);
+	if (query.lastUsageFrameID + NUMBER_OF_FRAMES_IN_FLIGHT > m_FrameID)
+		return false;
+	uint64_t data{};
+	return vkGetQueryPoolResults(
+		GetVkDevice(), m_QueryPool, handle, 1, sizeof(data), &data, 0, VK_QUERY_RESULT_64_BIT) != VK_NOT_READY;
+}
+
+uint64_t CDevice::GetQueryResult(const uint32_t handle)
+{
+	ENSURE(handle < m_Queries.size());
+	Query& query{m_Queries[handle]};
+	ENSURE(query.occupied);
+	ENSURE(query.submitted);
+	uint64_t data{};
+	ENSURE_VK_SUCCESS(vkGetQueryPoolResults(
+		GetVkDevice(), m_QueryPool, handle, 1, sizeof(data), &data, 0, VK_QUERY_RESULT_64_BIT | VK_QUERY_RESULT_WAIT_BIT));
+	query.submitted = false;
+	return data;
+}
+
 bool CDevice::IsFormatSupportedForUsage(const Format format, const uint32_t usage) const
 {
 	VkFormatProperties formatProperties{};
@@ -921,6 +998,17 @@ bool CDevice::IsFormatSupportedForUsage(const Format format, const uint32_t usag
 	return (formatProperties.optimalTilingFeatures & expectedFeatures) == expectedFeatures;
 }
 
+void CDevice::InsertTimestampQuery(VkCommandBuffer commandBuffer, const uint32_t handle, const bool isScopeBegin)
+{
+	ENSURE(handle < m_Queries.size());
+	vkCmdResetQueryPool(
+		commandBuffer, m_QueryPool, handle, 1);
+	vkCmdWriteTimestamp(
+		commandBuffer, isScopeBegin ? VK_PIPELINE_STAGE_TOP_OF_PIPE_BIT : VK_PIPELINE_STAGE_BOTTOM_OF_PIPE_BIT, m_QueryPool, handle);
+	m_Queries[handle].lastUsageFrameID = m_FrameID;
+	m_Queries[handle].submitted = true;
+}
+
 void CDevice::ScheduleObjectToDestroy(
 	VkObjectType type, const uint64_t handle, const VmaAllocation allocation)
 {
@@ -957,7 +1045,25 @@ std::unique_ptr<CRingCommandContext> CDevice::CreateRingCommandContext(const siz
 
 void CDevice::RecreateSwapChain()
 {
-	m_BackbufferReadbackTexture.reset();
+	if (m_SwapChain)
+	{
+		vkDeviceWaitIdle(m_Device);
+
+		// It seems some drivers might not reuse the same swapchain memory. So
+		// to avoid higher memory peaks destroy the old swapchain before.
+		const bool destroyOldSwapchainBefore{
+			g_ConfigDB.Get("renderer.backend.vulkan.destroyoldswapchainbefore", false)};
+		if (destroyOldSwapchainBefore)
+			m_SwapChain.reset();
+
+		m_BackbufferReadbackTexture.reset();
+
+		// Since we know there is no GPU work in progress we can free resources
+		// queued for deletion.
+		ProcessDeviceObjectToDestroyQueue(true);
+		ProcessObjectToDestroyQueue(true);
+	}
+
 	int surfaceDrawableWidth = 0, surfaceDrawableHeight = 0;
 	SDL_Vulkan_GetDrawableSize(m_Window, &surfaceDrawableWidth, &surfaceDrawableHeight);
 	m_SwapChain = CSwapChain::Create(
