@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,15 +19,23 @@
 
 #include "DeviceCommandContext.h"
 
+#include "graphics/Color.h"
 #include "lib/bits.h"
-#include "maths/MathUtil.h"
+#include "lib/debug.h"
 #include "ps/CLogger.h"
 #include "ps/ConfigDB.h"
-#include "ps/containers/Span.h"
 #include "ps/containers/StaticVector.h"
+#include "renderer/backend/Format.h"
+#include "renderer/backend/IBuffer.h"
+#include "renderer/backend/IFramebuffer.h"
+#include "renderer/backend/IShaderProgram.h"
+#include "renderer/backend/ITexture.h"
+#include "renderer/backend/PipelineState.h"
+#include "renderer/backend/Sampler.h"
 #include "renderer/backend/vulkan/Buffer.h"
 #include "renderer/backend/vulkan/DescriptorManager.h"
 #include "renderer/backend/vulkan/Device.h"
+#include "renderer/backend/vulkan/DeviceSelection.h"
 #include "renderer/backend/vulkan/Framebuffer.h"
 #include "renderer/backend/vulkan/Mapping.h"
 #include "renderer/backend/vulkan/PipelineState.h"
@@ -38,7 +46,10 @@
 
 #include <algorithm>
 #include <cstddef>
+#include <cstring>
+#include <iterator>
 #include <tuple>
+#include <utility>
 
 namespace Renderer
 {
@@ -100,7 +111,7 @@ class ScopedImageLayoutTransition
 {
 public:
 	ScopedImageLayoutTransition(
-		CRingCommandContext& commandContext, const PS::span<CTexture* const> textures,
+		CRingCommandContext& commandContext, const std::span<CTexture* const> textures,
 		const VkImageLayout layout, const VkAccessFlags accessMask, const VkPipelineStageFlags stageMask)
 		: m_CommandContext(commandContext), m_Textures(textures), m_Layout(layout),
 		m_AccessMask(accessMask), m_StageMask(stageMask)
@@ -135,7 +146,7 @@ public:
 
 private:
 	CRingCommandContext& m_CommandContext;
-	const PS::span<CTexture* const> m_Textures;
+	const std::span<CTexture* const> m_Textures;
 	const VkImageLayout m_Layout = VK_IMAGE_LAYOUT_UNDEFINED;
 	const VkAccessFlags m_AccessMask = 0;
 	const VkPipelineStageFlags m_StageMask = 0;
@@ -203,7 +214,7 @@ public:
 	CBuffer* GetBuffer() { return m_Buffer.get(); }
 
 	uint32_t ScheduleUpload(
-		VkCommandBuffer commandBuffer, const PS::span<const std::byte> data,
+		VkCommandBuffer commandBuffer, const std::span<const std::byte> data,
 		const uint32_t alignment);
 
 	void ExecuteUploads(VkCommandBuffer commandBuffer);
@@ -259,7 +270,7 @@ void CDeviceCommandContext::CUploadRing::ResizeIfNeeded(
 }
 
 uint32_t CDeviceCommandContext::CUploadRing::ScheduleUpload(
-	VkCommandBuffer commandBuffer, const PS::span<const std::byte> data,
+	VkCommandBuffer commandBuffer, const std::span<const std::byte> data,
 	const uint32_t alignment)
 {
 	ENSURE(data.size() > 0);
@@ -331,7 +342,7 @@ std::unique_ptr<IDeviceCommandContext> CDeviceCommandContext::Create(CDevice* de
 	deviceCommandContext->m_UniformUploadRing = std::make_unique<CUploadRing>(
 		device, IBuffer::Type::UNIFORM, UNIFORM_BUFFER_INITIAL_SIZE);
 
-	CFG_GET_VAL(
+	deviceCommandContext->m_DebugBarrierAfterFramebufferPass = g_ConfigDB.Get(
 		"renderer.backend.vulkan.debugbarrierafterframebufferpass",
 		deviceCommandContext->m_DebugBarrierAfterFramebufferPass);
 
@@ -595,9 +606,9 @@ void CDeviceCommandContext::BeginFramebufferPass(IFramebuffer* framebuffer)
 			m_Framebuffer->GetDepthStencilAttachmentLoadOp() == AttachmentLoadOp::CLEAR);
 	if (needsClearValues)
 	{
-		for (CTexture* colorAttachment : m_Framebuffer->GetColorAttachments())
+		const CFramebuffer::ColorAttachments& colorAttachments{m_Framebuffer->GetColorAttachments()};
+		std::for_each(colorAttachments.begin(), colorAttachments.end(), [&](CTexture*)
 		{
-			UNUSED2(colorAttachment);
 			const CColor& clearColor = m_Framebuffer->GetClearColor();
 			// The four array elements of the clear color map to R, G, B, and A
 			// components of image formats, in order.
@@ -606,7 +617,7 @@ void CDeviceCommandContext::BeginFramebufferPass(IFramebuffer* framebuffer)
 			clearValues.back().color.float32[1] = clearColor.g;
 			clearValues.back().color.float32[2] = clearColor.b;
 			clearValues.back().color.float32[3] = clearColor.a;
-		}
+		});
 		if (m_Framebuffer->GetDepthStencilAttachment())
 		{
 			clearValues.emplace_back();
@@ -808,7 +819,7 @@ void CDeviceCommandContext::SetVertexBufferData(
 
 	const uint32_t offset = m_VertexUploadRing->ScheduleUpload(
 		m_PrependCommandContext->GetCommandBuffer(),
-		PS::span<const std::byte>{static_cast<const std::byte*>(data), dataSize}, ALIGNMENT);
+		std::span<const std::byte>{static_cast<const std::byte*>(data), dataSize}, ALIGNMENT);
 	BindVertexBuffer(bindingSlot, m_VertexUploadRing->GetBuffer(), offset);
 }
 
@@ -825,7 +836,7 @@ void CDeviceCommandContext::SetIndexBufferData(
 
 	const uint32_t offset = m_IndexUploadRing->ScheduleUpload(
 		m_PrependCommandContext->GetCommandBuffer(),
-		PS::span<const std::byte>{static_cast<const std::byte*>(data), dataSize}, ALIGNMENT);
+		std::span<const std::byte>{static_cast<const std::byte*>(data), dataSize}, ALIGNMENT);
 	BindIndexBuffer(m_IndexUploadRing->GetBuffer(), offset);
 }
 
@@ -876,7 +887,7 @@ void CDeviceCommandContext::DrawIndexedInstanced(
 
 void CDeviceCommandContext::DrawIndexedInRange(
 	const uint32_t firstIndex, const uint32_t indexCount,
-	const uint32_t UNUSED(start), const uint32_t UNUSED(end))
+	const uint32_t /*start*/, const uint32_t /*end*/)
 {
 	DrawIndexed(firstIndex, indexCount, 0);
 }
@@ -1005,12 +1016,18 @@ void CDeviceCommandContext::SetUniform(
 }
 
 void CDeviceCommandContext::SetUniform(
-	const int32_t bindingSlot, PS::span<const float> values)
+	const int32_t bindingSlot, std::span<const float> values)
 {
 	ENSURE(m_InsidePass || m_InsideComputePass);
 	m_ShaderProgram->SetUniform(bindingSlot, values);
 }
 
+void CDeviceCommandContext::InsertTimestampQuery(const uint32_t handle, const bool isScopeBegin)
+{
+	ENSURE(!m_InsideFramebufferPass);
+	m_Device->InsertTimestampQuery(m_CommandContext->GetCommandBuffer(), handle, isScopeBegin);
+}
+
 void CDeviceCommandContext::BeginScopedLabel(const char* name)
 {
 	if (!m_DebugScopedLabels)
@@ -1140,7 +1157,7 @@ void CDeviceCommandContext::UpdateOutdatedConstants()
 			std::max(static_cast<VkDeviceSize>(16), m_Device->GetChoosenPhysicalDevice().properties.limits.minUniformBufferOffsetAlignment);
 		const uint32_t offset = m_UniformUploadRing->ScheduleUpload(
 			m_PrependCommandContext->GetCommandBuffer(),
-			PS::span<const std::byte>{
+			std::span<const std::byte>{
 				m_ShaderProgram->GetMaterialConstantsData(),
 				m_ShaderProgram->GetMaterialConstantsDataSize()}, alignment);
 		m_ShaderProgram->UpdateMaterialConstantsData();
