@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -20,21 +20,33 @@
 #include "ShaderProgram.h"
 
 #include "graphics/ShaderDefines.h"
+#include "lib/path.h"
+#include "lib/utf8.h"
 #include "ps/CLogger.h"
-#include "ps/containers/StaticVector.h"
 #include "ps/CStr.h"
 #include "ps/CStrInternStatic.h"
+#include "ps/Errors.h"
 #include "ps/Filesystem.h"
-#include "ps/Profile.h"
+#include "ps/XMB/XMBData.h"
+#include "ps/XMB/XMBStorage.h"
 #include "ps/XML/Xeromyces.h"
+#include "ps/containers/StaticVector.h"
+#include "renderer/backend/ITexture.h"
+#include "renderer/backend/vulkan/Buffer.h"
 #include "renderer/backend/vulkan/DescriptorManager.h"
 #include "renderer/backend/vulkan/Device.h"
+#include "renderer/backend/vulkan/DeviceSelection.h"
 #include "renderer/backend/vulkan/RingCommandContext.h"
 #include "renderer/backend/vulkan/Texture.h"
 #include "renderer/backend/vulkan/Utilities.h"
 
 #include <algorithm>
+#include <cstring>
+#include <iterator>
 #include <limits>
+#include <map>
+#include <string>
+#include <tuple>
 
 namespace Renderer
 {
@@ -264,7 +276,7 @@ std::unique_ptr<CShaderProgram> CShaderProgram::Create(
 				const uint32_t set = descriporSetsChild.GetAttributes().GetNamedItem(at_set).ToUInt();
 				if (useDescriptorIndexing && set == 0 && !descriporSetsChild.GetChildNodes().empty())
 				{
-					LOGERROR("Descritor set for descriptor indexing shouldn't contain bindings.");
+					LOGERROR("Descriptor set for descriptor indexing shouldn't contain bindings.");
 					return false;
 				}
 				XERO_ITER_EL(descriporSetsChild, descriporSetChild)
@@ -781,7 +793,7 @@ void CShaderProgram::SetUniform(
 	const float value)
 {
 	const float values[1] = {value};
-	SetUniform(bindingSlot, PS::span<const float>(values, values + 1));
+	SetUniform(bindingSlot, std::span<const float>(values, values + 1));
 }
 
 void CShaderProgram::SetUniform(
@@ -789,7 +801,7 @@ void CShaderProgram::SetUniform(
 	const float valueX, const float valueY)
 {
 	const float values[2] = {valueX, valueY};
-	SetUniform(bindingSlot, PS::span<const float>(values, values + 2));
+	SetUniform(bindingSlot, std::span<const float>(values, values + 2));
 }
 
 void CShaderProgram::SetUniform(
@@ -798,7 +810,7 @@ void CShaderProgram::SetUniform(
 	const float valueZ)
 {
 	const float values[3] = {valueX, valueY, valueZ};
-	SetUniform(bindingSlot, PS::span<const float>(values, values + 3));
+	SetUniform(bindingSlot, std::span<const float>(values, values + 3));
 }
 
 void CShaderProgram::SetUniform(
@@ -807,10 +819,10 @@ void CShaderProgram::SetUniform(
 	const float valueZ, const float valueW)
 {
 	const float values[4] = {valueX, valueY, valueZ, valueW};
-	SetUniform(bindingSlot, PS::span<const float>(values, values + 4));
+	SetUniform(bindingSlot, std::span<const float>(values, values + 4));
 }
 
-void CShaderProgram::SetUniform(const int32_t bindingSlot, PS::span<const float> values)
+void CShaderProgram::SetUniform(const int32_t bindingSlot, std::span<const float> values)
 {
 	if (bindingSlot < 0)
 		return;
