@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -21,34 +21,53 @@
 
 #include "graphics/MapReader.h"
 #include "graphics/Terrain.h"
-#include "lib/timer.h"
+#include "lib/debug.h"
+#include "lib/file/file_system.h"
 #include "lib/file/vfs/vfs_util.h"
+#include "lib/os_path.h"
+#include "lib/path.h"
+#include "lib/sysdep/filesystem.h"
+#include "lib/timer.h"
+#include "lib/types.h"
+#include "lib/utf8.h"
+#include "maths/Fixed.h"
 #include "maths/MathUtil.h"
 #include "ps/CLogger.h"
+#include "ps/CStr.h"
 #include "ps/ConfigDB.h"
+#include "ps/Errors.h"
 #include "ps/Filesystem.h"
 #include "ps/Loader.h"
 #include "ps/Profile.h"
+#include "ps/Profiler2.h"
 #include "ps/Pyrogenesis.h"
 #include "ps/Util.h"
-#include "ps/XML/Xeromyces.h"
 #include "scriptinterface/FunctionWrapper.h"
 #include "scriptinterface/JSON.h"
 #include "scriptinterface/Object.h"
 #include "scriptinterface/ScriptContext.h"
 #include "scriptinterface/ScriptInterface.h"
+#include "scriptinterface/ScriptRequest.h"
 #include "scriptinterface/StructuredClone.h"
 #include "simulation2/MessageTypes.h"
-#include "simulation2/system/ComponentManager.h"
-#include "simulation2/system/ParamNode.h"
-#include "simulation2/system/SimContext.h"
 #include "simulation2/components/ICmpAIManager.h"
 #include "simulation2/components/ICmpCommandQueue.h"
-#include "simulation2/components/ICmpTemplateManager.h"
+#include "simulation2/components/ICmpPathfinder.h"
+#include "simulation2/helpers/Player.h"
+#include "simulation2/helpers/SimulationCommand.h"
+#include "simulation2/system/Component.h"
 
+#include <algorithm>
+#include <cstddef>
+#include <cstdint>
 #include <fstream>
 #include <iomanip>
+#include <js/CallArgs.h>
+#include <js/RootingAPI.h>
+#include <js/Value.h>
 #include <memory>
+#include <set>
+#include <sstream>
 
 class CSimulation2Impl
 {
@@ -56,23 +75,18 @@ public:
 	CSimulation2Impl(CUnitManager* unitManager, ScriptContext& cx, CTerrain* terrain) :
 		m_SimContext{terrain, unitManager},
 		m_ComponentManager{m_SimContext, cx},
+		m_InitAttributes{cx.GetGeneralJSContext()},
 		m_MapSettings{cx.GetGeneralJSContext()},
-		m_InitAttributes{cx.GetGeneralJSContext()}
+		// Tests won't have config initialised
+		m_EnableOOSLog{CConfigDB::GetIfInitialised("ooslog", false)},
+		m_EnableSerializationTest{CConfigDB::GetIfInitialised("serializationtest", false)},
+		// Handle bogus values of the arg
+		m_RejoinTestTurn{std::max(CConfigDB::GetIfInitialised("rejointest", -1), -1)}
 	{
 		m_ComponentManager.LoadComponentTypes();
 
 		RegisterFileReloadFunc(ReloadChangedFileCB, this);
 
-		// Tests won't have config initialised
-		if (CConfigDB::IsInitialised())
-		{
-			CFG_GET_VAL("ooslog", m_EnableOOSLog);
-			CFG_GET_VAL("serializationtest", m_EnableSerializationTest);
-			CFG_GET_VAL("rejointest", m_RejoinTestTurn);
-			if (m_RejoinTestTurn < 0) // Handle bogus values of the arg
-				m_RejoinTestTurn = -1;
-		}
-
 		if (m_EnableOOSLog)
 		{
 			m_OOSLogPath = createDateIndexSubdirectory(psLogDir() / "oos_logs");
@@ -100,8 +114,8 @@ public:
 		componentManager.AddSystemComponents(skipScriptedComponents, skipAI);
 	}
 
-	static bool LoadDefaultScripts(CComponentManager& componentManager, std::set<VfsPath>* loadedScripts);
-	static bool LoadScripts(CComponentManager& componentManager, std::set<VfsPath>* loadedScripts, const VfsPath& path);
+	static void LoadDefaultScripts(CComponentManager& componentManager, std::set<VfsPath>* loadedScripts);
+	static void LoadScripts(CComponentManager& componentManager, std::set<VfsPath>* loadedScripts, const VfsPath& path);
 	static bool LoadTriggerScripts(CComponentManager& componentManager, JS::HandleValue mapSettings, std::set<VfsPath>* loadedScripts);
 	Status ReloadChangedFile(const VfsPath& path);
 
@@ -179,31 +193,27 @@ public:
 	}
 };
 
-bool CSimulation2Impl::LoadDefaultScripts(CComponentManager& componentManager, std::set<VfsPath>* loadedScripts)
+void CSimulation2Impl::LoadDefaultScripts(CComponentManager& componentManager, std::set<VfsPath>* loadedScripts)
 {
-	return (
-		LoadScripts(componentManager, loadedScripts, L"simulation/components/interfaces/") &&
-		LoadScripts(componentManager, loadedScripts, L"simulation/helpers/") &&
-		LoadScripts(componentManager, loadedScripts, L"simulation/components/")
-	);
+	LoadScripts(componentManager, loadedScripts, L"simulation/components/interfaces/");
+	LoadScripts(componentManager, loadedScripts, L"simulation/helpers/");
+	LoadScripts(componentManager, loadedScripts, L"simulation/components/");
 }
 
-bool CSimulation2Impl::LoadScripts(CComponentManager& componentManager, std::set<VfsPath>* loadedScripts, const VfsPath& path)
+void CSimulation2Impl::LoadScripts(CComponentManager& componentManager, std::set<VfsPath>* loadedScripts, const VfsPath& path)
 {
 	VfsPaths pathnames;
 	if (vfs::GetPathnames(g_VFS, path, L"*.js", pathnames) < 0)
-		return false;
+		throw CSimulation2::LoadScriptError{"Error enumerating " + path.string8()};
 
-	bool ok = true;
 	for (const VfsPath& scriptPath : pathnames)
 	{
 		if (loadedScripts)
 			loadedScripts->insert(scriptPath);
 		LOGMESSAGE("Loading simulation script '%s'", scriptPath.string8());
 		if (!componentManager.LoadScript(scriptPath))
-			ok = false;
+			throw CSimulation2::LoadScriptError{"Error loading " + scriptPath.string8()};
 	}
-	return ok;
 }
 
 bool CSimulation2Impl::LoadTriggerScripts(CComponentManager& componentManager, JS::HandleValue mapSettings, std::set<VfsPath>* loadedScripts)
@@ -411,11 +421,18 @@ void CSimulation2Impl::Update(int turnLength, const std::vector<SimulationComman
 		m_SecondaryComponentManager->LoadComponentTypes();
 
 		m_SecondaryLoadedScripts = std::make_unique<std::set<VfsPath>>();
-		ENSURE(LoadDefaultScripts(*m_SecondaryComponentManager, m_SecondaryLoadedScripts.get()));
+		LoadDefaultScripts(*m_SecondaryComponentManager, m_SecondaryLoadedScripts.get());
 		ResetComponentState(*m_SecondaryComponentManager, false, false);
 
 		ScriptRequest rq(scriptInterface);
 
+		// Clone InitAttributes.
+		{
+			const ScriptRequest rq2(m_SecondaryComponentManager->GetScriptInterface());
+			const JS::RootedValue initAttributesCloned(rq2.cx, Script::CloneValueFromOtherCompartment(m_SecondaryComponentManager->GetScriptInterface(), scriptInterface, m_InitAttributes));
+			m_SecondaryComponentManager->GetScriptInterface().SetGlobal("InitAttributes", initAttributesCloned, true, true, true);
+		}
+
 		// Load the trigger scripts after we have loaded the simulation.
 		{
 			ScriptRequest rq2(m_SecondaryComponentManager->GetScriptInterface());
@@ -624,14 +641,11 @@ void CSimulation2Impl::DumpState()
 ////////////////////////////////////////////////////////////////
 
 CSimulation2::CSimulation2(CUnitManager* unitManager, ScriptContext& cx, CTerrain* terrain) :
-	m(new CSimulation2Impl(unitManager, cx, terrain))
+	m(std::make_unique<CSimulation2Impl>(unitManager, cx, terrain))
 {
 }
 
-CSimulation2::~CSimulation2()
-{
-	delete m;
-}
+CSimulation2::~CSimulation2() = default;
 
 // Forward all method calls to the appropriate CSimulation2Impl/CComponentManager methods:
 
@@ -764,14 +778,14 @@ float CSimulation2::GetLastFrameOffset() const
 	return m->m_LastFrameOffset;
 }
 
-bool CSimulation2::LoadScripts(const VfsPath& path)
+void CSimulation2::LoadScripts(const VfsPath& path)
 {
-	return m->LoadScripts(m->m_ComponentManager, &m->m_LoadedScripts, path);
+	m->LoadScripts(m->m_ComponentManager, &m->m_LoadedScripts, path);
 }
 
-bool CSimulation2::LoadDefaultScripts()
+void CSimulation2::LoadDefaultScripts()
 {
-	return m->LoadDefaultScripts(m->m_ComponentManager, &m->m_LoadedScripts);
+	m->LoadDefaultScripts(m->m_ComponentManager, &m->m_LoadedScripts);
 }
 
 void CSimulation2::SetStartupScript(const std::string& code)
