@@ -1,4 +1,4 @@
-/* Copyright (C) 2023 Wildfire Games.
+/* Copyright (C) 2026 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -17,40 +17,77 @@
 
 #include "precompiled.h"
 
-#include "simulation2/system/Component.h"
 #include "ICmpAIManager.h"
 
-#include "simulation2/MessageTypes.h"
-
-#include "graphics/Terrain.h"
-#include "lib/timer.h"
-#include "lib/tex/tex.h"
+#include "graphics/HeightMipmap.h"
+#include "lib/alignment.h"
 #include "lib/allocators/shared_ptr.h"
+#include "lib/code_annotation.h"
+#include "lib/debug.h"
+#include "lib/file/vfs/vfs_path.h"
+#include "lib/file/vfs/vfs_util.h"
+#include "lib/os_path.h"
+#include "lib/path.h"
+#include "lib/tex/tex.h"
+#include "lib/types.h"
+#include "lib/utf8.h"
+#include "maths/FixedVector2D.h"
 #include "ps/CLogger.h"
 #include "ps/Filesystem.h"
 #include "ps/Profile.h"
-#include "ps/scripting/JSInterface_VFS.h"
+#include "ps/Profiler2.h"
 #include "ps/TemplateLoader.h"
 #include "ps/Util.h"
+#include "ps/scripting/JSInterface_VFS.h"
 #include "scriptinterface/FunctionWrapper.h"
 #include "scriptinterface/JSON.h"
+#include "scriptinterface/ModuleLoader.h"
 #include "scriptinterface/Object.h"
 #include "scriptinterface/ScriptContext.h"
+#include "scriptinterface/ScriptConversions.h"
+#include "scriptinterface/ScriptInterface.h"
+#include "scriptinterface/ScriptRequest.h"
 #include "scriptinterface/StructuredClone.h"
 #include "simulation2/components/ICmpAIInterface.h"
 #include "simulation2/components/ICmpCommandQueue.h"
-#include "simulation2/components/ICmpObstructionManager.h"
+#include "simulation2/components/ICmpPathfinder.h"
 #include "simulation2/components/ICmpRangeManager.h"
 #include "simulation2/components/ICmpTemplateManager.h"
 #include "simulation2/components/ICmpTerritoryManager.h"
+#include "simulation2/helpers/Grid.h"
 #include "simulation2/helpers/HierarchicalPathfinder.h"
 #include "simulation2/helpers/LongPathfinder.h"
+#include "simulation2/helpers/PathGoal.h"
+#include "simulation2/helpers/Pathfinding.h"
+#include "simulation2/helpers/Player.h"
 #include "simulation2/serialization/DebugSerializer.h"
+#include "simulation2/serialization/SerializeTemplates.h"
 #include "simulation2/serialization/SerializedTypes.h"
 #include "simulation2/serialization/StdDeserializer.h"
 #include "simulation2/serialization/StdSerializer.h"
+#include "simulation2/system/Component.h"
 
-extern void QuitEngine();
+#include <boost/random/linear_congruential.hpp>
+#include <cstring>
+#include <js/Array.h>
+#include <js/GCAPI.h>
+#include <js/GCVector.h>
+#include <js/PropertyAndElement.h>
+#include <js/RootingAPI.h>
+#include <js/TracingAPI.h>
+#include <js/TypeDecls.h>
+#include <js/Value.h>
+#include <js/experimental/TypedData.h>
+#include <map>
+#include <memory>
+#include <set>
+#include <sstream>
+#include <string>
+#include <tuple>
+#include <utility>
+#include <vector>
+
+extern void QuitEngine(int exitStatus);
 
 /**
  * @file
@@ -93,10 +130,6 @@ private:
 
 		bool Initialise()
 		{
-			// LoadScripts will only load each script once even though we call it for each player
-			if (!m_Worker.LoadScripts(m_AIName))
-				return false;
-
 			ScriptRequest rq(m_ScriptInterface);
 
 			OsPath path = L"simulation/ai/" + m_AIName + L"/data.json";
@@ -109,24 +142,23 @@ private:
 			}
 
 			// Get the constructor name from the metadata
-			std::string moduleName;
+			std::string filename;
 			std::string constructor;
-			JS::RootedValue objectWithConstructor(rq.cx); // object that should contain the constructor function
-			JS::RootedValue global(rq.cx, rq.globalValue());
 			JS::RootedValue ctor(rq.cx);
-			if (!Script::HasProperty(rq, metadata, "moduleName"))
+			if (!Script::HasProperty(rq, metadata, "filename"))
 			{
-				LOGERROR("Failed to create AI player: %s: missing 'moduleName'", path.string8());
+				LOGERROR("Failed to create AI player: %s: missing 'filename'", path.string8());
 				return false;
 			}
 
-			Script::GetProperty(rq, metadata, "moduleName", moduleName);
-			if (!Script::GetProperty(rq, global, moduleName.c_str(), &objectWithConstructor)
-			    || objectWithConstructor.isUndefined())
-			{
-				LOGERROR("Failed to create AI player: %s: can't find the module that should contain the constructor: '%s'", path.string8(), moduleName);
-				return false;
-			}
+			Script::GetProperty(rq, metadata, "filename", filename);
+
+
+			auto result = m_ScriptInterface->GetModuleLoader().LoadModule(rq,
+				"simulation/ai/" + utf8_from_wstring(m_AIName) + "/" + filename);
+
+			g_ScriptContext->RunJobs();
+			JS::RootedValue objectWithConstructor(rq.cx, JS::ObjectValue(*result.begin()->Get()));
 
 			if (!Script::GetProperty(rq, metadata, "constructor", constructor))
 			{
@@ -160,7 +192,7 @@ private:
 			}
 
 			JS::RootedValueVector argv(rq.cx);
-			ignore_result(argv.append(settings.get()));
+			std::ignore = argv.append(settings.get());
 			m_ScriptInterface->CallConstructor(ctor, argv, &m_Obj);
 
 			if (m_Obj.get().isNull())
@@ -232,7 +264,11 @@ public:
 	{
 		// Create the script interface in the same compartment as the simulation interface.
 		// This will allow us to directly share data from the sim to the AI (and vice versa, should the need arise).
-		m_ScriptInterface = std::make_shared<ScriptInterface>("Engine", "AI", simInterface);
+		m_ScriptInterface = std::make_shared<ScriptInterface>("Engine", "AI", simInterface,
+			[](const VfsPath& path)
+			{
+				return path.string().find(L"simulation/ai/") == 0;
+			});
 
 		ScriptRequest rq(m_ScriptInterface);
 
@@ -261,7 +297,6 @@ public:
 	ScriptFunction::Register<&CAIWorker::func, ScriptInterface::ObjectFromCBData<CAIWorker>>(rq, name);
 
 		REGISTER_FUNC_NAME(PostCommand, "PostCommand");
-		REGISTER_FUNC_NAME(LoadScripts, "IncludeModule");
 		ScriptFunction::Register<QuitEngine>(rq, "Exit");
 
 		REGISTER_FUNC_NAME(ComputePathScript, "ComputePath");
@@ -280,35 +315,6 @@ public:
 
 	bool HasLoadedEntityTemplates() const { return m_HasLoadedEntityTemplates; }
 
-	bool LoadScripts(const std::wstring& moduleName)
-	{
-		// Ignore modules that are already loaded
-		if (m_LoadedModules.find(moduleName) != m_LoadedModules.end())
-			return true;
-
-		// Mark this as loaded, to prevent it recursively loading itself
-		m_LoadedModules.insert(moduleName);
-
-		// Load and execute *.js
-		VfsPaths pathnames;
-		if (vfs::GetPathnames(g_VFS, L"simulation/ai/" + moduleName + L"/", L"*.js", pathnames) < 0)
-		{
-			LOGERROR("Failed to load AI scripts for module %s", utf8_from_wstring(moduleName));
-			return false;
-		}
-
-		for (const VfsPath& path : pathnames)
-		{
-			if (!m_ScriptInterface->LoadGlobalScriptFile(path))
-			{
-				LOGERROR("Failed to load script %s", path.string8());
-				return false;
-			}
-		}
-
-		return true;
-	}
-
 	void PostCommand(int playerid, JS::HandleValue cmd)
 	{
 		ScriptRequest rq(m_ScriptInterface);
@@ -406,30 +412,21 @@ public:
 		ScriptRequest rq(m_ScriptInterface);
 
 		// we don't need to load it.
-		if (!m_HasSharedComponent)
+		if (!std::exchange(m_HasSharedComponent, true))
 			return false;
 
-		// reset the value so it can be used to determine if we actually initialized it.
-		m_HasSharedComponent = false;
+		auto result = m_ScriptInterface->GetModuleLoader().LoadModule(rq,
+			"simulation/ai/common-api/shared.js");
 
-		if (LoadScripts(L"common-api"))
-			m_HasSharedComponent = true;
-		else
-			return false;
+		g_ScriptContext->RunJobs();
 
 		// mainly here for the error messages
 		OsPath path = L"simulation/ai/common-api/";
 
 		// Constructor name is SharedScript, it's in the module API3
 		// TODO: Hardcoding this is bad, we need a smarter way.
-		JS::RootedValue AIModule(rq.cx);
-		JS::RootedValue global(rq.cx, rq.globalValue());
+		JS::RootedValue AIModule(rq.cx, JS::ObjectValue(*result.begin()->Get()));
 		JS::RootedValue ctor(rq.cx);
-		if (!Script::GetProperty(rq, global, "API3", &AIModule) || AIModule.isUndefined())
-		{
-			LOGERROR("Failed to create shared AI component: %s: can't find module '%s'", path.string8(), "API3");
-			return false;
-		}
 
 		if (!Script::GetProperty(rq, AIModule, "SharedScript", &ctor)
 		    || ctor.isUndefined())
@@ -459,7 +456,7 @@ public:
 			"templates", m_EntityTemplates);
 
 		JS::RootedValueVector argv(rq.cx);
-		ignore_result(argv.append(settings));
+		std::ignore = argv.append(settings);
 		m_ScriptInterface->CallConstructor(ctor, argv, &m_SharedAIObj);
 
 		if (m_SharedAIObj.get().isNull())
@@ -870,7 +867,7 @@ private:
 class CCmpAIManager final : public ICmpAIManager
 {
 public:
-	static void ClassInit(CComponentManager& UNUSED(componentManager))
+	static void ClassInit(CComponentManager&)
 	{
 	}
 
@@ -881,7 +878,7 @@ public:
 		return "<a:component type='system'/><empty/>";
 	}
 
-	void Init(const CParamNode& UNUSED(paramNode)) override
+	void Init(const CParamNode&) override
 	{
 		m_Worker.Init(GetSimContext().GetScriptInterface());
 
