@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -17,32 +17,60 @@
 
 #include "precompiled.h"
 
-#include "simulation2/system/Component.h"
 #include "ICmpRangeManager.h"
 
 #include "ICmpTerrain.h"
-#include "simulation2/system/EntityMap.h"
+#include "graphics/Color.h"
+#include "graphics/Overlay.h"
+#include "lib/debug.h"
+#include "lib/posix/posix_types.h"
+#include "lib/types.h"
+#include "maths/Fixed.h"
+#include "maths/FixedVector2D.h"
+#include "maths/FixedVector3D.h"
+#include "maths/MathUtil.h"
+#include "maths/Sqrt.h"
+#include "ps/CLogger.h"
+#include "ps/Profile.h"
+#include "renderer/Scene.h"
 #include "simulation2/MessageTypes.h"
 #include "simulation2/components/ICmpFogging.h"
 #include "simulation2/components/ICmpMirage.h"
+#include "simulation2/components/ICmpObstruction.h"
 #include "simulation2/components/ICmpOwnership.h"
+#include "simulation2/components/ICmpPathfinder.h"
 #include "simulation2/components/ICmpPosition.h"
-#include "simulation2/components/ICmpObstructionManager.h"
 #include "simulation2/components/ICmpTerritoryManager.h"
 #include "simulation2/components/ICmpVisibility.h"
 #include "simulation2/components/ICmpVision.h"
 #include "simulation2/components/ICmpWaterManager.h"
+#include "simulation2/helpers/Grid.h"
 #include "simulation2/helpers/Los.h"
 #include "simulation2/helpers/MapEdgeTiles.h"
+#include "simulation2/helpers/Pathfinding.h"
+#include "simulation2/helpers/Player.h"
+#include "simulation2/helpers/Position.h"
 #include "simulation2/helpers/Render.h"
 #include "simulation2/helpers/Spatial.h"
+#include "simulation2/serialization/SerializeTemplates.h"
 #include "simulation2/serialization/SerializedTypes.h"
+#include "simulation2/system/Component.h"
+#include "simulation2/system/Entity.h"
+#include "simulation2/system/EntityMap.h"
+#include "simulation2/system/Message.h"
 
-#include "graphics/Overlay.h"
-#include "lib/timer.h"
-#include "ps/CLogger.h"
-#include "ps/Profile.h"
-#include "renderer/Scene.h"
+#include <algorithm>
+#include <array>
+#include <cstdint>
+#include <cstdlib>
+#include <iterator>
+#include <limits>
+#include <map>
+#include <set>
+#include <string>
+#include <type_traits>
+#include <utility>
+#include <vector>
 
 #define DEBUG_RANGE_MANAGER_BOUNDS 0
 
@@ -286,7 +314,7 @@ template<>
 struct SerializeHelper<Query>
 {
 	template<typename S>
-	void Common(S& serialize, const char* UNUSED(name), Serialize::qualify<S, Query> value)
+	void Common(S& serialize, const char* /*name*/, Serialize::qualify<S, Query> value)
 	{
 		serialize.NumberFixed_Unbounded("min range", value.minRange);
 		serialize.NumberFixed_Unbounded("max range", value.maxRange);
@@ -300,7 +328,7 @@ struct SerializeHelper<Query>
 		serialize.Bool("account for size",value.accountForSize);
 	}
 
-	void operator()(ISerializer& serialize, const char* name, Query& value, const CSimContext& UNUSED(context))
+	void operator()(ISerializer& serialize, const char* name, Query& value, const CSimContext&)
 	{
 		Common(serialize, name, value);
 
@@ -327,7 +355,7 @@ template<>
 struct SerializeHelper<EntityData>
 {
 	template<typename S>
-	void operator()(S& serialize, const char* UNUSED(name), Serialize::qualify<S, EntityData> value)
+	void operator()(S& serialize, const char* /*name*/, Serialize::qualify<S, EntityData> value)
 	{
 		serialize.NumberFixed_Unbounded("x", value.x);
 		serialize.NumberFixed_Unbounded("z", value.z);
@@ -436,7 +464,7 @@ public:
 		return "<a:component type='system'/><empty/>";
 	}
 
-	void Init(const CParamNode& UNUSED(paramNode)) override
+	void Init(const CParamNode&) override
 	{
 		m_QueryNext = 1;
 
@@ -508,7 +536,7 @@ public:
 		SerializeCommon(deserialize);
 	}
 
-	void HandleMessage(const CMessage& msg, bool UNUSED(global)) override
+	void HandleMessage(const CMessage& msg, bool /*global*/) override
 	{
 		switch (msg.GetType())
 		{
