@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -17,20 +17,32 @@
 
 #include "precompiled.h"
 
-#include "simulation2/system/Component.h"
 #include "ICmpTerritoryManager.h"
 
+#include "graphics/Color.h"
 #include "graphics/Overlay.h"
-#include "graphics/Terrain.h"
-#include "graphics/TextureManager.h"
+#include "graphics/SColor.h"
 #include "graphics/TerritoryBoundary.h"
+#include "graphics/Texture.h"
+#include "graphics/TextureManager.h"
+#include "lib/code_annotation.h"
+#include "lib/code_generation.h"
+#include "lib/debug.h"
+#include "lib/path.h"
+#include "lib/types.h"
+#include "maths/Fixed.h"
+#include "maths/FixedVector2D.h"
 #include "maths/MathUtil.h"
+#include "maths/Vector2D.h"
+#include "ps/Filesystem.h"
 #include "ps/Profile.h"
 #include "ps/XML/Xeromyces.h"
 #include "renderer/Renderer.h"
 #include "renderer/Scene.h"
 #include "renderer/TerrainOverlay.h"
+#include "renderer/backend/Sampler.h"
 #include "simulation2/MessageTypes.h"
+#include "simulation2/components/ICmpObstructionManager.h"
 #include "simulation2/components/ICmpOwnership.h"
 #include "simulation2/components/ICmpPathfinder.h"
 #include "simulation2/components/ICmpPlayer.h"
@@ -39,11 +51,26 @@
 #include "simulation2/components/ICmpTerritoryDecayManager.h"
 #include "simulation2/components/ICmpTerritoryInfluence.h"
 #include "simulation2/helpers/Grid.h"
+#include "simulation2/helpers/Pathfinding.h"
+#include "simulation2/helpers/Player.h"
+#include "simulation2/helpers/Position.h"
 #include "simulation2/helpers/Render.h"
+#include "simulation2/system/Component.h"
+#include "simulation2/system/Entity.h"
+#include "simulation2/system/Message.h"
 
+#include <array>
+#include <cmath>
+#include <cstddef>
+#include <map>
 #include <queue>
+#include <string>
+#include <type_traits>
+#include <utility>
+#include <vector>
 
 class CCmpTerritoryManager;
+class CFrustum;
 
 class TerritoryOverlay final : public TerrainTextureOverlay
 {
@@ -117,7 +144,7 @@ public:
 	bool m_EnableLineDebugOverlays; ///< Enable node debugging overlays for boundary lines?
 	std::vector<SOverlayLine> m_DebugBoundaryLineNodes;
 
-	void Init(const CParamNode& UNUSED(paramNode)) override
+	void Init(const CParamNode&) override
 	{
 		m_Territories = NULL;
 		m_CostGrid = NULL;
@@ -171,7 +198,7 @@ public:
 		deserialize.Bool("trigger event", m_TriggerEvent);
 	}
 
-	void HandleMessage(const CMessage& msg, bool UNUSED(global)) override
+	void HandleMessage(const CMessage& msg, bool /*global*/) override
 	{
 		switch (msg.GetType())
 		{
@@ -705,7 +732,7 @@ void CCmpTerritoryManager::UpdateBoundaryLines()
 	}
 }
 
-void CCmpTerritoryManager::Interpolate(float frameTime, float UNUSED(frameOffset))
+void CCmpTerritoryManager::Interpolate(float frameTime, float /*frameOffset*/)
 {
 	m_AnimTime += frameTime;
 
