@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,8 +19,11 @@
 
 #include "ICmpAIInterface.h"
 
-#include "simulation2/system/InterfaceScripted.h"
 #include "simulation2/scripting/ScriptComponent.h"
+#include "simulation2/system/InterfaceScripted.h"
+
+#include <js/RootingAPI.h>
+#include <string>
 
 BEGIN_INTERFACE_WRAPPER(AIInterface)
 END_INTERFACE_WRAPPER(AIInterface)
