@@ -1,4 +1,4 @@
-/* Copyright (C) 2021 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,21 +18,25 @@
 #ifndef INCLUDED_ICMPPATHFINDER
 #define INCLUDED_ICMPPATHFINDER
 
-#include "simulation2/system/Interface.h"
-
+#include "lib/types.h"
 #include "simulation2/components/ICmpObstruction.h"
 #include "simulation2/helpers/Pathfinding.h"
+#include "simulation2/helpers/Position.h"
+#include "simulation2/system/Component.h"
+#include "simulation2/system/Entity.h"
+#include "simulation2/system/Interface.h"
 
+#include <js/Value.h>
 #include <map>
+#include <string>
+#include <vector>
 
+class CFixedVector2D;
 class IObstructionTestFilter;
 class PathGoal;
-
+struct GridUpdateInformation;
 template<typename T> class Grid;
 
-// Returned by asynchronous workers, used to send messages in the main thread.
-struct WaypointPath;
-
 struct PathResult
 {
 	PathResult() = default;
@@ -130,6 +134,11 @@ public:
 	 */
 	virtual void SetDebugPath(entity_pos_t x0, entity_pos_t z0, const PathGoal& goal, pass_class_t passClass) = 0;
 
+	/**
+	 * Distribute units around a point, returning a list of positions.
+	 */
+	virtual std::vector<CFixedVector2D> DistributeAround(std::vector<entity_id_t> units, entity_pos_t x, entity_pos_t z) const = 0;
+
 	/**
 	 * @return true if the goal is reachable from (x0, z0) for the given passClass, false otherwise.
 	 * Warning: this is synchronous, somewhat expensive and not should not be called too liberally.
