@@ -1,4 +1,4 @@
-/* Copyright (C) 2018 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
 * This file is part of 0 A.D.
 *
 * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,8 +18,12 @@
 #ifndef INCLUDED_ICMPSOUND
 #define INCLUDED_ICMPSOUND
 
+#include "simulation2/system/Component.h"
 #include "simulation2/system/Interface.h"
 
+#include <js/Value.h>
+#include <string>
+
 /**
 * Sound data.
 * (This interface includes functions needed by native code for loading soundgroups.
