@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -15,23 +15,36 @@
  * along with 0 A.D.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "simulation2/system/ComponentTest.h"
+#include "lib/self_test.h"
 
+#include "maths/Fixed.h"
+#include "maths/FixedVector3D.h"
 #include "maths/Matrix3D.h"
+#include "maths/Vector3D.h"
+#include "ps/XML/Xeromyces.h"
+#include "scriptinterface/ScriptInterface.h"
+#include "simulation2/MessageTypes.h"
 #include "simulation2/components/ICmpPosition.h"
 #include "simulation2/components/ICmpWaterManager.h"
+#include "simulation2/helpers/Position.h"
+#include "simulation2/system/Component.h"
+#include "simulation2/system/ComponentTest.h"
+#include "simulation2/system/Entity.h"
+
+#include <memory>
+#include <string>
 
 class MockWater : public ICmpWaterManager
 {
 public:
 	DEFAULT_MOCK_COMPONENT()
 
-	entity_pos_t GetWaterLevel(entity_pos_t UNUSED(x), entity_pos_t UNUSED(z)) const override
+	entity_pos_t GetWaterLevel(entity_pos_t /*x*/, entity_pos_t /*z*/) const override
 	{
 		return entity_pos_t::FromInt(100);
 	}
 
-	float GetExactWaterLevel(float UNUSED(x), float UNUSED(z)) const override
+	float GetExactWaterLevel(float /*x*/, float /*z*/) const override
 	{
 		return 100.f;
 	}
@@ -40,7 +53,7 @@ public:
 	{
 	}
 
-	void SetWaterLevel(entity_pos_t UNUSED(h)) override
+	void SetWaterLevel(entity_pos_t /*h*/) override
 	{
 	}
 };
