@@ -1,4 +1,4 @@
-/* Copyright (C) 2023 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -34,16 +34,24 @@
 
 #include "VertexPathfinder.h"
 
-#include "lib/timer.h"
-#include "ps/Profile.h"
+#include "graphics/Color.h"
+#include "lib/code_generation.h"
+#include "lib/debug.h"
+#include "maths/MathUtil.h"
+#include "ps/Profiler2.h"
 #include "renderer/Scene.h"
 #include "simulation2/components/ICmpObstructionManager.h"
 #include "simulation2/helpers/Grid.h"
+#include "simulation2/helpers/PathGoal.h"
+#include "simulation2/helpers/Position.h"
 #include "simulation2/helpers/PriorityQueue.h"
 #include "simulation2/helpers/Render.h"
-#include "simulation2/system/SimContext.h"
 
+#include <algorithm>
+#include <cmath>
+#include <cstddef>
 #include <mutex>
+#include <queue>
 
 namespace
 {
@@ -1003,7 +1011,8 @@ void VertexPathfinderDebugOverlay::DebugRenderGraph(const CSimContext& simContex
 	}
 }
 
-void VertexPathfinderDebugOverlay::DebugRenderEdges(const CSimContext& UNUSED(simContext), bool UNUSED(visible), CFixedVector2D UNUSED(curr), CFixedVector2D UNUSED(npos))
+void VertexPathfinderDebugOverlay::DebugRenderEdges(const CSimContext&, bool /*visible*/,
+	CFixedVector2D /*curr*/, CFixedVector2D /*npos*/)
 {
 	if (!m_DebugOverlay)
 		return;
