@@ -19,23 +19,37 @@
 
 #include "ComponentManager.h"
 
+#include "graphics/HeightMipmap.h"
 #include "lib/utf8.h"
-#include "ps/algorithm.h"
 #include "ps/CLogger.h"
+#include "ps/CStr.h"
+#include "ps/Errors.h"
 #include "ps/Filesystem.h"
-#include "ps/Profile.h"
+#include "ps/Profiler2.h"
+#include "ps/algorithm.h"
 #include "ps/scripting/JSInterface_VFS.h"
 #include "scriptinterface/FunctionWrapper.h"
 #include "scriptinterface/Object.h"
-#include "simulation2/components/ICmpTemplateManager.h"
+#include "scriptinterface/ScriptRequest.h"
 #include "simulation2/MessageTypes.h"
+#include "simulation2/components/ICmpTemplateManager.h"
+#include "simulation2/helpers/Player.h"
 #include "simulation2/system/DynamicSubscription.h"
-#include "simulation2/system/IComponent.h"
-#include "simulation2/system/ParamNode.h"
-#include "simulation2/system/SimContext.h"
+#include "simulation2/system/Message.h"
 
+#include <algorithm>
+#include <cstdint>
+#include <cstdlib>
+#include <fmt/format.h>
+#include <iterator>
+#include <js/GCAPI.h>
+#include <js/TracingAPI.h>
+#include <js/ValueArray.h>
+#include <stdexcept>
 #include <string_view>
 
+class ScriptContext;
+
 /**
  * Used for script-only message types.
  */
@@ -45,7 +59,7 @@ public:
 	virtual int GetType() const { return mtid; }
 	virtual const char* GetScriptHandlerName() const { return handlerName.c_str(); }
 	virtual const char* GetScriptGlobalHandlerName() const { return globalHandlerName.c_str(); }
-	virtual JS::Value ToJSVal(const ScriptRequest& UNUSED(rq)) const { return msg.get(); }
+	virtual JS::Value ToJSVal(const ScriptRequest&) const { return msg.get(); }
 
 	CMessageScripted(const ScriptRequest& rq, int mtid, const std::string& name, JS::HandleValue msg) :
 		mtid(mtid), handlerName("On" + name), globalHandlerName("OnGlobal" + name), msg(rq.cx, msg)
@@ -68,6 +82,8 @@ CComponentManager::CComponentManager(CSimContext& context, ScriptContext& cx, bo
 	m_ScriptInterface.SetCallbackData(static_cast<void*> (this));
 	m_ScriptInterface.ReplaceNondeterministicRNG(m_RNG);
 
+	JS_AddExtraGCRootsTracer(m_ScriptInterface.GetGeneralJSContext(), Trace, (void*)this);
+
 	// For component script tests, the test system sets up its own scripted implementation of
 	// these functions, so we skip registering them here in those cases
 	if (!skipScriptFunctions)
@@ -119,6 +135,7 @@ CComponentManager::CComponentManager(CSimContext& context, ScriptContext& cx, bo
 
 CComponentManager::~CComponentManager()
 {
+	JS_RemoveExtraGCRootsTracer(m_ScriptInterface.GetGeneralJSContext(), Trace, (void*)this);
 	ResetState();
 }
 
@@ -165,10 +182,8 @@ void CComponentManager::Script_RegisterComponentType_Common(int iid, const std::
 	// Find the C++ component that wraps the interface
 	int cidWrapper = GetScriptWrapper(iid);
 	if (cidWrapper == CID__Invalid)
-	{
-		ScriptException::Raise(rq, "Invalid interface id");
-		return;
-	}
+		throw std::invalid_argument{"Invalid interface id"};
+
 	const ComponentType& ctWrapper = m_ComponentTypesById[cidWrapper];
 
 	bool mustReloadComponents = false; // for hotloading
@@ -178,8 +193,8 @@ void CComponentManager::Script_RegisterComponentType_Common(int iid, const std::
 	{
 		if (reRegister)
 		{
-			ScriptException::Raise(rq, "ReRegistering component type that was not registered before '%s'", cname.c_str());
-			return;
+			throw std::logic_error{fmt::format(
+				"ReRegistering component type that was not registered before '{}'", cname.c_str())};
 		}
 		// Allocate a new cid number
 		cid = m_NextScriptComponentTypeId++;
@@ -193,8 +208,8 @@ void CComponentManager::Script_RegisterComponentType_Common(int iid, const std::
 
 		if (!m_CurrentlyHotloading && !reRegister)
 		{
-			ScriptException::Raise(rq, "Registering component type with already-registered name '%s'", cname.c_str());
-			return;
+			throw std::logic_error{fmt::format(
+				"Registering component type with already-registered name '{}'", cname.c_str())};
 		}
 
 		const ComponentType& ctPrevious = m_ComponentTypesById[cid];
@@ -202,8 +217,9 @@ void CComponentManager::Script_RegisterComponentType_Common(int iid, const std::
 		// We can only replace scripted component types, not native ones
 		if (ctPrevious.type != CT_Script)
 		{
-			ScriptException::Raise(rq, "Loading script component type with same name '%s' as native component", cname.c_str());
-			return;
+			throw std::logic_error{fmt::format(
+				"Loading script component type with same name '%s' as native component",
+				cname.c_str())};
 		}
 
 		// We don't support changing the IID of a component type (it would require fiddling
@@ -213,8 +229,8 @@ void CComponentManager::Script_RegisterComponentType_Common(int iid, const std::
 			// ...though it only matters if any components exist with this type
 			if (!m_ComponentsByTypeId[cid].empty())
 			{
-				ScriptException::Raise(rq, "Hotloading script component type mustn't change interface ID");
-				return;
+				throw std::logic_error{
+					"Hotloading script component type mustn't change interface ID"};
 			}
 		}
 
@@ -240,15 +256,10 @@ void CComponentManager::Script_RegisterComponentType_Common(int iid, const std::
 
 	JS::RootedValue protoVal(rq.cx);
 	if (!Script::GetProperty(rq, ctor, "prototype", &protoVal))
-	{
-		ScriptException::Raise(rq, "Failed to get property 'prototype'");
-		return;
-	}
+		throw std::runtime_error("Failed to get property 'prototype'");
 	if (!protoVal.isObject())
-	{
-		ScriptException::Raise(rq, "Component has no constructor");
-		return;
-	}
+		throw std::invalid_argument{"Component has no constructor"};
+
 	std::string schema = "<empty/>";
 
 	if (Script::HasProperty(rq, protoVal, "Schema"))
@@ -276,7 +287,7 @@ void CComponentManager::Script_RegisterComponentType_Common(int iid, const std::
 
 	if (!Script::EnumeratePropertyNames(rq, protoVal, false, methods))
 	{
-		ScriptException::Raise(rq, "Failed to enumerate component properties.");
+		throw std::runtime_error{"Failed to enumerate component properties."};
 		return;
 	}
 
@@ -298,10 +309,9 @@ void CComponentManager::Script_RegisterComponentType_Common(int iid, const std::
 		auto mit = m_MessageTypeIdsByName.find(std::string{name});
 		if (mit == m_MessageTypeIdsByName.end())
 		{
-			ScriptException::Raise(rq,
-				"Registered component has unrecognized '%s' message handler method",
-				method.c_str());
-			return;
+			throw std::invalid_argument{fmt::format(
+				"Registered component has unrecognized '{}' message handler method",
+				method.c_str())};
 		}
 
 		// If we have already subscribed in classInit, do not subscribe again
@@ -360,8 +370,8 @@ void CComponentManager::Script_RegisterInterface(const std::string& name)
 		// they're probably unintentional and should be reported
 		if (!m_CurrentlyHotloading)
 		{
-			ScriptRequest rq(m_ScriptInterface);
-			ScriptException::Raise(rq, "Registering interface with already-registered name '%s'", name.c_str());
+			throw std::logic_error{fmt::format(
+				"Registering interface with already-registered name '{}'", name.c_str())};
 		}
 		return;
 	}
@@ -382,8 +392,8 @@ void CComponentManager::Script_RegisterMessageType(const std::string& name)
 		// they're probably unintentional and should be reported
 		if (!m_CurrentlyHotloading)
 		{
-			ScriptRequest rq(m_ScriptInterface);
-			ScriptException::Raise(rq, "Registering message type with already-registered name '%s'", name.c_str());
+			throw std::logic_error{fmt::format(
+				"Registering message type with already-registered name '{}'", name.c_str())};
 		}
 		return;
 	}
@@ -494,6 +504,9 @@ void CComponentManager::ResetState()
 	m_DynamicMessageSubscriptionsNonsync.clear();
 	m_DynamicMessageSubscriptionsNonsyncByComponent.clear();
 
+	// Remove all items we were tracing.
+	m_TraceCache.clear();
+
 	// Delete all IComponents in reverse order of creation.
 	std::map<ComponentTypeId, std::map<entity_id_t, IComponent*> >::reverse_iterator iit = m_ComponentsByTypeId.rbegin();
 	for (; iit != m_ComponentsByTypeId.rend(); ++iit)
@@ -815,6 +828,19 @@ void CComponentManager::AddMockComponent(CEntityHandle ent, InterfaceId iid, ICo
 	cache->interfaces[iid] = &component;
 }
 
+void CComponentManager::Trace(JSTracer* trc, void* data)
+{
+	CComponentManager& cmpMgr = *(static_cast<CComponentManager*>(data));
+	for (auto& traceByEnt : cmpMgr.m_TraceCache)
+		for (JS::Heap<JS::Value>* ptr : traceByEnt.second)
+			JS::TraceEdge(trc, ptr, "ComponentManager::Trace");
+}
+
+void CComponentManager::RegisterTrace(entity_id_t ent, const JS::Heap<JS::Value>& instance)
+{
+	m_TraceCache.try_emplace(ent).first->second.push_back(const_cast<JS::Heap<JS::Value>*>(std::addressof(instance)));
+}
+
 CEntityHandle CComponentManager::AllocateEntityHandle(entity_id_t ent)
 {
 	ENSURE(!EntityExists(ent));
@@ -955,6 +981,10 @@ void CComponentManager::FlushDestroyedComponents()
 			free(handle.GetComponentCache());
 			m_ComponentCaches.erase(ent);
 
+			auto hit = m_TraceCache.find(ent);
+			if (hit != m_TraceCache.end())
+				m_TraceCache.erase(hit);
+
 			// Remove from m_ComponentsByInterface
 			std::vector<std::unordered_map<entity_id_t, IComponent*> >::iterator ifcit = m_ComponentsByInterface.begin();
 			for (; ifcit != m_ComponentsByInterface.end(); ++ifcit)
@@ -1018,8 +1048,6 @@ const CComponentManager::InterfaceListUnordered& CComponentManager::GetEntitiesW
 
 void CComponentManager::PostMessage(entity_id_t ent, const CMessage& msg)
 {
-	PROFILE2_IFSPIKE("Post Message", 0.0005);
-	PROFILE2_ATTR("%s", msg.GetScriptHandlerName());
 	// Send the message to components of ent, that subscribed locally to this message
 	std::map<MessageTypeId, std::vector<ComponentTypeId> >::const_iterator it;
 	it = m_LocalMessageSubscriptions.find(msg.GetType());
@@ -1070,8 +1098,6 @@ void CComponentManager::BroadcastMessage(const CMessage& msg)
 
 void CComponentManager::SendGlobalMessage(entity_id_t ent, const CMessage& msg)
 {
-	PROFILE2_IFSPIKE("SendGlobalMessage", 0.001);
-	PROFILE2_ATTR("%s", msg.GetScriptHandlerName());
 	// (Common functionality for PostMessage and BroadcastMessage)
 
 	// Send the message to components of all entities that subscribed globally to this message
