@@ -18,23 +18,30 @@
 #ifndef INCLUDED_COMPONENTMANAGER
 #define INCLUDED_COMPONENTMANAGER
 
-#include "ps/Filesystem.h"
+#include "lib/code_annotation.h"
+#include "lib/debug.h"
+#include "lib/types.h"
 #include "scriptinterface/ScriptInterface.h"
-#include "simulation2/helpers/Player.h"
-#include "simulation2/system/Components.h"
+#include "simulation2/system/Component.h"
+#include "simulation2/system/DynamicSubscription.h"
 #include "simulation2/system/Entity.h"
-#include "simulation2/system/IComponent.h"
 
 #include <boost/random/linear_congruential.hpp>
+#include <iosfwd>
+#include <js/RootingAPI.h>
+#include <js/TypeDecls.h>
+#include <js/Value.h>
 #include <map>
+#include <memory>
 #include <set>
+#include <string>
 #include <unordered_map>
+#include <utility>
+#include <vector>
 
-class IComponent;
-class CParamNode;
 class CMessage;
-class CSimContext;
-class CDynamicSubscription;
+class JSTracer;
+class ScriptContext;
 
 class CComponentManager
 {
@@ -239,6 +246,16 @@ public:
 	 */
 	void FlushDestroyedComponents();
 
+	/**
+	 * Called during GC tracing of our components.
+	 */
+	static void Trace(JSTracer* trc, void* data);
+	/**
+	 * Call this from components when they need to save their JS instance.
+	 * Not done by the component manager because C++ components do it lazily.
+	 */
+	void RegisterTrace(entity_id_t ent, const JS::Heap<JS::Value>& instance);
+
 	IComponent* QueryInterface(entity_id_t ent, InterfaceId iid) const;
 
 	using InterfacePair = std::pair<entity_id_t, IComponent*>;
@@ -335,6 +352,7 @@ private:
 	std::map<IComponent*, std::set<MessageTypeId> > m_DynamicMessageSubscriptionsNonsyncByComponent;
 
 	std::unordered_map<entity_id_t, SEntityComponentCache*> m_ComponentCaches;
+	std::unordered_map<entity_id_t, std::vector<JS::Heap<JS::Value>*>> m_TraceCache;
 
 	// TODO: maintaining both ComponentsBy* is nasty; can we get rid of one,
 	// while keeping QueryInterface and PostMessage sufficiently efficient?
