@@ -1,4 +1,4 @@
-/* Copyright (C) 2024 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -24,21 +24,31 @@
 
 #include "precompiled.h"
 
-#include <fstream>
-
 #include "lib/self_test.h"
-#include <cxxtest/GlobalFixture.h>
 
-#include "lib/timer.h"
+#include "lib/code_generation.h"
+#include "lib/debug.h"
+#include "lib/os_path.h"
+#include "lib/path.h"
+#include "lib/sysdep/compiler.h"
+#include "lib/sysdep/os.h"
 #include "lib/sysdep/sysdep.h"
+#include "lib/timer.h"
+#include "lib/utf8.h"
 #include "ps/Profiler2.h"
 #include "ps/TaskManager.h"
+#include "ps/ThreadUtil.h"
 #include "scriptinterface/FunctionWrapper.h"
-#include "scriptinterface/ScriptEngine.h"
 #include "scriptinterface/ScriptContext.h"
+#include "scriptinterface/ScriptEngine.h"
 #include "scriptinterface/ScriptInterface.h"
+#include "scriptinterface/ScriptRequest.h"
 
+#include <fstream>
+#include <iterator>
+#include <memory>
 #include <optional>
+#include <string>
 
 class LeakReporter : public CxxTest::GlobalFixture
 {
@@ -129,7 +139,7 @@ bool ts_str_contains(const std::wstring& str1, const std::wstring& str2)
 // available, so we use sys_ExecutablePathname.
 OsPath DataDir()
 {
-	return sys_ExecutablePathname().Parent()/".."/"data";
+	return sys_ExecutablePathname().Parent().Parent()/"data";
 }
 
 // Script-based testing setup:
