@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,10 +19,17 @@
 
 #include "HighResTimer.h"
 
+#include <cstddef>
+
 // TODO: Better accuracy and reliability, if necessary.
 
 #ifdef __WXMSW__
 
+#include "lib/sysdep/os/win/win.h"
+
+#include <wx/intl.h>
+#include <wx/log.h>
+
 HighResTimer::HighResTimer()
 {
 	LARGE_INTEGER freq;
