@@ -1,4 +1,4 @@
-/* Copyright (C) 2020 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
 * This file is part of 0 A.D.
 *
 * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,9 +18,13 @@
 #ifndef INCLUDED_MAPRESIZEDIALOG
 #define INCLUDED_MAPRESIZEDIALOG
 
-#include "PseudoMiniMapPanel.h"
-
+#include <wx/defs.h>
 #include <wx/dialog.h>
+#include <wx/event.h>
+
+class PseudoMiniMapPanel;
+class wxPoint;
+class wxWindow;
 
 class MapResizeDialog : public wxDialog
 {
