@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -15,18 +15,26 @@
  * along with 0 A.D.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "../Common/Sidebar.h"
+#include "tools/atlas/AtlasUI/General/Observable.h"
+#include "tools/atlas/AtlasUI/ScenarioEditor/Sections/Common/Sidebar.h"
 
-#include "General/Observable.h"
+#include <wx/defs.h>
+#include <wx/event.h>
 
+class ScenarioEditor;
 class VariableListBox;
+class wxWindow;
 
 class EnvironmentSidebar : public Sidebar
 {
 public:
 	EnvironmentSidebar(ScenarioEditor& scenarioEditor, wxWindow* sidebarContainer, wxWindow* bottomBarContainer);
 
+	void OnPickWaterHeight(wxCommandEvent& evt);
 	virtual void OnMapReload();
+	virtual void RecomputeWaterData(wxCommandEvent& evt);
+
+	void UpdateEnvironmentSettings();
 
 protected:
 	virtual void OnFirstDisplay();
@@ -34,5 +42,8 @@ protected:
 private:
 	VariableListBox* m_PostEffectList;
 	VariableListBox* m_SkyList;
+	VariableListBox* m_WaterTypeList;
 	ObservableScopedConnection m_Conn;
+
+	DECLARE_EVENT_TABLE();
 };
