@@ -1,4 +1,4 @@
-/* Copyright (C) 2013 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -19,12 +19,47 @@
 
 #include "Player.h"
 
-#include "AtlasObject/AtlasObject.h"
-#include "AtlasScript/ScriptInterface.h"
-#include "CustomControls/ColourDialog/ColourDialog.h"
-#include "ScenarioEditor/ScenarioEditor.h"
+#include "tools/atlas/AtlasObject/AtlasObject.h"
+#include "tools/atlas/AtlasUI/CustomControls/ColorDialog/ColorDialog.h"
+#include "tools/atlas/AtlasUI/General/Observable.h"
+#include "tools/atlas/AtlasUI/ScenarioEditor/ScenarioEditor.h"
+#include "tools/atlas/AtlasUI/ScenarioEditor/Sections/Common/Sidebar.h"
+#include "tools/atlas/AtlasUI/ScenarioEditor/Tools/Common/Tools.h"
+#include "tools/atlas/GameInterface/MessagePasser.h"
+#include "tools/atlas/GameInterface/Messages.h"
+#include "tools/atlas/GameInterface/Shareable.h"
+#include "tools/atlas/GameInterface/SharedTypes.h"
 
-#include "wx/choicebk.h"
+#include <climits>
+#include <list>
+#include <string>
+#include <vector>
+#include <wx/arrstr.h>
+#include <wx/bookctrl.h>
+#include <wx/button.h>
+#include <wx/chartype.h>
+#include <wx/checkbox.h>
+#include <wx/choice.h>
+#include <wx/choicebk.h>
+#include <wx/clntdata.h>
+#include <wx/collpane.h>
+#include <wx/colour.h>
+#include <wx/colourdata.h>
+#include <wx/debug.h>
+#include <wx/gdicmn.h>
+#include <wx/msgdlg.h>
+#include <wx/object.h>
+#include <wx/panel.h>
+#include <wx/scrolwin.h>
+#include <wx/sizer.h>
+#include <wx/spinbutt.h>
+#include <wx/spinctrl.h>
+#include <wx/statbox.h>
+#include <wx/stattext.h>
+#include <wx/textctrl.h>
+#include <wx/toolbar.h>
+#include <wx/translation.h>
+#include <wx/window.h>
 
 enum
 {
@@ -34,11 +69,11 @@ enum
 	ID_PlayerMetal,
 	ID_PlayerStone,
 	ID_PlayerPop,
-	ID_PlayerColour,
+	ID_PlayerColor,
 
 	ID_DefaultName,
 	ID_DefaultCiv,
-	ID_DefaultColour,
+	ID_DefaultColor,
 	ID_DefaultAI,
 	ID_DefaultFood,
 	ID_DefaultWood,
@@ -101,8 +136,8 @@ class PlayerNotebookPage : public wxPanel
 {
 
 public:
-	PlayerNotebookPage(ScenarioEditor& scenarioEditor, wxWindow* parent, const wxString& name, size_t playerID)
-		: wxPanel(parent, wxID_ANY), m_ScenarioEditor(scenarioEditor), m_Name(name), m_PlayerID(playerID)
+	PlayerNotebookPage(wxWindow* parent, const wxString& name, size_t playerID)
+		: wxPanel(parent, wxID_ANY), m_Name(name), m_PlayerID(playerID)
 	{
 
 		m_Controls.page = this;
@@ -119,28 +154,28 @@ public:
 			wxFlexGridSizer* gridSizer = new wxFlexGridSizer(3, 5, 5);
 			gridSizer->AddGrowableCol(2);
 
-			wxTextCtrl* nameCtrl = new wxTextCtrl(this, wxID_ANY);
-			gridSizer->Add(new DefaultCheckbox(this, ID_DefaultName, nameCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
-			gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Name")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			wxTextCtrl* nameCtrl = new wxTextCtrl(playerInfoSizer->GetStaticBox(), wxID_ANY);
+			gridSizer->Add(new DefaultCheckbox(playerInfoSizer->GetStaticBox(), ID_DefaultName, nameCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			gridSizer->Add(new wxStaticText(playerInfoSizer->GetStaticBox(), wxID_ANY, _("Name")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
 			gridSizer->Add(nameCtrl, wxSizerFlags(1).Expand().Align(wxALIGN_RIGHT));
 			m_Controls.name = nameCtrl;
 
-			wxChoice* civChoice = new wxChoice(this, wxID_ANY);
-			gridSizer->Add(new DefaultCheckbox(this, ID_DefaultCiv, civChoice), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
-			gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Civilisation")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			wxChoice* civChoice = new wxChoice(playerInfoSizer->GetStaticBox(), wxID_ANY);
+			gridSizer->Add(new DefaultCheckbox(playerInfoSizer->GetStaticBox(), ID_DefaultCiv, civChoice), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			gridSizer->Add(new wxStaticText(playerInfoSizer->GetStaticBox(), wxID_ANY, _("Civilisation")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
 			gridSizer->Add(civChoice, wxSizerFlags(1).Expand().Align(wxALIGN_RIGHT));
 			m_Controls.civ = civChoice;
 
-			wxButton* colourButton = new wxButton(this, ID_PlayerColour);
-			gridSizer->Add(new DefaultCheckbox(this, ID_DefaultColour, colourButton), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
-			gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Colour")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
-			gridSizer->Add(Tooltipped(colourButton,
-				_("Set player colour")), wxSizerFlags(1).Expand().Align(wxALIGN_RIGHT));
-			m_Controls.colour = colourButton;
+			wxButton* colorButton = new wxButton(playerInfoSizer->GetStaticBox(), ID_PlayerColor);
+			gridSizer->Add(new DefaultCheckbox(playerInfoSizer->GetStaticBox(), ID_DefaultColor, colorButton), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			gridSizer->Add(new wxStaticText(playerInfoSizer->GetStaticBox(), wxID_ANY, _("Color")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			gridSizer->Add(Tooltipped(colorButton,
+				_("Set player color")), wxSizerFlags(1).Expand().Align(wxALIGN_RIGHT));
+			m_Controls.color = colorButton;
 
-			wxChoice* aiChoice = new wxChoice(this, wxID_ANY);
-			gridSizer->Add(new DefaultCheckbox(this, ID_DefaultAI, aiChoice), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
-			gridSizer->Add(new wxStaticText(this, wxID_ANY, _("AI")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			wxChoice* aiChoice = new wxChoice(playerInfoSizer->GetStaticBox(), wxID_ANY);
+			gridSizer->Add(new DefaultCheckbox(playerInfoSizer->GetStaticBox(), ID_DefaultAI, aiChoice), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			gridSizer->Add(new wxStaticText(playerInfoSizer->GetStaticBox(), wxID_ANY, _("AI")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
 			gridSizer->Add(Tooltipped(aiChoice,
 				_("Select AI")), wxSizerFlags(1).Expand().Align(wxALIGN_RIGHT));
 			m_Controls.ai = aiChoice;
@@ -156,37 +191,37 @@ public:
 			wxFlexGridSizer* gridSizer = new wxFlexGridSizer(3, 5, 5);
 			gridSizer->AddGrowableCol(2);
 
-			wxSpinCtrl* foodCtrl = new wxSpinCtrl(this, ID_PlayerFood, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
-			gridSizer->Add(new DefaultCheckbox(this, ID_DefaultFood, foodCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
-			gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Food")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			wxSpinCtrl* foodCtrl = new wxSpinCtrl(resourceSizer->GetStaticBox(), ID_PlayerFood, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
+			gridSizer->Add(new DefaultCheckbox(resourceSizer->GetStaticBox(), ID_DefaultFood, foodCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			gridSizer->Add(new wxStaticText(resourceSizer->GetStaticBox(), wxID_ANY, _("Food")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
 			gridSizer->Add(Tooltipped(foodCtrl,
 				_("Initial value of food resource")), wxSizerFlags().Expand());
 			m_Controls.food = foodCtrl;
 
-			wxSpinCtrl* woodCtrl = new wxSpinCtrl(this, ID_PlayerWood, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
-			gridSizer->Add(new DefaultCheckbox(this, ID_DefaultWood, woodCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
-			gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Wood")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			wxSpinCtrl* woodCtrl = new wxSpinCtrl(resourceSizer->GetStaticBox(), ID_PlayerWood, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
+			gridSizer->Add(new DefaultCheckbox(resourceSizer->GetStaticBox(), ID_DefaultWood, woodCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			gridSizer->Add(new wxStaticText(resourceSizer->GetStaticBox(), wxID_ANY, _("Wood")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
 			gridSizer->Add(Tooltipped(woodCtrl,
 				_("Initial value of wood resource")), wxSizerFlags().Expand());
 			m_Controls.wood = woodCtrl;
 
-			wxSpinCtrl* metalCtrl = new wxSpinCtrl(this, ID_PlayerMetal, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
-			gridSizer->Add(new DefaultCheckbox(this, ID_DefaultMetal, metalCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
-			gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Metal")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			wxSpinCtrl* metalCtrl = new wxSpinCtrl(resourceSizer->GetStaticBox(), ID_PlayerMetal, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
+			gridSizer->Add(new DefaultCheckbox(resourceSizer->GetStaticBox(), ID_DefaultMetal, metalCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			gridSizer->Add(new wxStaticText(resourceSizer->GetStaticBox(), wxID_ANY, _("Metal")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
 			gridSizer->Add(Tooltipped(metalCtrl,
 				_("Initial value of metal resource")), wxSizerFlags().Expand());
 			m_Controls.metal = metalCtrl;
 
-			wxSpinCtrl* stoneCtrl = new wxSpinCtrl(this, ID_PlayerStone, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
-			gridSizer->Add(new DefaultCheckbox(this, ID_DefaultStone, stoneCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
-			gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Stone")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			wxSpinCtrl* stoneCtrl = new wxSpinCtrl(resourceSizer->GetStaticBox(), ID_PlayerStone, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
+			gridSizer->Add(new DefaultCheckbox(resourceSizer->GetStaticBox(), ID_DefaultStone, stoneCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			gridSizer->Add(new wxStaticText(resourceSizer->GetStaticBox(), wxID_ANY, _("Stone")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
 			gridSizer->Add(Tooltipped(stoneCtrl,
 				_("Initial value of stone resource")), wxSizerFlags().Expand());
 			m_Controls.stone = stoneCtrl;
 
-			wxSpinCtrl* popCtrl = new wxSpinCtrl(this, ID_PlayerPop, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
-			gridSizer->Add(new DefaultCheckbox(this, ID_DefaultPop, popCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
-			gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Pop limit")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			wxSpinCtrl* popCtrl = new wxSpinCtrl(resourceSizer->GetStaticBox(), ID_PlayerPop, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, INT_MAX);
+			gridSizer->Add(new DefaultCheckbox(resourceSizer->GetStaticBox(), ID_DefaultPop, popCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			gridSizer->Add(new wxStaticText(resourceSizer->GetStaticBox(), wxID_ANY, _("Pop limit")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
 			gridSizer->Add(Tooltipped(popCtrl,
 				_("Population limit for this player")), wxSizerFlags().Expand());
 			m_Controls.pop = popCtrl;
@@ -199,10 +234,10 @@ public:
 			// Diplomacy
 			wxStaticBoxSizer* diplomacySizer = new wxStaticBoxSizer(wxVERTICAL, this, _("Diplomacy"));
 			wxBoxSizer* boxSizer = new wxBoxSizer(wxHORIZONTAL);
-			wxChoice* teamCtrl = new wxChoice(this, wxID_ANY);
-			boxSizer->Add(new DefaultCheckbox(this, ID_DefaultTeam, teamCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+			wxChoice* teamCtrl = new wxChoice(diplomacySizer->GetStaticBox(), wxID_ANY);
+			boxSizer->Add(new DefaultCheckbox(diplomacySizer->GetStaticBox(), ID_DefaultTeam, teamCtrl), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
 			boxSizer->AddSpacer(5);
-			boxSizer->Add(new wxStaticText(this, wxID_ANY, _("Team")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
+			boxSizer->Add(new wxStaticText(diplomacySizer->GetStaticBox(), wxID_ANY, _("Team")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
 			boxSizer->AddSpacer(5);
 			teamCtrl->Append(_("None"));
 			teamCtrl->Append(_T("1"));
@@ -227,14 +262,14 @@ public:
 			// Camera
 			wxStaticBoxSizer* cameraSizer = new wxStaticBoxSizer(wxVERTICAL, this, _("Starting Camera"));
 			wxGridSizer* gridSizer = new wxGridSizer(3);
-			wxButton* cameraSet = new wxButton(this, ID_CameraSet, _("Set"));
+			wxButton* cameraSet = new wxButton(cameraSizer->GetStaticBox(), ID_CameraSet, _("Set"), wxDefaultPosition, wxSize(48, -1));
 			gridSizer->Add(Tooltipped(cameraSet,
-				_("Set player camera to this view")), wxSizerFlags().Expand());
-			wxButton* cameraView = new wxButton(this, ID_CameraView, _("View"));
+				_("Set player camera to cameraSizer->GetStaticBox() view")), wxSizerFlags().Expand());
+			wxButton* cameraView = new wxButton(cameraSizer->GetStaticBox(), ID_CameraView, _("View"), wxDefaultPosition, wxSize(48, -1));
 			cameraView->Enable(false);
 			gridSizer->Add(Tooltipped(cameraView,
 				_("View the player camera")), wxSizerFlags().Expand());
-			wxButton* cameraClear = new wxButton(this, ID_CameraClear, _("Clear"));
+			wxButton* cameraClear = new wxButton(cameraSizer->GetStaticBox(), ID_CameraClear, _("Clear"), wxDefaultPosition, wxSize(48, -1));
 			cameraClear->Enable(false);
 			gridSizer->Add(Tooltipped(cameraClear,
 				_("Clear player camera")), wxSizerFlags().Expand());
@@ -288,15 +323,15 @@ public:
 	}
 
 private:
-	void OnColour(wxCommandEvent& evt)
+	void OnColor(wxCommandEvent& evt)
 	{
-		// Show colour dialog
-		ColourDialog colourDlg(this, _T("Scenario Editor/PlayerColour"), m_Controls.colour->GetBackgroundColour());
+		// Show color dialog
+		ColorDialog colorDlg(this, _T("Scenario Editor/PlayerColor"), m_Controls.color->GetBackgroundColour());
 
-		if (colourDlg.ShowModal() == wxID_OK)
+		if (colorDlg.ShowModal() == wxID_OK)
 		{
-			m_Controls.colour->SetBackgroundColour(colourDlg.GetColourData().GetColour());
-			
+			m_Controls.color->SetBackgroundColour(colorDlg.GetColourData().GetColour());
+
 			// Pass event on to next handler
 			evt.Skip();
 		}
@@ -329,15 +364,14 @@ private:
 	bool m_CameraDefined;
 	wxString m_Name;
 	size_t m_PlayerID;
-	ScenarioEditor& m_ScenarioEditor;
-	
+
 	PlayerPageControls m_Controls;
 
 	DECLARE_EVENT_TABLE();
 };
 
 BEGIN_EVENT_TABLE(PlayerNotebookPage, wxPanel)
-	EVT_BUTTON(ID_PlayerColour, PlayerNotebookPage::OnColour)
+	EVT_BUTTON(ID_PlayerColor, PlayerNotebookPage::OnColor)
 	EVT_BUTTON(ID_CameraSet, PlayerNotebookPage::OnCameraSet)
 	EVT_BUTTON(ID_CameraView, PlayerNotebookPage::OnCameraView)
 	EVT_BUTTON(ID_CameraClear, PlayerNotebookPage::OnCameraClear)
@@ -348,15 +382,14 @@ END_EVENT_TABLE();
 class PlayerNotebook : public wxChoicebook
 {
 public:
-	PlayerNotebook(ScenarioEditor& scenarioEditor, wxWindow *parent)
-		: wxChoicebook(parent, wxID_ANY/*, wxDefaultPosition, wxDefaultSize, wxNB_FIXEDWIDTH*/),
-		  m_ScenarioEditor(scenarioEditor)
+	PlayerNotebook(wxWindow *parent)
+		: wxChoicebook(parent, wxID_ANY/*, wxDefaultPosition, wxDefaultSize, wxNB_FIXEDWIDTH*/)
 	{
 	}
 
 	PlayerPageControls AddPlayer(wxString name, size_t player)
 	{
-		PlayerNotebookPage* playerPage = new PlayerNotebookPage(m_ScenarioEditor, this, name, player);
+		PlayerNotebookPage* playerPage = new PlayerNotebookPage(this, name, player);
 		AddPage(playerPage, name);
 		m_Pages.push_back(playerPage);
 		return playerPage->GetControls();
@@ -407,7 +440,6 @@ protected:
 	}
 
 private:
-	ScenarioEditor& m_ScenarioEditor;
 	std::vector<PlayerNotebookPage*> m_Pages;
 
 	DECLARE_EVENT_TABLE();
@@ -447,13 +479,13 @@ private:
 		}
 	}
 
-	void OnPlayerColour(wxCommandEvent& WXUNUSED(evt))
+	void OnPlayerColor(wxCommandEvent& WXUNUSED(evt))
 	{
 		if (!m_InGUIUpdate)
 		{
 			SendToEngine();
 
-			// Update player settings, to show new colour
+			// Update player settings, to show new color
 			POST_MESSAGE(LoadPlayerSettings, (false));
 		}
 	}
@@ -468,7 +500,7 @@ private:
 		if (!m_InGUIUpdate)
 		{
 			wxASSERT(evt.GetInt() > 0);
-			
+
 			// When wxMessageBox pops up, wxSpinCtrl loses focus, which
 			//	forces another EVT_SPINCTRL event, which we don't want
 			//	to handle, so we check here for a change
@@ -476,7 +508,7 @@ private:
 			{
 				return;	// No change
 			}
-			
+
 			size_t oldNumPlayers = m_NumPlayers;
 			m_NumPlayers = evt.GetInt();
 
@@ -531,7 +563,6 @@ private:
 	bool m_InGUIUpdate;
 	AtObj m_PlayerDefaults;
 	PlayerNotebook* m_Players;
-	ScenarioEditor& m_ScenarioEditor;
 	std::vector<PlayerPageControls> m_PlayerControls;
 	Observable<AtObj>& m_MapSettings;
 	size_t m_NumPlayers;
@@ -540,7 +571,7 @@ private:
 };
 
 BEGIN_EVENT_TABLE(PlayerSettingsControl, wxPanel)
-	EVT_BUTTON(ID_PlayerColour, PlayerSettingsControl::OnPlayerColour)
+	EVT_BUTTON(ID_PlayerColor, PlayerSettingsControl::OnPlayerColor)
 	EVT_BUTTON(ID_CameraSet, PlayerSettingsControl::OnEdit)
 	EVT_BUTTON(ID_CameraClear, PlayerSettingsControl::OnEdit)
 	EVT_CHECKBOX(wxID_ANY, PlayerSettingsControl::OnEdit)
@@ -556,7 +587,7 @@ BEGIN_EVENT_TABLE(PlayerSettingsControl, wxPanel)
 END_EVENT_TABLE();
 
 PlayerSettingsControl::PlayerSettingsControl(wxWindow* parent, ScenarioEditor& scenarioEditor)
-	: wxPanel(parent, wxID_ANY), m_ScenarioEditor(scenarioEditor), m_InGUIUpdate(false), m_MapSettings(scenarioEditor.GetMapSettings()), m_NumPlayers(0)
+	: wxPanel(parent, wxID_ANY), m_InGUIUpdate(false), m_MapSettings(scenarioEditor.GetMapSettings()), m_NumPlayers(0)
 {
 	// To prevent recursion, don't handle GUI events right now
 	m_InGUIUpdate = true;
@@ -565,14 +596,14 @@ PlayerSettingsControl::PlayerSettingsControl(wxWindow* parent, ScenarioEditor& s
 	SetSizer(sizer);
 
 	wxBoxSizer* boxSizer = new wxBoxSizer(wxHORIZONTAL);
-	boxSizer->Add(new wxStaticText(this, wxID_ANY, _("Num players")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT));
-	wxSpinCtrl* numPlayersSpin = new wxSpinCtrl(this, ID_NumPlayers, wxEmptyString, wxDefaultPosition, wxSize(40, -1));
+	boxSizer->Add(new wxStaticText(sizer->GetStaticBox(), wxID_ANY, _("Num players")), wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+	wxSpinCtrl* numPlayersSpin = new wxSpinCtrl(sizer->GetStaticBox(), ID_NumPlayers, wxEmptyString, wxDefaultPosition, wxSize(40, -1));
 	numPlayersSpin->SetValue(MAX_NUM_PLAYERS);
 	numPlayersSpin->SetRange(1, MAX_NUM_PLAYERS);
 	boxSizer->Add(numPlayersSpin);
 	sizer->Add(boxSizer, wxSizerFlags().Expand().Proportion(0));
 	sizer->AddSpacer(5);
-	m_Players = new PlayerNotebook(m_ScenarioEditor, this);
+	m_Players = new PlayerNotebook(sizer->GetStaticBox());
 	sizer->Add(m_Players, wxSizerFlags().Expand().Proportion(1));
 
 	m_InGUIUpdate = false;
@@ -588,36 +619,35 @@ void PlayerSettingsControl::CreateWidgets()
 	wxArrayString civCodes;
 	AtlasMessage::qGetCivData qryCiv;
 	qryCiv.Post();
-	std::vector<std::string> civData = *qryCiv.data;
-	for (size_t i = 0; i < civData.size(); ++i)
+	std::vector<std::vector<std::wstring>> civData = *qryCiv.data;
+	for (const std::vector<std::wstring>& civ : civData)
 	{
-		AtObj civ = AtlasObject::LoadFromJSON(m_ScenarioEditor.GetScriptInterface().GetContext(), civData[i]);
-		civNames.Add(wxString(civ["Name"]));
-		civCodes.Add(wxString(civ["Code"]));
+		civCodes.Add(civ[0]);
+		civNames.Add(civ[1]);
 	}
 
 	// Load AI data
 	ArrayOfAIData ais(AIData::CompareAIData);
 	AtlasMessage::qGetAIData qryAI;
 	qryAI.Post();
-	AtObj aiData = AtlasObject::LoadFromJSON(m_ScenarioEditor.GetScriptInterface().GetContext(), *qryAI.data);
+	AtObj aiData = AtlasObject::LoadFromJSON(*qryAI.data);
 	for (AtIter a = aiData["AIData"]["item"]; a.defined(); ++a)
 	{
-		ais.Add(new AIData(wxString(a["id"]), wxString(a["data"]["name"])));
+		ais.Add(new AIData(wxString::FromUTF8(a["id"]), wxString::FromUTF8(a["data"]["name"])));
 	}
 
 	// Create player pages
 	AtIter playerDefs = m_PlayerDefaults["item"];
 	if (playerDefs.defined())
 		++playerDefs;	// Skip gaia
-	
+
 	for (size_t i = 0; i < MAX_NUM_PLAYERS; ++i)
 	{
 		// Create new player tab and get controls
 		wxString name(_("Unknown"));
 		if (playerDefs["Name"].defined())
 			name = playerDefs["Name"];
-		
+
 		PlayerPageControls controls = m_Players->AddPlayer(name, i);
 		m_PlayerControls.push_back(controls);
 
@@ -634,7 +664,6 @@ void PlayerSettingsControl::CreateWidgets()
 			aiChoice->Append(ais[j]->GetName(), new wxStringClientData(ais[j]->GetID()));
 		aiChoice->SetSelection(0);
 
-		// Only increment AtIters if they are defined
 		if (playerDefs.defined())
 			++playerDefs;
 	}
@@ -646,7 +675,7 @@ void PlayerSettingsControl::LoadDefaults()
 {
 	AtlasMessage::qGetPlayerDefaults qryPlayers;
 	qryPlayers.Post();
-	AtObj playerData = AtlasObject::LoadFromJSON(m_ScenarioEditor.GetScriptInterface().GetContext(), *qryPlayers.defaults);
+	AtObj playerData = AtlasObject::LoadFromJSON(*qryPlayers.defaults);
 	m_PlayerDefaults = *playerData["PlayerData"];
 }
 
@@ -658,7 +687,7 @@ void PlayerSettingsControl::ReadFromEngine()
 	if (!(*qry.settings).empty())
 	{
 		// Prevent error if there's no map settings to parse
-		m_MapSettings = AtlasObject::LoadFromJSON(m_ScenarioEditor.GetScriptInterface().GetContext(), *qry.settings);
+		m_MapSettings = AtlasObject::LoadFromJSON(*qry.settings);
 	}
 	else
 	{
@@ -673,7 +702,10 @@ void PlayerSettingsControl::ReadFromEngine()
 		m_NumPlayers = MAX_NUM_PLAYERS;
 	}
 	else
+	{
+		++player; // skip gaia
 		m_NumPlayers = player.count();
+	}
 
 	wxASSERT(m_NumPlayers <= MAX_NUM_PLAYERS && m_NumPlayers != 0);
 
@@ -698,21 +730,17 @@ void PlayerSettingsControl::ReadFromEngine()
 		wxString name(_("Unknown"));
 		bool defined = player["Name"].defined();
 		if (defined)
-			name = wxString(player["Name"]);
+			name = wxString::FromUTF8(player["Name"]);
 		else if (playerDefs["Name"].defined())
-			name = wxString(playerDefs["Name"]);
+			name = wxString::FromUTF8(playerDefs["Name"]);
 
 		controls.name->SetValue(name);
 		wxDynamicCast(FindWindowById(ID_DefaultName, controls.page), DefaultCheckbox)->SetValue(defined);
 
 		// civ
 		wxChoice* choice = controls.civ;
-		wxString civCode;
 		defined = player["Civ"].defined();
-		if (defined)
-			civCode = wxString(player["Civ"]);
-		else
-			civCode = wxString(playerDefs["Civ"]);
+		wxString civCode = wxString::FromUTF8(defined ? player["Civ"] : playerDefs["Civ"]);
 
 		for (size_t j = 0; j < choice->GetCount(); ++j)
 		{
@@ -725,23 +753,19 @@ void PlayerSettingsControl::ReadFromEngine()
 		}
 		wxDynamicCast(FindWindowById(ID_DefaultCiv, controls.page), DefaultCheckbox)->SetValue(defined);
 
-		// colour
-		wxColour colour;
-		AtObj clrObj = *player["Colour"];
+		// color
+		wxColor color;
+		AtObj clrObj = *player["Color"];
 		defined = clrObj.defined();
 		if (!defined)
-			clrObj = *playerDefs["Colour"];
-		colour = wxColor((*clrObj["r"]).getInt(), (*clrObj["g"]).getInt(), (*clrObj["b"]).getInt());
-		controls.colour->SetBackgroundColour(colour);
-		wxDynamicCast(FindWindowById(ID_DefaultColour, controls.page), DefaultCheckbox)->SetValue(defined);
+			clrObj = *playerDefs["Color"];
+		color = wxColor((*clrObj["r"]).getInt(), (*clrObj["g"]).getInt(), (*clrObj["b"]).getInt());
+		controls.color->SetBackgroundColour(color);
+		wxDynamicCast(FindWindowById(ID_DefaultColor, controls.page), DefaultCheckbox)->SetValue(defined);
 
 		// player type
-		wxString aiID;
 		defined = player["AI"].defined();
-		if (defined)
-			aiID = wxString(player["AI"]);
-		else
-			aiID = wxString(playerDefs["AI"]);
+		wxString aiID = wxString::FromUTF8(defined ? player["AI"] : playerDefs["AI"]);
 
 		choice = controls.ai;
 		if (!aiID.empty())
@@ -765,28 +789,28 @@ void PlayerSettingsControl::ReadFromEngine()
 		AtObj resObj = *player["Resources"];
 		defined = resObj.defined() && resObj["food"].defined();
 		if (defined)
-			controls.food->SetValue(wxString(resObj["food"]));
+			controls.food->SetValue((*resObj["food"]).getInt());
 		else
 			controls.food->SetValue(0);
 		wxDynamicCast(FindWindowById(ID_DefaultFood, controls.page), DefaultCheckbox)->SetValue(defined);
 
 		defined = resObj.defined() && resObj["wood"].defined();
 		if (defined)
-			controls.wood->SetValue(wxString(resObj["wood"]));
+			controls.wood->SetValue((*resObj["wood"]).getInt());
 		else
 			controls.wood->SetValue(0);
 		wxDynamicCast(FindWindowById(ID_DefaultWood, controls.page), DefaultCheckbox)->SetValue(defined);
 
 		defined = resObj.defined() && resObj["metal"].defined();
 		if (defined)
-			controls.metal->SetValue(wxString(resObj["metal"]));
+			controls.metal->SetValue((*resObj["metal"]).getInt());
 		else
 			controls.metal->SetValue(0);
 		wxDynamicCast(FindWindowById(ID_DefaultMetal, controls.page), DefaultCheckbox)->SetValue(defined);
 
 		defined = resObj.defined() && resObj["stone"].defined();
 		if (defined)
-			controls.stone->SetValue(wxString(resObj["stone"]));
+			controls.stone->SetValue((*resObj["stone"]).getInt());
 		else
 			controls.stone->SetValue(0);
 		wxDynamicCast(FindWindowById(ID_DefaultStone, controls.page), DefaultCheckbox)->SetValue(defined);
@@ -794,7 +818,7 @@ void PlayerSettingsControl::ReadFromEngine()
 		// population limit
 		defined = player["PopulationLimit"].defined();
 		if (defined)
-			controls.pop->SetValue(wxString(player["PopulationLimit"]));
+			controls.pop->SetValue((*player["PopulationLimit"]).getInt());
 		else
 			controls.pop->SetValue(0);
 		wxDynamicCast(FindWindowById(ID_DefaultPop, controls.page), DefaultCheckbox)->SetValue(defined);
@@ -822,15 +846,15 @@ void PlayerSettingsControl::ReadFromEngine()
 			info.rX = (float)(*camRot["x"]).getDouble();
 			info.rY = (float)(*camRot["y"]).getDouble();
 			info.rZ = (float)(*camRot["z"]).getDouble();
-			
+
 			controls.page->SetCamera(info, true);
 		}
 		else
 			controls.page->SetCamera(sCameraInfo(), false);
 
-		// Only increment AtIters if they are defined
 		if (player.defined())
 			++player;
+
 		if (playerDefs.defined())
 			++playerDefs;
 	}
@@ -845,10 +869,14 @@ AtObj PlayerSettingsControl::UpdateSettingsObject()
 {
 	// Update player data in the map settings
 	AtObj players;
-	players.set("@array", L"");
+	players.set("@array", "");
 
 	wxASSERT(m_NumPlayers <= MAX_NUM_PLAYERS);
 
+	AtIter playerDefs = m_PlayerDefaults["item"];
+	if (playerDefs.defined())
+		++playerDefs;	// Skip gaia
+
 	for (size_t i = 0; i < m_NumPlayers; ++i)
 	{
 		PlayerPageControls controls = m_PlayerControls[i];
@@ -858,40 +886,39 @@ AtObj PlayerSettingsControl::UpdateSettingsObject()
 		// name
 		wxTextCtrl* text = controls.name;
 		if (text->IsEnabled())
-			player.set("Name", text->GetValue());
+			player.set("Name", text->GetValue().utf8_str());
 
 		// civ
 		wxChoice* choice = controls.civ;
 		if (choice->IsEnabled() && choice->GetSelection() >= 0)
 		{
 			wxStringClientData* str = dynamic_cast<wxStringClientData*>(choice->GetClientObject(choice->GetSelection()));
-			player.set("Civ", str->GetData());
+			player.set("Civ", str->GetData().utf8_str());
 		}
+		else
+			player.unset("Civ");
 
-		// colour
-		if (controls.colour->IsEnabled())
+		// color
+		if (controls.color->IsEnabled())
 		{
-			wxColour colour = controls.colour->GetBackgroundColour();
+			wxColor color = controls.color->GetBackgroundColour();
 			AtObj clrObj;
-			clrObj.setInt("r", (int)colour.Red());
-			clrObj.setInt("g", (int)colour.Green());
-			clrObj.setInt("b", (int)colour.Blue());
-			player.set("Colour", clrObj);
+			clrObj.setInt("r", (int)color.Red());
+			clrObj.setInt("g", (int)color.Green());
+			clrObj.setInt("b", (int)color.Blue());
+			player.set("Color", clrObj);
 		}
 
 		// player type
 		choice = controls.ai;
-		if (choice->IsEnabled())
+		if (choice->IsEnabled() && choice->GetSelection() > 0)
 		{
-			if (choice->GetSelection() > 0)
-			{
-				// ai - get id
-				wxStringClientData* str = dynamic_cast<wxStringClientData*>(choice->GetClientObject(choice->GetSelection()));
-				player.set("AI", str->GetData());
-			}
-			else // human
-				player.set("AI", _T(""));
+			// ai - get id
+			wxStringClientData* str = dynamic_cast<wxStringClientData*>(choice->GetClientObject(choice->GetSelection()));
+			player.set("AI", str->GetData().utf8_str());
 		}
+		else // human
+			player.unset("AI");
 
 		// resources
 		AtObj resObj;
@@ -935,8 +962,11 @@ AtObj PlayerSettingsControl::UpdateSettingsObject()
 		player.set("StartingCamera", camObj);
 
 		players.add("item", player);
+
+		if (playerDefs.defined())
+			++playerDefs;
 	}
-	
+
 	m_MapSettings.set("PlayerData", players);
 
 	return m_MapSettings;
@@ -946,7 +976,7 @@ void PlayerSettingsControl::SendToEngine()
 {
 	UpdateSettingsObject();
 
-	std::string json = AtlasObject::SaveToJSON(m_ScenarioEditor.GetScriptInterface().GetContext(), m_MapSettings);
+	std::string json = AtlasObject::SaveToJSON(m_MapSettings);
 
 	// TODO: would be nice if we supported undo for settings changes
 
@@ -958,8 +988,14 @@ void PlayerSettingsControl::SendToEngine()
 PlayerSidebar::PlayerSidebar(ScenarioEditor& scenarioEditor, wxWindow* sidebarContainer, wxWindow* bottomBarContainer)
 	: Sidebar(scenarioEditor, sidebarContainer, bottomBarContainer), m_Loaded(false)
 {
-	m_PlayerSettingsCtrl = new PlayerSettingsControl(this, m_ScenarioEditor);
-	m_MainSizer->Add(m_PlayerSettingsCtrl, wxSizerFlags().Expand());
+	wxSizer* scrollSizer = new wxBoxSizer(wxVERTICAL);
+	wxScrolledWindow* scrolledWindow = new wxScrolledWindow(this);
+	scrolledWindow->SetScrollRate(10, 10);
+	scrolledWindow->SetSizer(scrollSizer);
+	m_MainSizer->Add(scrolledWindow, wxSizerFlags().Proportion(1).Expand());
+
+	m_PlayerSettingsCtrl = new PlayerSettingsControl(scrolledWindow, m_ScenarioEditor);
+	scrollSizer->Add(m_PlayerSettingsCtrl, wxSizerFlags().Expand());
 }
 
 void PlayerSidebar::OnCollapse(wxCollapsiblePaneEvent& WXUNUSED(evt))
