@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Wildfire Games.
+/* Copyright (C) 2025 Wildfire Games.
  * This file is part of 0 A.D.
  *
  * 0 A.D. is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 #ifndef INCLUDED_INPUTPROCESSOR
 #define INCLUDED_INPUTPROCESSOR
 
-#include "GameLoop.h"
+struct GameLoopState;
 
 class InputProcessor
 {
