@@ -21,22 +21,22 @@ def test_dump_directory_unicode(request, check_for_crashes, tmpdir, capsys):
     """Test that check_for_crashes can handle unicode in dump_directory."""
     from conftest import minidump_files
 
-    tmpdir = tmpdir.ensure(u"🍪", dir=1)
+    tmpdir = tmpdir.ensure("🍪", dir=1)
     minidump_files = minidump_files(request, tmpdir)
 
     assert 1 == check_for_crashes(dump_directory=fspath(tmpdir), quiet=False)
 
     out, _ = capsys.readouterr()
     assert fspath(minidump_files[0]["dmp"]) in out
-    assert u"🍪" in out
+    assert "🍪" in out
 
 
 def test_test_name_unicode(check_for_crashes, minidump_files, capsys):
     """Test that check_for_crashes can handle unicode in dump_directory."""
-    assert 1 == check_for_crashes(test_name=u"🍪", quiet=False)
+    assert 1 == check_for_crashes(test_name="🍪", quiet=False)
 
     out, err = capsys.readouterr()
-    assert u"| 🍪" in out
+    assert "| 🍪" in out
 
 
 if __name__ == "__main__":
