@@ -7,12 +7,10 @@
 """
 tests for mozfile.NamedTemporaryFile
 """
-from __future__ import absolute_import
-
-import mozfile
 import os
 import unittest
 
+import mozfile
 import mozunit
 import six
 
@@ -21,10 +19,10 @@ class TestNamedTemporaryFile(unittest.TestCase):
     """test our fix for NamedTemporaryFile"""
 
     def test_named_temporary_file(self):
-        """ Ensure the fix for re-opening a NamedTemporaryFile works
+        """Ensure the fix for re-opening a NamedTemporaryFile works
 
-            Refer to https://bugzilla.mozilla.org/show_bug.cgi?id=818777
-            and https://bugzilla.mozilla.org/show_bug.cgi?id=821362
+        Refer to https://bugzilla.mozilla.org/show_bug.cgi?id=818777
+        and https://bugzilla.mozilla.org/show_bug.cgi?id=821362
         """
 
         test_string = b"A simple test"
@@ -35,21 +33,21 @@ class TestNamedTemporaryFile(unittest.TestCase):
             temp.flush()
 
             # Test we can open the file again on all platforms
-            self.assertEqual(open(temp.name, 'rb').read(), test_string)
+            self.assertEqual(open(temp.name, "rb").read(), test_string)
 
     def test_iteration(self):
         """ensure the line iterator works"""
 
         # make a file and write to it
         tf = mozfile.NamedTemporaryFile()
-        notes = [b'doe', b'rae', b'mi']
+        notes = [b"doe", b"rae", b"mi"]
         for note in notes:
-            tf.write(b'%s\n' % note)
+            tf.write(b"%s\n" % note)
         tf.flush()
 
         # now read from it
         tf.seek(0)
-        lines = [line.rstrip(b'\n') for line in tf.readlines()]
+        lines = [line.rstrip(b"\n") for line in tf.readlines()]
         self.assertEqual(lines, notes)
 
         # now read from it iteratively
@@ -103,5 +101,5 @@ class TestNamedTemporaryFile(unittest.TestCase):
                 os.remove(path)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     mozunit.main()
