@@ -13,7 +13,6 @@ import subprocess
 import sys
 import telnetlib
 import time
-from distutils.spawn import find_executable
 from enum import Enum
 
 import six
@@ -176,7 +175,6 @@ AVD_DICT = {
 
 
 def _get_device(substs, device_serial=None):
-
     adb_path = _find_sdk_exe(substs, "adb", False)
     if not adb_path:
         adb_path = "adb"
@@ -261,7 +259,7 @@ def _maybe_update_host_utils(build_obj):
 
     # Compare, prompt, update
     if existing_version and manifest_version:
-        hu_version_regex = "host-utils-([\d\.]*)"
+        hu_version_regex = r"host-utils-([\d\.]*)"
         manifest_version = float(re.search(hu_version_regex, manifest_version).group(1))
         existing_version = float(re.search(hu_version_regex, existing_version).group(1))
         if existing_version < manifest_version:
@@ -306,11 +304,21 @@ def verify_android_device(
     Returns True if the emulator was started or another device was
     already connected.
     """
-    if "MOZ_DISABLE_ADB_INSTALL" in os.environ:
+    if "MOZ_DISABLE_ADB_INSTALL" in os.environ or install == InstallIntent.NO:
         install = InstallIntent.NO
         _log_info(
-            "Found MOZ_DISABLE_ADB_INSTALL in environment, skipping android app"
-            "installation"
+            "Found MOZ_DISABLE_ADB_INSTALL in environment and/or the"
+            " --noinstall flag, skipping android app installation"
+        )
+    else:
+        _log_info(
+            "*********************************************************************\n"
+            "Neither the MOZ_DISABLE_ADB_INSTALL environment variable nor the\n"
+            "--noinstall flag was found. The code will now uninstall the current\n"
+            "app then re-install the android app from a different source. If you\n"
+            "don't want this set your local env so that\n"
+            "MOZ_DISABLE_ADB_INSTALL=True or pass the --noinstall flag\n"
+            "*********************************************************************"
         )
     device_verified = False
     emulator = AndroidEmulator("*", substs=build_obj.substs, verbose=verbose)
@@ -933,7 +941,7 @@ def _find_sdk_exe(substs, exe, tools):
 
     if not found:
         # Is exe on PATH?
-        exe_path = find_executable(exe)
+        exe_path = shutil.which(exe)
         if exe_path:
             found = True
         else:
